<?php
namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Base;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */

class SR_Bandsintown extends Widget_Base {

	public function get_name() {
		return 'bandsintown';
	}

	public function get_title() {
		return __( 'Bands In Town', 'elementor-sonaar' );
	}

	public function get_icon() {
		return 'far fa-calendar sonaar-badge';
	}
	public function get_help_url() {
		return 'https://support.sonaar.io';
	}
	public function get_categories() {
		return [ 'elementor-sonaar' ];
	}

	public function get_script_depends() {
		return [ 'elementor-sonaar' ];
	}
	public function get_keywords() {
		return [ 'bands', 'event', 'concert', 'calendar', 'sonaar'];
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Bands In Town Settings', 'elementor-sonaar' ),
			]
		);
				$this->add_control(
					'band_name',
					[
						'label' => __( 'Band Name', 'elementor-sonaar' ),
						'type' => \Elementor\Controls_Manager::TEXT,
						'placeholder' => __( 'Type your BandsInTown artist name here', 'elementor-sonaar' ),
					]
				);
				$this->add_control(
					'widget_background_color',
					[
						'label' => esc_html__( 'Background Color', 'elementor-sonaar' ),
						'type' => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .bit-widget' => 'background-color:{{VALUE}};',
							'{{WRAPPER}} .bit-widget .bit-offers' => 'color:{{VALUE}};',
						],
					]
				);
				$this->add_control(
					'widget_bt_color',
					[
						'label' => esc_html__( 'Button & Link Color', 'elementor-sonaar' ),
						'type' => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .bit-widget .bit-venue, {{WRAPPER}} .bit-widget .bit-rsvp, {{WRAPPER}} .bit-widget .bit-clickable, {{WRAPPER}} .bit-widget .bit-upcoming-events-show-all-button' => 'color:{{VALUE}};border-color:{{VALUE}};',
							'{{WRAPPER}} .bit-widget .bit-offers' => 'border-color:{{VALUE}};',
							'{{WRAPPER}} .bit-widget .bit-offers' => 'background-color:{{VALUE}};',

						],
					]
				);
				$this->add_control(
					'widget_textcolor',
					[
						'label' => esc_html__( 'Text Color', 'elementor-sonaar' ),
						'type' => Controls_Manager::COLOR,
						'selectors' => [
							'{{WRAPPER}} .bit-widget, {{WRAPPER}} .bit-widget .bit-event' => 'color:{{VALUE}};',
						],
					]
				);
				$this->add_control(
					'event_number_to_show',
					[
						'label' => __( 'Maximum numbers of Events to display', 'elementor-sonaar' ),
						'type' => \Elementor\Controls_Manager::NUMBER,
						'min' => 1,
						'max' => 100,
						'step' => 1,
						'default' => 10,
					]
				);
				$this->add_control(
					'display_local_dates',
						[
							'label'                 => esc_html__( 'Display Local Events', 'elementor-sonaar' ),
							'type'                  => Controls_Manager::SELECT,
							'label_block'           => true,
							'options' 				=> [
										'1'			=> __( 'Yes', 'elementor-sonaar' ),
										'' 			=> __( 'No', 'elementor-sonaar' ),
									],
			                'default'               => '',        	
						]
				);
				$this->add_control(
					'display_past_events',
						[
							'label'                 => esc_html__( 'Display Past Events', 'elementor-sonaar' ),
							'type'                  => Controls_Manager::SELECT,
							'label_block'           => true,
							'options'				=> [
										'1'			=> __( 'Yes', 'elementor-sonaar' ),
										'' 			=> __( 'No', 'elementor-sonaar' ),
									],
			                'default'               => '',
			                
			               				             	
						]
				);
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$shortcode = '[iron_bandsintown band_name="' . $settings['band_name'] . '" background_color="' . $settings['widget_background_color'] . '" button_color="' . $settings['widget_bt_color'] . '" button_txt_color="' . $settings['widget_textcolor'] . '" local_dates="' . $settings['display_local_dates'] . '" past_dates="' . $settings['display_past_events'] . '" display_limit="' . $settings['event_number_to_show'] . '"]';
		echo do_shortcode( $shortcode );
	}
	public function render_plain_content() {
		$settings = $this->get_settings_for_display();
		$shortcode = '[iron_bandsintown band_name="' . $settings['band_name'] . '" background_color="' . $settings['widget_background_color'] . '" button_color="' . $settings['widget_bt_color'] . '" button_txt_color="' . $settings['widget_textcolor'] . '" local_dates="' . $settings['display_local_dates'] . '" past_dates="' . $settings['display_past_events'] . '" display_limit="' . $settings['event_number_to_show'] . '"]';
		echo $shortcode;
	}
	

	
}
Plugin::instance()->widgets_manager->register( new SR_Bandsintown() );