<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Base;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

class SR_DualHeading extends Widget_Base {

    public function get_name() {
        return 'sr-dualheading';
    }

    public function get_title() {
        return esc_html__( 'Dual Heading', 'essential-addons-elementor' );
    }

    public function get_icon() {
        return 'eicon-animated-headline sonaar-badge';
    }
	public function get_help_url() {
		return 'https://support.sonaar.io';
	}
    public function get_categories() {
        return [ 'elementor-sonaar' ];
    }

    protected function register_controls() {

        /**
         * Dual Color Heading Content Settings
         */
        $this->start_controls_section(
            'sr_section_dch_content_settings',
            [
                'label' => esc_html__( 'Content Settings', 'essential-addons-elementor' )
            ]
        );

        $this->add_control(
            'sr_dch_type',
            [
            'label'         => esc_html__( 'Content Style', 'essential-addons-elementor' ),
                'type'          => Controls_Manager::SELECT,
                'default'       => 'dch-default',
                'label_block'   => false,
                'options'       => [
                    'dch-default'                   => esc_html__( 'Default', 'essential-addons-elementor' ),
                    'dch-icon-on-top'               => esc_html__( 'Icon on top', 'essential-addons-elementor' ),
                    'dch-icon-subtext-on-top'   => esc_html__( 'Icon &amp; sub-text on top', 'essential-addons-elementor' ),
                    'dch-subtext-on-top'            => esc_html__( 'Sub-text on top', 'essential-addons-elementor' ),
                ],
            ]
        );
        $this->add_control(
            'sr_show_dch_icon_content',
            [
                'label' => __( 'Show Icon', 'essential-addons-elementor' ),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'label_on' => __( 'Show', 'essential-addons-elementor' ),
                'label_off' => __( 'Hide', 'essential-addons-elementor' ),
                'return_value' => 'yes',
                'separator' => 'after',
            ]
        );
        /**
         * Condition: 'sr_show_dch_icon_content' => 'yes'
         */
        $this->add_control(
            'sr_dch_icon',
            [
                'label' => esc_html__( 'Icon', 'essential-addons-elementor' ),
                'type' => Controls_Manager::ICON,
                'default' => 'fa fa-heart',
                'condition' => [
                    'sr_show_dch_icon_content' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'sr_dch_first_title',
            [
                'label' => esc_html__( 'Title ( First Part )', 'essential-addons-elementor' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => esc_html__( 'Sonaar', 'essential-addons-elementor' ),
                'dynamic' => [ 'active' => true ]
            ]
        );

        $this->add_control(
            'sr_dch_last_title',
            [
                'label' => esc_html__( 'Title ( Last Part )', 'essential-addons-elementor' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => esc_html__( 'Music', 'essential-addons-elementor' ),
                'dynamic' => [ 'active' => true ]
            ]
        );

        $this->add_control(
            'sr_dch_subtext',
            [
                'label' => esc_html__( 'Sub Text', 'essential-addons-elementor' ),
                'type' => Controls_Manager::WYSIWYG,
                'label_block' => true,
                'default' => esc_html__( 'Insert a very nice optional subtitle here.', 'essential-addons-elementor' )
            ]
        );

        $this->add_responsive_control(
            'sr_dch_content_alignment',
            [
                'label' => esc_html__( 'Alignment', 'essential-addons-elementor' ),
                'type' => Controls_Manager::CHOOSE,
                'label_block' => true,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'essential-addons-elementor' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'essential-addons-elementor' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'essential-addons-elementor' ),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'default' => 'center',
                'prefix_class' => 'sr-dual-header-content-align-'
            ]
        );

        $this->end_controls_section();

        /**
         * -------------------------------------------
         * Tab Style ( Dual Heading Style )
         * -------------------------------------------
         */
        $this->start_controls_section(
            'sr_section_dch_style_settings',
            [
                'label' => esc_html__( 'Dual Heading Style', 'essential-addons-elementor' ),
                'tab' => Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_control(
            'sr_dch_bg_color',
            [
                'label' => esc_html__( 'Background Color', 'essential-addons-elementor' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .sr-dual-header' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'sr_dch_container_padding',
            [
                'label' => esc_html__( 'Padding', 'essential-addons-elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                        '{{WRAPPER}} .sr-dual-header' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'sr_dch_container_margin',
            [
                'label' => esc_html__( 'Margin', 'essential-addons-elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                        '{{WRAPPER}} .sr-dual-header' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'sr_dch_border',
                'label' => esc_html__( 'Border', 'essential-addons-elementor' ),
                'selector' => '{{WRAPPER}} .sr-dual-header',
            ]
        );

        $this->add_control(
            'sr_dch_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'essential-addons-elementor' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .sr-dual-header' => 'border-radius: {{SIZE}}px;',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'sr_dch_shadow',
                'selector' => '{{WRAPPER}} .sr-dual-header',
            ]
        );

        $this->end_controls_section();

        /**
         * -------------------------------------------
         * Tab Style (Title Style)
         * -------------------------------------------
         */
        $this->start_controls_section(
            'sr_section_dch_title_style_settings',
            [
                'label' => esc_html__( 'Color &amp; Typography', 'essential-addons-elementor' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'sr_dch_title_heading',
            [
                'label' => esc_html__( 'Title Style', 'essential-addons-elementor' ),
                'type' => Controls_Manager::HEADING,
            ]
        );

        $this->add_control(
            'sr_dch_base_title_color',
            [
                'label' => esc_html__( 'Main Color', 'essential-addons-elementor' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#4d4d4d',
                'selectors' => [
                    '{{WRAPPER}} .sr-dual-header .title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'sr_dch_dual_title_color',
            [
                'label' => esc_html__( 'Dual Color', 'essential-addons-elementor' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#1abc9c',
                'selectors' => [
                    '{{WRAPPER}} .sr-dual-header .title span.lead' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
            'name' => 'sr_dch_first_title_typography',
                'selector' => '{{WRAPPER}} .sr-dual-header .title, {{WRAPPER}} .sr-dual-header .title span',
            ]
        );

        $this->add_control(
            'sr_dch_sub_title_heading',
            [
                'label' => esc_html__( 'Sub-title Style ', 'essential-addons-elementor' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'sr_dch_subtext_color',
            [
                'label' => esc_html__( 'Color', 'essential-addons-elementor' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#4d4d4d',
                'selectors' => [
                    '{{WRAPPER}} .sr-dual-header .subtext' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
            'name' => 'sr_dch_subtext_typography',
                'selector' => '{{WRAPPER}} .sr-dual-header .subtext',
            ]
        );

        $this->end_controls_section();

        /**
         * -------------------------------------------
         * Tab Style (Icon Style)
         * -------------------------------------------
         */
        $this->start_controls_section(
            'sr_section_dch_icon_style_settings',
            [
                'label' => esc_html__( 'Icon Style', 'essential-addons-elementor' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'sr_show_dch_icon_content' => 'yes'
                ]
            ]
        );

        $this->add_control(
            'sr_dch_icon_size',
            [
                'label' => __( 'Icon Size', 'essential-addons-elementor' ),
            'type' => Controls_Manager::SLIDER,
                'default' => [
                'size' => 36,
                ],
                'range' => [
                'px' => [
                    'min' => 20,
                    'max' => 100,
                    'step' => 1,
                ]
                ],
                'selectors' => [
                '{{WRAPPER}} .sr-dual-header i' => 'font-size: {{SIZE}}px;',
                ],
            ]
        );

        $this->add_control(
            'sr_dch_icon_color',
            [
                'label' => esc_html__( 'Icon Color', 'essential-addons-elementor' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#4d4d4d',
                'selectors' => [
                    '{{WRAPPER}} .sr-dual-header i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();


    }

    protected function render( ) {

    $settings = $this->get_settings_for_display();

    ?>
    <?php if( 'dch-default' == $settings['sr_dch_type'] ) : ?>
    <div class="sr-dual-header">
        <h2 class="title"><span class="lead"><?php esc_html_e( $settings['sr_dch_first_title'], 'essential-addons-elementor' ); ?></span> <span><?php esc_html_e( $settings['sr_dch_last_title'], 'essential-addons-elementor' ); ?></span></h2>
       <span class="subtext"><?php echo $settings['sr_dch_subtext']; ?></span>
       <?php if( 'yes' == $settings['sr_show_dch_icon_content'] ) : ?>
        <i class="<?php echo esc_attr( $settings['sr_dch_icon'] ); ?>"></i>
        <?php endif; ?>
    </div>
    <?php endif; ?>

    <?php if( 'dch-icon-on-top' == $settings['sr_dch_type'] ) : ?>
    <div class="sr-dual-header">
        <?php if( 'yes' == $settings['sr_show_dch_icon_content'] ) : ?>
        <i class="<?php echo esc_attr( $settings['sr_dch_icon'] ); ?>"></i>
        <?php endif; ?>
        <h2 class="title"><span class="lead"><?php esc_html_e( $settings['sr_dch_first_title'], 'essential-addons-elementor' ); ?></span> <span><?php esc_html_e( $settings['sr_dch_last_title'], 'essential-addons-elementor' ); ?></span></h2>
       <span class="subtext"><?php echo $settings['sr_dch_subtext']; ?></span>
    </div>
    <?php endif; ?>

    <?php if( 'dch-icon-subtext-on-top' == $settings['sr_dch_type'] ) : ?>
    <div class="sr-dual-header">
        <?php if( 'yes' == $settings['sr_show_dch_icon_content'] ) : ?>
        <i class="<?php echo esc_attr( $settings['sr_dch_icon'] ); ?>"></i>
        <?php endif; ?>
       <span class="subtext"><?php echo $settings['sr_dch_subtext']; ?></span>
       <h2 class="title"><span class="lead"><?php esc_html_e( $settings['sr_dch_first_title'], 'essential-addons-elementor' ); ?></span> <span><?php esc_html_e( $settings['sr_dch_last_title'], 'essential-addons-elementor' ); ?></span></h2>
    </div>
    <?php endif; ?>

    <?php if( 'dch-subtext-on-top' == $settings['sr_dch_type'] ) : ?>
    <div class="sr-dual-header">
       <span class="subtext"><?php echo $settings['sr_dch_subtext']; ?></span>
            <h2 class="title"><span class="lead"><?php esc_html_e( $settings['sr_dch_first_title'], 'essential-addons-elementor' ); ?></span> <span><?php esc_html_e( $settings['sr_dch_last_title'], 'essential-addons-elementor' ); ?></span></h2>
        <?php if( 'yes' == $settings['sr_show_dch_icon_content'] ) : ?>
        <i class="<?php echo esc_attr( $settings['sr_dch_icon'] ); ?>"></i>
        <?php endif; ?>
    </div>
    <?php endif; ?>

    <?php
    }

    protected function content_template() {
        ?>

        <?php
    }
}


Plugin::instance()->widgets_manager->register( new SR_DualHeading() );