<?php
namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Base;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;



/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */

class SR_Events extends Widget_Base {

	public function get_name() {
		return 'event';
	}

	public function get_title() {
		return __( 'Event & Gigs', 'elementor-sonaar' );
	}

	public function get_icon() {
		return 'fas fa-calendar sonaar-badge';
	}
	public function get_help_url() {
		return 'https://support.sonaar.io';
	}
	public function get_categories() {
		return [ 'elementor-sonaar' ];
	}

	public function get_script_depends() {
		return [ 'elementor-sonaar' ];
	}
	public function get_keywords() {
		return [ 'event', 'show', 'date', 'concert', 'calendar', 'sonaar'];
	}
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Events & Gigs Settings', 'elementor-sonaar' ),
			]
		);
			
			$this->add_control(
				'event_displayer_by_list',
					[
						'label'                 => esc_html__( 'Display by', 'elementor-sonaar' ),
						'type'                  => Controls_Manager::SELECT,
						'label_block'           => false,
						'options' => [
									'upcoming'  => __( 'Upcoming Events', 'elementor-sonaar' ),
									'past' => __( 'Past Events', 'elementor-sonaar' ),
								],
		                'default'               => 'upcoming',
		                
		               				             	
					]
			);
			$this->add_control(
				'event_number_to_show',
				[
					'label' => __( 'Maximum numbers of Events to display', 'elementor-sonaar' ),
					'type' => \Elementor\Controls_Manager::NUMBER,
					'min' => 1,
					'max' => 9999,
					'step' => 1,
					'default' => 10,
				]
			);
			$this->add_control(
				'hr11',
					[
						'type' => \Elementor\Controls_Manager::DIVIDER,
						'style' => 'default',
					]
			);
			$this->add_control(
				'event_display_events_for',
				[
					'label' => __( 'Which Artist(s) you want to display the events for?', 'elementor-sonaar' ),
					'type' => \Elementor\Controls_Manager::SELECT2,
					'label_block' => true,
					'multiple' => true,
					'options' => sr_elementor_select_events_for(),
					'default' => '',
				]
			);
			$this->add_control(
				'event_enable_artist_filter',
					[
						'label'                 => esc_html__( 'Enable Artist Dropdown Filter', 'elementor-sonaar' ),
						'type'                  => Controls_Manager::SELECT,
						'label_block'           => false,
						'options' => [
									'yes'		=> __( 'Yes', 'elementor-sonaar' ),
									'' 			=> __( 'No', 'elementor-sonaar' ),
								],
		                'default'               => '',
		                
		               				             	
					]
			);
			$this->add_control(
				'hr10',
					[
						'type' => \Elementor\Controls_Manager::DIVIDER,
						'style' => 'default',
					]
			);
			$this->add_control(
				'hide_time',
				[
					'label' => __( 'Hide Time', 'elementor-sonaar' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => __( 'Yes', 'elementor-sonaar' ),
					'label_off' => __( 'No', 'elementor-sonaar' ),
					'return_value' => '1',
					'default' => '1',
				]
			);
			$this->add_control(
				'hide_artist',
				[
					'label' => __( 'Hide Artist', 'elementor-sonaar' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => __( 'Yes', 'elementor-sonaar' ),
					'label_off' => __( 'No', 'elementor-sonaar' ),
					'return_value' => '1',
					'default' => '0',
				]
			);
			$this->add_control(
				'hide_venue',
				[
					'label' => __( 'Hide Venue', 'elementor-sonaar' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => __( 'Yes', 'elementor-sonaar' ),
					'label_off' => __( 'No', 'elementor-sonaar' ),
					'return_value' => '1',
					'default' => '0',
				]
			);
			$this->add_control(
				'hide_city',
				[
					'label' => __( 'Hide City', 'elementor-sonaar' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => __( 'Yes', 'elementor-sonaar' ),
					'label_off' => __( 'No', 'elementor-sonaar' ),
					'return_value' => '1',
					'default' => '0',
				]
			);
			$this->add_control(
				'sr_event_btshow',
				[
					'label' => esc_html__( 'Hide button(s)?', 'sonaar-elementor' ),
					'type' => Controls_Manager::SWITCHER,
					'default' => '',
					'return_value' => 'none',
					'selectors' => [
		 					'{{WRAPPER}} .sr_it-event-buttons' => 'display:{{VALUE}};',
		 			],
				]
			);
			$this->add_control(
				'hr12',
					[
						'type' => \Elementor\Controls_Manager::DIVIDER,
						'style' => 'default',
					]
			);
			$this->add_control(
				'sr_event_title_tag',
				[
					'label' => __( 'HTML Title Tag', 'elementor-sonaar' ),
					'type' => Controls_Manager::SELECT,
					'options' => [
						'h1' => 'H1',
						'h2' => 'H2',
						'h3' => 'H3',
						'h4' => 'H4',
						'h5' => 'H5',
						'h6' => 'H6',
						'div' => 'div',
						'span' => 'span',
						'p' => 'p',
					],
					'default' => 'h1',
				]
			);
			$this->add_control(
				'hr14',
					[
						'type' => \Elementor\Controls_Manager::DIVIDER,
						'style' => 'default',
					]
			);
			$this->add_control(
				'important_note',
				[
					'label' => __( 'Message', 'elementor-sonaar' ),
					'show_label' => false,
					'type' => \Elementor\Controls_Manager::RAW_HTML,
					'raw' => __( '<br>To add a new event, go to the <a href="./edit.php?post_type=event" target="_blank">Event Section</a>', 'elementor-sonaar' ),
					'content_classes' => 'elementor-sonaar-raw-html',
				]
			);
		$this->end_controls_section();

        /**
         * STYLE: LOOK AND FEEL
         * -------------------------------------------------
         */
		$this->start_controls_section(
            'typography_style',
            [
                'label'                 => __( 'Look and feel', 'elementor-sonaar' ),
                'tab'                   => Controls_Manager::TAB_STYLE,
            ]
        );
				$this->add_control(
						'title_color',
						[
							'label' 	=> esc_html__( 'Title Color', 'elementor-sonaar' ),
							'type' 		=> Controls_Manager::COLOR,
							'default'	=> '',
							'selectors' => ['{{WRAPPER}} .sr_it-event-main .sr_it-event-title' => 'color:{{VALUE}};',
										],
						]
				);
				$this->add_group_control(
					Group_Control_Typography::get_type(),
						[
							'name' => 'title_typography',
							'label' => __( 'Title Typography', 'elementor-sonaar' ),
							'scheme' => Typography::TYPOGRAPHY_1,
							'selector' => '{{WRAPPER}} .sr_it-event-main .sr_it-event-title',
						]
				);
				$this->add_control(
				'hr',
					[
						'type' => \Elementor\Controls_Manager::DIVIDER,
						'style' => 'default',
					]
				);
				$this->add_control(
						'subtitle_color',
						[
							'label' 	=> esc_html__( 'Sub Title Color', 'elementor-sonaar' ),
							'type' 		=> Controls_Manager::COLOR,
							'default'	=> '',
							'selectors' => ['{{WRAPPER}} .sr_it-event-info' => 'color:{{VALUE}};',
										],
						]
				);
				$this->add_group_control(
					Group_Control_Typography::get_type(),
						[
							'name' => 'subtitle_typography',
							'label' => __( 'Sub Title Typography', 'elementor-sonaar' ),
							'scheme' => Typography::TYPOGRAPHY_1,
							'selector' => '{{WRAPPER}} .sr_it-event-info',
						]
				);
				$this->add_control(
				'hr2',
					[
						'type' => \Elementor\Controls_Manager::DIVIDER,
						'style' => 'default',
					]
				);
				$this->add_control(
						'date_color',
						[
							'label' 	=> esc_html__( 'Day Date Color', 'elementor-sonaar' ),
							'type' 		=> Controls_Manager::COLOR,
							'default'	=> '',
							'selectors' => ['{{WRAPPER}} .sr-it-date-day' => 'color:{{VALUE}};',
										],
						]
				);
				$this->add_group_control(
					Group_Control_Typography::get_type(),
						[
							'name' => 'date_typography',
							'label' => __( 'Day Date Typography', 'elementor-sonaar' ),
							'scheme' => Typography::TYPOGRAPHY_1,
							'selector' => '{{WRAPPER}} .sr-it-date-day',
						]
				);
				$this->add_control(
				'hr3',
					[
						'type' => \Elementor\Controls_Manager::DIVIDER,
						'style' => 'default',
					]
				);				
				$this->add_control(
						'monthyear_color',
						[
							'label' 	=> esc_html__( 'Month/Year Color', 'elementor-sonaar' ),
							'type' 		=> Controls_Manager::COLOR,
							'default'	=> '',
							'selectors' => ['{{WRAPPER}} .sr-it-date-years' => 'color:{{VALUE}};',
										],
						]
				);
				$this->add_group_control(
					Group_Control_Typography::get_type(),
						[
							'name' => 'monthyear_typography',
							'label' => __( 'Month/Year Typography', 'elementor-sonaar' ),
							'scheme' => Typography::TYPOGRAPHY_1,
							'selector' => '{{WRAPPER}} .sr-it-date-years',
						]
				);
				$this->add_control(
				'hr4',
					[
						'type' => \Elementor\Controls_Manager::DIVIDER,
						'style' => 'default',
					]
				);				
				$this->add_control(
						'eventborder_color',
						[
							'label' 	=> esc_html__( 'Borders Color', 'elementor-sonaar' ),
							'type' 		=> Controls_Manager::COLOR,
							'default'	=> '',
							'selectors' => ['{{WRAPPER}} .concerts-list .event, {{WRAPPER}} .concerts-list:first-of-type, {{WRAPPER}} .sr_it-event-main' => 'border-color:{{VALUE}};',
										],
						]
				);
				$this->add_control(
				'hr5',
					[
						'type' => \Elementor\Controls_Manager::DIVIDER,
						'style' => 'default',
					]
				);
				$this->add_control(
						'event_bg_color',
						[
							'label' 	=> esc_html__( 'Background Color', 'elementor-sonaar' ),
							'type' 		=> Controls_Manager::COLOR,
							'default'	=> '',
							'selectors' =>  ['{{WRAPPER}} .concerts-list a' => 'background-color:{{VALUE}};',
											'{{WRAPPER}} .concerts-list' => 'background-color:inherit;',
										],
						]
				);
				$this->add_control(
						'event_hoverbg_color',
						[
							'label' 	=> esc_html__( 'Hover Background Color', 'elementor-sonaar' ),
							'type' 		=> Controls_Manager::COLOR,
							'default'	=> '',
							'selectors' => ['{{WRAPPER}} .concerts-list a:hover' => 'background-color:{{VALUE}};',
											'{{WRAPPER}} .concerts-list .event:hover a.event-link' => 'background-color:{{VALUE}};',
										],
						]
				);
				$this->add_control(
						'event_hover_color',
						[
							'label' 	=> esc_html__( 'Hover Text Colors', 'elementor-sonaar' ),
							'type' 		=> Controls_Manager::COLOR,
							'default'	=> '',
							'selectors' => ['{{WRAPPER}} .concerts-list .event:hover .sr_it-event-main .sr_it-event-title,{{WRAPPER}} .concerts-list .event:hover .sr_it-event-main .sr_it-event-title,{{WRAPPER}} .concerts-list .event:hover .sr-it-date-day,{{WRAPPER}} .concerts-list .event:hover .sr-it-date-years,{{WRAPPER}} .concerts-list .event:hover .sr_it-event-info, {{WRAPPER}} .concerts-list a:hover .sr_it-event-main .sr_it-event-title,{{WRAPPER}} .concerts-list a:hover .sr_it-event-main .sr_it-event-title,{{WRAPPER}} .concerts-list a:hover .sr-it-date-day,{{WRAPPER}} .concerts-list a:hover .sr-it-date-years,{{WRAPPER}} .concerts-list a:hover .sr_it-event-info' => 'color:{{VALUE}};',
										],
						]
				);
				$this->add_control(
				'hr13',
					[
						'type' => \Elementor\Controls_Manager::DIVIDER,
						'style' => 'default',
					]
			);
				$this->add_control(
							'sr_event_border_radius',
							[
								'label' => esc_html__( 'Border Radius', 'sonaar-elementor' ),
								'type' => Controls_Manager::SLIDER,
								'range' => [
									'px' => [
										'max' => 100,
									],
								],
								'selectors' => [
									'{{WRAPPER}} .concerts-list a' => 'border-radius: {{SIZE}}px;',
								],
							]
				);
				$this->add_responsive_control(
					'sr_event_padding',
					[
						'label' => esc_html__( 'Padding', 'sonaar-elementor' ),
						'type' => Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', 'em', '%' ],
						'selectors' => [
			 					'{{WRAPPER}} .concerts-list a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			 			],
					]
				);
				$this->add_responsive_control(
					'sr_event_margin',
					[
						'label' => esc_html__( 'Margin', 'sonaar-elementor' ),
						'type' => Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', 'em', '%' ],
						'selectors' => [
			 					'{{WRAPPER}} .concerts-list a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			 			],
					]
				);

		$this->end_controls_section();

		$this->start_controls_section(
        'event_btn',
            [
                'label' => __( 'Buttons Style', 'sonaar-elementor' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );		
				/**
			  		 * Subscribe Button Style
			  		 */
				$this->add_group_control(
					Group_Control_Typography::get_type(),
						[
							'name' => 'buttons_typography',
							'label' => __( 'Buttons Typography', 'elementor-sonaar' ),
							'scheme' => Typography::TYPOGRAPHY_1,
							'selector' => '{{WRAPPER}} .sr_it-event-buttons a',
						]
				);
				$this->add_control(
				'hr6',
					[
						'type' => \Elementor\Controls_Manager::DIVIDER,
						'style' => 'default',
					]
				);
				$this->start_controls_tabs( 'sr_event_btn_tabs' );

					// Normal State Tab
					$this->start_controls_tab( 'sr_event_btn_normal', [ 'label' => esc_html__( 'Normal', 'sonaar-elementor' ) ] );

						$this->add_control(
							'sr_event_btn_normal_text_color',
							[
								'label' => esc_html__( 'Text Color', 'sonaar-elementor' ),
								'type' => Controls_Manager::COLOR,
								'default' => '',
								'selectors' => [
									'{{WRAPPER}} .sr_it-event-buttons a' => 'color: {{VALUE}};',
								],
							]
						);

						$this->add_control(
							'sr_event_btn_normal_bg_color',
							[
								'label' => esc_html__( 'Background Color', 'sonaar-elementor' ),
								'type' => Controls_Manager::COLOR,
								'default' => '',
								'selectors' => [
									'{{WRAPPER}} .sr_it-event-buttons .button' => 'background: {{VALUE}};',
								],
							]
						);

						$this->add_group_control(
							Group_Control_Border::get_type(),
							[
								'name' => 'sr_event_btn_normal_border',
								'label' => esc_html__( 'Border', 'sonaar-elementor' ),
								'selector' => '{{WRAPPER}} .sr_it-event-buttons .button',
							]
						);

						$this->add_group_control(
							Group_Control_Box_Shadow::get_type(),
							[
								'name' => 'sr_event_btn_shadow',
								'selector' => '{{WRAPPER}} .sr_it-event-buttons .button',
								'separator' => 'before'
							]
						);
					$this->end_controls_tab();

					// Hover State Tab
					$this->start_controls_tab( 'sr_event_btn_hover', [ 'label' => esc_html__( 'Hover', 'sonaar-elementor' ) ] );

						$this->add_control(
							'sr_event_btn_hover_text_color',
							[
								'label' => esc_html__( 'Text Color', 'sonaar-elementor' ),
								'type' => Controls_Manager::COLOR,
								'default' => '#fff',
								'selectors' => [
									'{{WRAPPER}} .sr_it-event-buttons .button:hover' => 'color: {{VALUE}};',
								],
							]
						);

						$this->add_control(
							'sr_event_btn_hover_bg_color',
							[
								'label' => esc_html__( 'Background Color', 'sonaar-elementor' ),
								'type' => Controls_Manager::COLOR,
								'default' => '#27bdbd',
								'selectors' => [
									'{{WRAPPER}} .sr_it-event-buttons .button:hover' => 'background: {{VALUE}};',
								],
							]
						);

						$this->add_control(
							'sr_event_btn_hover_border_color',
							[
								'label' => esc_html__( 'Border Color', 'sonaar-elementor' ),
								'type' => Controls_Manager::COLOR,
								'default' => '',
								'selectors' => [
									'{{WRAPPER}} .sr_it-event-buttons  .button:hover' => 'border-color: {{VALUE}};',
								],
							]

						);
						$this->add_group_control(
							Group_Control_Box_Shadow::get_type(),
							[
								'name' => 'sr_event_btn_hover_shadow',
								'selector' => '{{WRAPPER}} .sr_it-event-buttons .button:hover',
								'separator' => 'before'
							]
						);
					$this->end_controls_tab();

				$this->end_controls_tabs();
				$this->add_control(
				'hr7',
					[
						'type' => \Elementor\Controls_Manager::DIVIDER,
						'style' => 'default',
					]
				);

				$this->add_control(
							'sr_event_btn_border_radius',
							[
								'label' => esc_html__( 'Border Radius', 'sonaar-elementor' ),
								'type' => Controls_Manager::SLIDER,
								'range' => [
									'px' => [
										'max' => 100,
									],
								],
								'selectors' => [
									'{{WRAPPER}} .sr_it-event-buttons .button' => 'border-radius: {{SIZE}}px;',
								],
							]
				);

				$this->add_responsive_control(
		  			'sr_event_btn_width',
		  			[
		  				'label' => esc_html__( 'Button Max Width', 'sonaar-elementor' ),
		  				'type' => Controls_Manager::SLIDER,
						'size_units' => [ 'px', 'em', '%' ],
						'range' => [
							'px' => [
								'min' => 0,
								'max' => 1500,
							],
							'em' => [
								'min' => 0,
								'max' => 80,
							],
						],
						'selectors' => [
							'{{WRAPPER}} .sr_it-event-buttons .button' => 'max-width: {{SIZE}}{{UNIT}};',
						],
		  			]
		  		);
				$this->add_responsive_control(
					'sr_event_btn_padding',
					[
						'label' => esc_html__( 'Padding', 'sonaar-elementor' ),
						'type' => Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', 'em', '%' ],
						'selectors' => [
			 					'{{WRAPPER}} .sr_it-event-buttons .button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			 			],
					]
				);

				$this->add_responsive_control(
					'sr_event_btn_margin',
					[
						'label' => esc_html__( 'Margin', 'sonaar-elementor' ),
						'type' => Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', 'em', '%' ],
						'selectors' => [
			 					'{{WRAPPER}} .sr_it-event-buttons .button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			 			],
					]
				);

		$this->end_controls_section();	

	}

	protected function render() {
		$settings = $this->get_settings();
		$display_artist_ar = $settings['event_display_events_for'];
		if(is_array($display_artist_ar)){
			$display_artist_ar = implode(", ", $display_artist_ar); 
		}
		echo do_shortcode( '[iron_events number="' . $settings['event_number_to_show'] . '"  titletag="'. $settings['sr_event_title_tag'] .'" filter="' . $settings['event_displayer_by_list'] . '" enable_artists_filter="' . $settings['event_enable_artist_filter'] . '" artists_filter="' . $display_artist_ar . '" hide_time="' . $settings['hide_time'] . '" hide_venue="' . $settings['hide_venue'] . '" hide_city="' . $settings['hide_city'] . '"  hide_artist="' . $settings['hide_artist'] . '"]' );
	}
	public function render_plain_content() {
		$settings = $this->get_settings();
		$display_artist_ar = $settings['event_display_events_for'];
		if(is_array($display_artist_ar)){
			$display_artist_ar = implode(", ", $display_artist_ar); 
		}
		echo do_shortcode( '[iron_events number="' . $settings['event_number_to_show'] . '"  titletag="'. $settings['sr_event_title_tag'] .'" filter="' . $settings['event_displayer_by_list'] . '" enable_artists_filter="' . $settings['event_enable_artist_filter'] . '" artists_filter="' . $display_artist_ar . '" hide_time="' . $settings['hide_time'] . '" hide_venue="' . $settings['hide_venue'] . '" hide_city="' . $settings['hide_city'] . '"  hide_artist="' . $settings['hide_artist'] . '"]' );
	}
	

}
Plugin::instance()->widgets_manager->register( new SR_Events() );