<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Base;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Iron_sonaar;

class SR_Mailchimp extends Widget_Base {

	public function get_name() {
		return 'sonaar-mailchimp';
	}

	public function get_title() {
		return esc_html__( 'Mailchimp', 'sonaar-elementor' );
	}

	public function get_icon() {
		return 'fas fa-envelope-open sonaar-badge';
	}
	public function get_help_url() {
		return 'https://support.sonaar.io';
	}
   public function get_categories() {
		return [ 'elementor-sonaar' ];
	}
	public function get_keywords() {
		return [ 'newsletter', 'mail', 'sonaar'];
	}
	protected function register_controls() {

  		/**
  		 * Mailchimp API Settings
  		 */
  		$this->start_controls_section(
  			'sr_section_mailchimp_api_settings',
  			[
  				'label' => esc_html__( 'Mailchimp Account Settings', 'sonaar-elementor' )
  			]
  		);

		$this->add_control(
		  	'sonaar_mailchimp_lists',
		  	[
		   		'label'       	=> esc_html__( 'Mailchimp List', 'sonaar-elementor' ),
		     	'type' 			=> Controls_Manager::SELECT,
		     	'label_block' 	=> false,
		     	'description' 	=> '<a href="./admin.php?page=iron_options&tab=12" target="_blank">Click here</a> to set your MailChimp API Key from <strong>Theme Settings &gt; Mailchimp API</strong>',
		     	'options' 		=> sonaar_mailchimp_lists(),
		  	]
		);
  		$this->end_controls_section();
  		/**
  		 * Mailchimp Fields Settings
  		 */
  		$this->start_controls_section(
  			'sr_section_mailchimp_field_settings',
  			[
  				'label' => esc_html__( 'Field Settings', 'sonaar-elementor' )
  			]
  		);
  		$this->add_control(
			'sr_mailchimp_email_label_text',
			[
				'label' => esc_html__( 'Email Label', 'sonaar-elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => false,
				'default' => 'Email',
			]
		);
  		$this->add_control(
			'sr_mailchimp_fname_show',
			[
				'label' => esc_html__( 'Enable First Name', 'sonaar-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'return_value' => 'yes',
			]
		);
		$this->add_control(
			'sr_mailchimp_fname_label_text',
			[
				'label' => esc_html__( 'First Name Label', 'sonaar-elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => false,
				'default' => 'First Name',
				'condition' => [
					'sr_mailchimp_fname_show' => 'yes'
				]
			]
		);
		$this->add_control(
			'sr_mailchimp_lname_show',
			[
				'label' => esc_html__( 'Enable Last Name', 'sonaar-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => 'yes',
				'return_value' => 'yes',
			]
		);
		$this->add_control(
			'sr_mailchimp_lname_label_text',
			[
				'label' => esc_html__( 'Last Name Label', 'sonaar-elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => false,
				'default' => 'Last Name',
				'condition' => [
					'sr_mailchimp_lname_show' => 'yes'
				]
			]
		);
  		$this->end_controls_section();

  		/**
  		 * Mailchimp Button Settings
  		 */
  		$this->start_controls_section(
  			'sr_section_mailchimp_button_settings',
  			[
  				'label' => esc_html__( 'Button Settings', 'sonaar-elementor' )
  			]
  		);
  		$this->add_control(
			'sr_section_mailchimp_button_text',
			[
				'label' => esc_html__( 'Button Text', 'sonaar-elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => false,
				'default' => esc_html__( 'Subscribe', 'sonaar-elementor' ),
			]
		);
		$this->add_control(
			'sr_section_mailchimp_loading_text',
			[
				'label' => esc_html__( 'Loading Text', 'sonaar-elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => false,
				'default' => esc_html__( 'Submitting...', 'sonaar-elementor' ),
			]
		);
  		$this->end_controls_section();

  		/**
  		 * Mailchimp Message Settings
  		 */
  		$this->start_controls_section(
  			'sr_section_mailchimp_message_settings',
  			[
  				'label' => esc_html__( 'Message Settings', 'sonaar-elementor' )
  			]
  		);
  		$this->add_control(
			'sr_section_mailchimp_success_text',
			[
				'label' => esc_html__( 'Success Text', 'sonaar-elementor' ),
				'type' => Controls_Manager::TEXT,
				'label_block' => true,
				'default' => esc_html__( 'You have subscribed successfully!', 'sonaar-elementor' ),
			]
		);
  		$this->end_controls_section();
  		/**
		 * -------------------------------------------
		 * Tab Style Mailchimp Style
		 * -------------------------------------------
		 */
		$this->start_controls_section(
			'sr_section_mailchimp_style_settings',
			[
				'label' => esc_html__( 'General Style', 'sonaar-elementor' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
            'sr_mailchimp_layout',
            [
                'label' => __( 'Layout', 'sonaar-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'inline' => 'Inline',
                    'stacked' => 'Stacked'
                ],
                'default' => 'stacked',

            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name'                  => 'sr_mailchimp_box_bg',
                'label'                 => __( 'Background', 'sonaar-elementor' ),
                'types'                 => [ 'none','classic','gradient' ],
                'selector'              => '{{WRAPPER}} .sr-mailchimp-wrap',
            ]
        );
		$this->add_responsive_control(
			'sr_mailchimp_padding',
			[
				'label' => esc_html__( 'Padding', 'sonaar-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
	 					'{{WRAPPER}} .sr-mailchimp-wrap' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	 			],
			]
		);
		$this->add_responsive_control(
			'sr_mailchimp_margin',
			[
				'label' => esc_html__( 'Margin', 'sonaar-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
	 					'{{WRAPPER}} .sr-mailchimp-wrap' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	 			],
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'sr_mailchimp_border',
				'label' => esc_html__( 'Border', 'sonaar-elementor' ),
				'selector' => '{{WRAPPER}} .sr-mailchimp-wrap',
			]
		);
		$this->add_responsive_control(
			'sr_mailchimp_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'sonaar-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
	 					'{{WRAPPER}} .sr-mailchimp-wrap' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	 			],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'sr_mailchimp_box_shadow',
				'selector' => '{{WRAPPER}} .sr-mailchimp-wrap',
			]
		);
  		$this->end_controls_section();

  		/**
  		 * Tab Style: Form Fields Style
  		 */
  		$this->start_controls_section(
			'sr_section_contact_form_field_styles',
			[
				'label' => esc_html__( 'Form Fields Styles', 'sonaar-elementor' ),
				'tab' => Controls_Manager::TAB_STYLE
			]
		);
		$this->add_control(
			'sr_mailchimp_input_background',
			[
				'label' => esc_html__( 'Input Field Background', 'sonaar-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sr-mailchimp-input' => 'background: {{VALUE}};',
				],
			]
		);
		$this->add_responsive_control(
  			'sr_mailchimp_input_width',
  			[
  				'label' => esc_html__( 'Input Width', 'sonaar-elementor' ),
  				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', 'em', '%' ],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 1500,
					],
					'em' => [
						'min' => 1,
						'max' => 80,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sr-field-group' => 'width: {{SIZE}}{{UNIT}};',
				],
  			]
  		);
  		$this->add_responsive_control(
  			'sr_mailchimp_input_height',
  			[
  				'label' => esc_html__( 'Input Height', 'sonaar-elementor' ),
  				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', 'em', '%' ],
				'range' => [
					'px' => [
						'min' => 30,
						'max' => 1500,
					],
					'em' => [
						'min' => 1,
						'max' => 80,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sr-mailchimp-input' => 'height: {{SIZE}}{{UNIT}};',
				],
  			]
  		);
  		$this->add_responsive_control(
			'sr_mailchimp_input_padding',
			[
				'label' => esc_html__( 'Fields Padding', 'sonaar-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sr-mailchimp-input' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
  		$this->add_responsive_control(
			'sr_mailchimp_input_margin',
			[
				'label' => esc_html__( 'Fields Margin', 'sonaar-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sr-field-group' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'sr_mailchimp_input_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'sonaar-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'separator' => 'before',
				'size_units' => [ 'px' ],
				'selectors' => [
					'{{WRAPPER}} .sr-mailchimp-input' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'sr_mailchimp_input_border',
				'selector' => '{{WRAPPER}} .sr-mailchimp-input',
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'sr_mailchimp_input_box_shadow',
				'selector' => '{{WRAPPER}} .sr-mailchimp-input',
			]
		);
  		$this->end_controls_section();

  		/**
  		 * Tab Style: Form Field Color & Typography
  		 */
  		$this->start_controls_section(
			'sr_section_mailchimp_typography',
			[
				'label' => esc_html__( 'Color & Typography', 'sonaar-elementor' ),
				'tab' => Controls_Manager::TAB_STYLE
			]
		);
		$this->add_control(
			'sr_mailchimp_label_color',
			[
				'label' => esc_html__( 'Label Color', 'sonaar-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sr-mailchimp-wrap label' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'sr_mailchimp_field_color',
			[
				'label' => esc_html__( 'Field Font Color', 'sonaar-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sr-mailchimp-input' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'sr_mailchimp_field_placeholder_color',
			[
				'label' => esc_html__( 'Placeholder Font Color', 'sonaar-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sr-mailchimp-wrap ::-webkit-input-placeholder' => 'color: {{VALUE}};',
					'{{WRAPPER}} .sr-mailchimp-wrap ::-moz-placeholder' => 'color: {{VALUE}};',
					'{{WRAPPER}} .sr-mailchimp-wrap ::-ms-input-placeholder' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'sr_mailchimp_label_heading',
			[
				'type' => Controls_Manager::HEADING,
				'label' => esc_html__( 'Label Typography', 'sonaar-elementor' ),
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sr_mailchimp_label_typography',
				'selector' => '{{WRAPPER}} .sr-mailchimp-wrap label',
			]
		);
		$this->add_control(
			'sr_mailchimp_heading_input_field',
			[
				'type' => Controls_Manager::HEADING,
				'label' => esc_html__( 'Input Fields Typography', 'sonaar-elementor' ),
				'separator' => 'before',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sr_mailchimp_input_field_typography',
				'selector' => '{{WRAPPER}} .sr-mailchimp-input',
			]
		);
  		$this->end_controls_section();

  		/**
  		 * Subscribe Button Style
  		 */
  		$this->start_controls_section(
            'sr_section_subscribe_btn',
            [
                'label' => __( 'Subscribe Button Style', 'sonaar-elementor' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
            'sr_mailchimp_subscribe_btn_display',
            [
                'label' => __( 'Button Display', 'sonaar-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'inline' => 'Inline',
                    'block' => 'Block'
                ],
                'default' => 'inline',

            ]
        );
		$this->add_responsive_control(
  			'sr_mailchimp_subscribe_btn_width',
  			[
  				'label' => esc_html__( 'Button Max Width', 'sonaar-elementor' ),
  				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', 'em', '%' ],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1500,
					],
					'em' => [
						'min' => 0,
						'max' => 80,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sr-mailchimp-submit-btn' => 'max-width: {{SIZE}}{{UNIT}};',
				],
  			]
  		);
		$this->add_responsive_control(
			'sr_mailchimp_subscribe_btn_padding',
			[
				'label' => esc_html__( 'Padding', 'sonaar-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
	 					'{{WRAPPER}} .sr-mailchimp-subscribe' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	 			],
			]
		);

		$this->add_responsive_control(
			'sr_mailchimp_subscribe_btn_margin',
			[
				'label' => esc_html__( 'Margin', 'sonaar-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
	 					'{{WRAPPER}} .sr-mailchimp-subscribe' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	 			],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
	         'name' => 'sr_mailchimp_subscribe_btn_typography',
				'selector' => '{{WRAPPER}} .sr-mailchimp-subscribe',
			]
		);

		$this->start_controls_tabs( 'sr_mailchimp_subscribe_btn_tabs' );

			// Normal State Tab
			$this->start_controls_tab( 'sr_mailchimp_subscribe_btn_normal', [ 'label' => esc_html__( 'Normal', 'sonaar-elementor' ) ] );

			$this->add_control(
				'sr_mailchimp_subscribe_btn_normal_text_color',
				[
					'label' => esc_html__( 'Text Color', 'sonaar-elementor' ),
					'type' => Controls_Manager::COLOR,
					'default' => '#fff',
					'selectors' => [
						'{{WRAPPER}} .sr-mailchimp-subscribe' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'sr_mailchimp_subscribe_btn_normal_bg_color',
				[
					'label' => esc_html__( 'Background Color', 'sonaar-elementor' ),
					'type' => Controls_Manager::COLOR,
					'default' => '#29d8d8',
					'selectors' => [
						'{{WRAPPER}} .sr-mailchimp-subscribe' => 'background: {{VALUE}};',
					],
				]
			);

			$this->add_group_control(
				Group_Control_Border::get_type(),
				[
					'name' => 'sr_mailchimp_subscribe_btn_normal_border',
					'label' => esc_html__( 'Border', 'sonaar-elementor' ),
					'selector' => '{{WRAPPER}} .sr-mailchimp-subscribe',
				]
			);

			$this->add_control(
				'sr_mailchimp_subscribe_btn_border_radius',
				[
					'label' => esc_html__( 'Border Radius', 'sonaar-elementor' ),
					'type' => Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .sr-mailchimp-subscribe' => 'border-radius: {{SIZE}}px;',
					],
				]
			);
			$this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'sr_mailchimp_subscribe_btn_shadow',
					'selector' => '{{WRAPPER}} .sr-mailchimp-subscribe',
					'separator' => 'before'
				]
			);
			$this->end_controls_tab();

			// Hover State Tab
			$this->start_controls_tab( 'sr_mailchimp_subscribe_btn_hover', [ 'label' => esc_html__( 'Hover', 'sonaar-elementor' ) ] );

			$this->add_control(
				'sr_mailchimp_subscribe_btn_hover_text_color',
				[
					'label' => esc_html__( 'Text Color', 'sonaar-elementor' ),
					'type' => Controls_Manager::COLOR,
					'default' => '#fff',
					'selectors' => [
						'{{WRAPPER}} .sr-mailchimp-subscribe:hover' => 'color: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'sr_mailchimp_subscribe_btn_hover_bg_color',
				[
					'label' => esc_html__( 'Background Color', 'sonaar-elementor' ),
					'type' => Controls_Manager::COLOR,
					'default' => '#27bdbd',
					'selectors' => [
						'{{WRAPPER}} .sr-mailchimp-subscribe:hover' => 'background: {{VALUE}};',
					],
				]
			);

			$this->add_control(
				'sr_mailchimp_subscribe_btn_hover_border_color',
				[
					'label' => esc_html__( 'Border Color', 'sonaar-elementor' ),
					'type' => Controls_Manager::COLOR,
					'default' => '',
					'selectors' => [
						'{{WRAPPER}} .sr-mailchimp-subscribe:hover' => 'border-color: {{VALUE}};',
					],
				]

			);
			$this->add_group_control(
				Group_Control_Box_Shadow::get_type(),
				[
					'name' => 'sr_mailchimp_subscribe_btn_hover_shadow',
					'selector' => '{{WRAPPER}} .sr-mailchimp-subscribe:hover',
					'separator' => 'before'
				]
			);
			$this->end_controls_tab();

		$this->end_controls_tabs();
		$this->end_controls_section();

  		/**
  		 * Subscribe Button Style
  		 */
  		$this->start_controls_section(
            'sr_section_success_message',
            [
                'label' => __( 'Message Style', 'sonaar-elementor' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'sr_mailchimp_message_background',
			[
				'label' => esc_html__( 'Background', 'sonaar-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sr-mailchimp-message' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'sr_mailchimp_message_color',
			[
				'label' => esc_html__( 'Font Color', 'sonaar-elementor' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sr-mailchimp-message' => 'color: {{VALUE}};',
				],
			]
		);
		$this->add_responsive_control(
			'sr_mailchimp_message_alignment',
			[
				'label' => esc_html__( 'Text Alignment', 'sonaar-elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'label_block' => true,
				'options' => [
					'default' => [
						'title' => __( 'Default', 'sonaar-elementor' ),
						'icon' => 'fa fa-ban',
					],
					'left' => [
						'title' => esc_html__( 'Left', 'sonaar-elementor' ),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'sonaar-elementor' ),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'sonaar-elementor' ),
						'icon' => 'fa fa-align-right',
					],
				],
				'default' => 'default',
				'prefix_class' => 'sr-mailchimp-message-text-',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'sr_mailchimp_message_typography',
				'selector' => '{{WRAPPER}} .sr-mailchimp-message',
			]
		);
		$this->add_responsive_control(
			'sr_mailchimp_message_padding',
			[
				'label' => esc_html__( 'Padding', 'sonaar-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
	 					'{{WRAPPER}} .sr-mailchimp-message' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	 			],
			]
		);
		$this->add_responsive_control(
			'sr_mailchimp_message_margin',
			[
				'label' => esc_html__( 'Margin', 'sonaar-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
	 					'{{WRAPPER}} .sr-mailchimp-message' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	 			],
			]
		);
		$this->add_responsive_control(
			'sr_mailchimp_message_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'sonaar-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
	 					'{{WRAPPER}} .sr-mailchimp-message' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
	 			],
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'sr_mailchimp_message_border',
				'label' => esc_html__( 'Border', 'sonaar-elementor' ),
				'selector' => '{{WRAPPER}} .sr-mailchimp-message',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'sr_mailchimp_message_box_shadow',
				'selector' => '{{WRAPPER}} .sr-mailchimp-message',
			]
		);
		$this->end_controls_section();
	}

	protected function render() {

		$settings = $this->get_settings();
   		$api_key = Iron_sonaar::getOption('sr_mailchimp_api');
   		//$api_key = getOption('sr_mailchimp_api');
   		//var_dump($api_key);
   		//die();

		// Layout Class
		if( 'stacked' === $settings['sr_mailchimp_layout'] ) {
			$layout = 'sr-mailchimp-stacked';
		} elseif( 'inline' === $settings['sr_mailchimp_layout'] ) {
			$layout = 'sr-mailchimp-inline';
		}		
		// Button Display Class
		if( 'block' === $settings['sr_mailchimp_subscribe_btn_display'] ) {
			$subscribe_btn_display = 'sr-mailchimp-btn-block';
		} elseif( 'inline' === $settings['sr_mailchimp_subscribe_btn_display'] ) {
			$subscribe_btn_display = 'sr-mailchimp-btn-inline';
		}
		   
		$this->add_render_attribute( 'sr-mailchimp-main-wrapper', 'class', 'sr-mailchimp-wrap' );
		$this->add_render_attribute( 'sr-mailchimp-main-wrapper', 'class', esc_attr($layout) );
		$this->add_render_attribute( 'sr-mailchimp-main-wrapper', 'data-mailchimp-id', esc_attr( $this->get_id() ) );
		$this->add_render_attribute( 'sr-mailchimp-main-wrapper', 'data-api-key',  esc_attr( $api_key) );
		$this->add_render_attribute( 'sr-mailchimp-main-wrapper', 'data-list-id', $settings['sonaar_mailchimp_lists'] );
		$this->add_render_attribute( 'sr-mailchimp-main-wrapper', 'data-button-text', $settings['sr_section_mailchimp_button_text'] );
		$this->add_render_attribute( 'sr-mailchimp-main-wrapper', 'data-success-text', $settings['sr_section_mailchimp_success_text']);
		$this->add_render_attribute( 'sr-mailchimp-main-wrapper', 'data-loading-text', $settings['sr_section_mailchimp_loading_text']);
   		
	?>
	<?php if( !empty( $api_key ) ) : ?>
	<div   <?php echo $this->get_render_attribute_string( 'sr-mailchimp-main-wrapper' ); ?> >
		<form action="#" id="sr-mailchimp-form-<?php echo esc_attr( $this->get_id() ); ?>">
			<div class="sr-form-fields-wrapper sr-mailchimp-fields-wrapper <?php echo esc_attr($subscribe_btn_display); ?>">
				<div class="sr-field-group sr-mailchimp-email">
					<label for="<?php echo esc_attr($settings['sr_mailchimp_email_label_text'], 'sonaar-elementor'); ?>"><?php echo esc_html__($settings['sr_mailchimp_email_label_text'], 'sonaar-elementor'); ?></label>
					<input type="email" name="sr_mailchimp_email" class="sr-mailchimp-input" placeholder="Email" required="required">
				</div>
				<div class="sr-field-group sr-mailchimp-fname" <?php echo ( !'yes' == $settings['sr_mailchimp_fname_show'] )?'style="display:none;"':''; ?>>
					<label for="<?php echo esc_attr($settings['sr_mailchimp_fname_label_text'], 'sonaar-elementor'); ?>"><?php echo esc_html__($settings['sr_mailchimp_fname_label_text'], 'sonaar-elementor'); ?></label>
					<input type="text" name="sr_mailchimp_firstname" class="sr-mailchimp-input" placeholder="First Name">
				</div>
				<div class="sr-field-group sr-mailchimp-lname" <?php echo ( !'yes' == $settings['sr_mailchimp_lname_show'] )?'style="display:none;"':''; ?>>
					<label for="<?php echo esc_attr($settings['sr_mailchimp_lname_label_text'], 'sonaar-elementor'); ?>"><?php echo esc_html__($settings['sr_mailchimp_lname_label_text'], 'sonaar-elementor'); ?></label>
					<input type="text" name="sr_mailchimp_lastname" class="sr-mailchimp-input" placeholder="Last Name">
				</div>
				<div class="sr-field-group sr-mailchimp-submit-btn">
					<button id="sr-subscribe-<?php echo esc_attr( $this->get_id() ); ?>" class="sr-load-more-button sr-mailchimp-subscribe">
						<div class="sr-btn-loader button__loader"></div>
				  		<span><?php echo esc_html__( $settings['sr_section_mailchimp_button_text'], 'sonaar-elementor' ); ?></span>
					</button>
				</div>
			</div>
		</form>
	</div>
	<?php else: ?>
		<p class="sr-mailchimp-error">Please insert your api key</p>
	<?php endif; ?>

	<?php
	}

	protected function content_template() {}
}


Plugin::instance()->widgets_manager->register( new SR_Mailchimp() );