<?php
namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Core\Responsive\Responsive;
//use Elementor\Group_Control_Base;
//use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
//use Elementor\Core\Kits\Documents\Tabs\Global_Typography;



/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */

class SR_E_Menu extends Widget_Base {
	protected $nav_menu_index = 1;
	public function get_name() {
		return 'sr-e-menu';
	}
	public function get_title() {
		return __( 'Nav Menu', 'elementor-sonaar' );
	}
	public function get_icon() {
		return 'eicon-banner sonaar-badge';
	}
	public function get_help_url() {
		return 'https://support.sonaar.io';
	}
	public function get_keywords() {
		return [ 'menu', 'nav', 'sonaar', 'sonar', 'sonnar', 'header'];
	}
	public function get_categories() {
		return [ 'elementor-sonaar' ];
	}
	protected function get_nav_menu_index() {
		return $this->nav_menu_index++;
	}
	public function get_script_depends() {
		return [ 'elementor-sonaar' ];
	}

	private function get_available_menus() {
		$menus = wp_get_nav_menus();

		$options = [];

		foreach ( $menus as $menu ) {
			$options[ $menu->slug ] = $menu->name;
		}

		return $options;
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Nav Menu Settings', 'elementor-sonaar' ),
			]
		);

		$menus = $this->get_available_menus();

		if ( ! empty( $menus ) ) {
			$this->add_control(
				'sr_menu',
				[
					'label' => __( 'Menu', 'elementor-sonaar' ),
					'type' => Controls_Manager::SELECT,
					'options' => $menus,
					'default' => array_keys( $menus )[0],
					'save_default' => true,
					'separator' => 'after',
					'description' => sprintf( __( 'Go to the <a href="%s" target="_blank">Menus screen</a> to manage your menus.', 'elementor-sonaar' ), admin_url( 'nav-menus.php' ) ),
				]
			);
		} else {
			$this->add_control(
				'sr_menu',
				[
					'type' => Controls_Manager::RAW_HTML,
					'raw' => '<strong>' . __( 'There are no menus in your site.', 'elementor-sonaar' ) . '</strong><br>' . sprintf( __( 'Go to the <a href="%s" target="_blank">Menus screen</a> to create one.', 'elementor-sonaar' ), admin_url( 'nav-menus.php?action=edit&menu=0' ) ),
					'separator' => 'after',
					'content_classes' => 'elementor-panel-alert elementor-panel-alert-info',
				]
			);
		}
		$this->add_control(
			'layout',
			[
				'label' => __( 'Layout', 'elementor-sonaar' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'horizontal',
				'options' => [
					'horizontal' => __( 'Horizontal', 'elementor-sonaar' ),
					'vertical' => __( 'Vertical', 'elementor-sonaar' ),
				],
				'frontend_available' => true,
			]
		);
		$this->add_responsive_control(
			'align_items',
			[
				'label' => __( 'Align', 'elementor-sonaar' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'elementor-sonaar' ),
						'icon' => 'eicon-h-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'elementor-sonaar' ),
						'icon' => 'eicon-h-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'elementor-sonaar' ),
						'icon' => 'eicon-h-align-right',
					],
					'justify' => [
						'title' => __( 'Stretch', 'elementor-sonaar' ),
						'icon' => 'eicon-h-align-stretch',
					],
				],
				'selectors_dictionary' => [
					'left' => 'text-align:left;',
					'center' => 'text-align:center',
					'right' => 'text-align:right',
				],
				'selectors' => [
					'{{WRAPPER}} .sr-menu--vertical .menu-item a' => '{{VALUE}}',
				],
				'default' => 'left',
				'prefix_class' => 'sr-e-menu__align-',
				
			]
		);
		$this->add_control(
			'pointer',
			[
				'label' => __( 'Pointer', 'elementor-sonaar' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'none',
				'options' => [
					'none' => __( 'None', 'elementor-sonaar' ),
					'underline' => __( 'Underline', 'elementor-pro' ),
					'overline' => __( 'Overline', 'elementor-pro' ),
					'doubleline' => __( 'Double Line', 'elementor-pro' ),
				],
				'condition' => [
					'layout' => 'horizontal',
				],
			]
		);
		$this->add_control(
			'pointer_animation',
			[
				'label' => __( 'Pointer Animation', 'elementor-sonaar' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'fade',
				'options' => [
					'none' => __( 'None', 'elementor-sonaar' ),
					'slide' => __( 'Slide', 'elementor-pro' ),
					'fade' => __( 'Fade', 'elementor-pro' ),
					'move-in' => __( 'Move In', 'elementor-pro' ),
					'move-out' => __( 'Move Out', 'elementor-pro' ),
				],
				'condition' => [
					'pointer!' => 'none',
					'layout' => 'horizontal',
				],
			]
		);
		$this->add_control(
			'layout_animation',
			[
				'label' => __( 'Enable Animation', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'elementor-sonaar' ),
				'label_off' => __( 'No', 'elementor-sonaar' ),
				'return_value' => 'enable',
				'default' => 'enable',
				'prefix_class' => 'sr-e-menu--anim-',
				/*'condition' => [
					'layout' => 'vertical',
				],*/
			]
		);

		$breakpoints = Responsive::get_breakpoints();

		$this->add_control(
			'dropdown',
			[
				'label' => __( 'Breakpoint', 'elementor-sonaar' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'tablet',
				'separator' => 'before',
				'options' => [
					/* translators: %d: Breakpoint number. */
					'mobile' => sprintf( __( 'Mobile (< %dpx)', 'elementor-sonaar' ), $breakpoints['md'] ),
					/* translators: %d: Breakpoint number. */
					'tablet' => sprintf( __( 'Tablet (< %dpx)', 'elementor-sonaar' ), $breakpoints['lg'] ),
					'none' => __( 'None', 'elementor-sonaar' ),
				],
				'prefix_class' => 'sr-e-menu--dropdown-',
			]
		);
		$this->add_control(
			'toggle',
			[
				'label' => __( 'Toggle Button', 'elementor-sonaar' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'burger',
				'options' => [
					'' => __( 'None', 'elementor-sonaar' ),
					'burger' => __( 'Hamburger', 'elementor-sonaar' ),
				],
				'prefix_class' => 'sr-e-menu--toggle sr-e-menu-toggle--',
				'render_type' => 'template',
				'frontend_available' => true,
				'condition' => [
					'dropdown!' => 'none',
				],
			]
		);

		$this->add_control(
			'toggle_align',
			[
				'label' => __( 'Toggle Align', 'elementor-sonaar' ),
				'type' => Controls_Manager::CHOOSE,
				'default' => 'center',
				'options' => [
					'left' => [
						'title' => __( 'Left', 'elementor-sonaar' ),
						'icon' => 'eicon-h-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'elementor-sonaar' ),
						'icon' => 'eicon-h-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'elementor-sonaar' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'selectors_dictionary' => [
					'left' => 'margin-right: auto',
					'center' => 'margin: 0 auto',
					'right' => 'margin-left: auto',
				],
				'selectors' => [
					'{{WRAPPER}} .sr-e-menu-toggle' => '{{VALUE}}',
				],
				'condition' => [
					'toggle!' => '',
					'dropdown!' => 'none',
				],
			]
		);
		/*$this->add_control(
			'toggle_content_align',
			[
				'label' => __( 'Content Align', 'elementor-sonaar' ),
				'type' => Controls_Manager::CHOOSE,
				'default' => 'center',
				'options' => [
					'left' => [
						'title' => __( 'Left', 'elementor-sonaar' ),
						'icon' => 'eicon-h-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'elementor-sonaar' ),
						'icon' => 'eicon-h-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'elementor-sonaar' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'selectors_dictionary' => [
					'left' => 'text-align:left;',
					'center' => 'text-align:center',
					'right' => 'text-align:right',
				],
				'selectors' => [
					'{{WRAPPER}} .sr-e-mobile.sr-menu--vertical .menu-item a' => '{{VALUE}}',
				],
				'condition' => [
					//'toggle!' => '',
					'dropdown!' => 'none',
				],
			]
		);*/
		$this->add_control(
			'full_width',
			[
				'label' => __( 'Full Width', 'elementor-sonaar' ),
				'type' => Controls_Manager::SWITCHER,
				'description' => __( 'Stretch the dropdown of the menu to full width.', 'elementor-sonaar' ),
				'prefix_class' => 'sr-e-menu--',
				'return_value' => 'stretch',
				'frontend_available' => true,
				'condition' => [
					'dropdown!' => 'none',
				],
			]
		);
		$this->add_control(
			'merge_menu',
			[
				'label' => __( 'Merge Another Menu on Breakpoint', 'elementor-sonaar' ),
				'type' => Controls_Manager::SWITCHER,
				'return_value' => '1',
				'separator' => 'before',
				'frontend_available' => true,
				'condition' => [
					'dropdown!' => 'none',
				],
			]
		);
		if ( ! empty( $menus ) ) {
			$this->add_control(
				'sr_menu_second',
				[
					'label' => __( 'Menu to merge', 'elementor-sonaar' ),
					'type' => Controls_Manager::SELECT,
					'options' => $menus,
					'default' => array_keys( $menus )[0],
					'save_default' => true,
					'condition' => [
						'dropdown!' => 'none',
						'merge_menu!' => '',
					],
				]
			);
		} else {
			$this->add_control(
				'sr_menu_second',
				[
					'type' => Controls_Manager::RAW_HTML,
					'raw' => '<strong>' . __( 'There are no menus in your site.', 'elementor-sonaar' ) . '</strong><br>' . sprintf( __( 'Go to the <a href="%s" target="_blank">Menus screen</a> to create one.', 'elementor-sonaar' ), admin_url( 'nav-menus.php?action=edit&menu=0' ) ),
					'content_classes' => 'elementor-panel-alert elementor-panel-alert-info',
					'condition' => [
						'dropdown!' => 'none',
						'merge_menu!' => '',
					],
				]
			);
		}
		$this->add_control(
			'sr_menu_second_make_primary',
			[
				'label' => __( 'Make this menu to display first', 'elementor-sonaar' ),
				'type' => Controls_Manager::SWITCHER,
				'return_value' => '1',
				'frontend_available' => true,
				'condition' => [
						'dropdown!' => 'none',
						'merge_menu!' => '',
				],
			]
		);


		$this->end_controls_section();

		/**
         * STYLE: MENU
         * -------------------------------------------------
         */
			
		$this->start_controls_section(
            'item_style',
            [
                'label'                 => __( 'Main Menu', 'elementor-sonaar' ),
				'tab'                   => Controls_Manager::TAB_STYLE,
            ]
		);
		/*------------------*/
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'item_typography',
				'label' => __( 'Typography', 'elementor-sonaar' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .menu-item',
			]
		);

		/*------------------*/
		$this->start_controls_tabs( 'tabs_menu_item_style' );
			$this->start_controls_tab(
				'tab_menu_item_normal',
				[
					'label' => __( 'Normal', 'elementor-sonaar' ),
				]
			);
			$this->add_control(
				'item_color',
				[
					'label'                 => __( 'Text Color', 'elementor-sonaar' ),
					'type'                  => Controls_Manager::COLOR,
					'default'               => '',
					'selectors'             => [
						'{{WRAPPER}} .menu-item a' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_control(
				'item_bg_color',
				[
					'label'                 => __( 'Background Color', 'elementor-sonaar' ),
					'type'                  => Controls_Manager::COLOR,
					'default'               => '',
					'selectors'             => [
						'{{WRAPPER}} .menu-item a' => 'background-color: {{VALUE}}',
					],
				]
			);
		$this->end_controls_tab();
		/*------------------*/

		$this->start_controls_tab(
			'tab_menu_item_hover',
			[
				'label' => __( 'Hover', 'elementor-sonaar' ),
			]
		);
		$this->add_control(
			'item_color_hover',
			[
				'label' => __( 'Text Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'global' => [
					'default' => Global_Colors::COLOR_ACCENT,
				],
				'selectors' => [
					'{{WRAPPER}} .menu-item a:hover,
					{{WRAPPER}} .menu-item a:focus,
					{{WRAPPER}} .menu-item a:active' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'item_bg_color_hover',
			[
				'label'                 => __( 'Background Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .menu-item a:hover,
					{{WRAPPER}} .menu-item a:focus,
					{{WRAPPER}} .menu-item a:active' => 'background-color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'pointer_color_menu_item_hover',
			[
				'label' => __( 'Pointer Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'global' => [
					'default' => Global_Colors::COLOR_ACCENT,
				],
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .sr-pointer--underline a:after, 
					{{WRAPPER}} .sr-pointer--overline a:before,
					{{WRAPPER}} .sr-pointer--doubleline a:before, {{WRAPPER}} .sr-pointer--doubleline a:after' 
					=> 'background-color: {{VALUE}}',
				],
				'condition' => [
					'pointer!' => [ 'none' ],
					'layout' => 'horizontal',
				],
			]
		);
		$this->end_controls_tab();
		/*------------------*/

		$this->start_controls_tab(
			'tab_menu_item_active',
			[
				'label' => __( 'Active', 'elementor-sonaar' ),
			]
		);

		$this->add_control(
			'item_color_active',
			[
				'label' => __( 'Text Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .menu-item.active > a' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'item_bg_color_active',
			[
				'label'                 => __( 'Background Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .menu-item.active > a' => 'background-color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'pointer_color_menu_item_active',
			[
				'label' => __( 'Pointer Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'global' => [
					'default' => Global_Colors::COLOR_ACCENT,
				],
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .sr-pointer--underline .current-menu-item a:after, 
					{{WRAPPER}} .sr-pointer--overline .current-menu-item a:before,
					{{WRAPPER}} .sr-pointer--doubleline .current-menu-item a:before, {{WRAPPER}} .sr-pointer--doubleline .current-menu-item a:after' 
					=> 'background-color: {{VALUE}}',
				],
				'condition' => [
					'pointer!' => [ 'none' ],
					'layout' => 'horizontal',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();

		/*------------------*/
		$this->add_responsive_control(
			'pointer_width',
			[
				'label' => __( 'Pointer Width', 'elementor-sonaar' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 25,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sr-pointer--underline a:after, 
					{{WRAPPER}} .sr-pointer--overline a:before,
					{{WRAPPER}} .sr-pointer--doubleline a:before, {{WRAPPER}} .sr-pointer--doubleline a:after' 
					=> 'height: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'pointer!' => [ 'none' ],
					'layout' => 'horizontal',
				],
			]
		);
		$this->add_responsive_control(
			'padding_horizontal_menu_item',
			[
				'label' => __( 'Horizontal Padding', 'elementor-sonaar' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .menu-item a' => 'padding-left: {{SIZE}}{{UNIT}}; padding-right: {{SIZE}}{{UNIT}}',
				],
			]
		);
		$this->add_responsive_control(
			'padding_vertical_menu_item',
			[
				'label' => __( 'Vertical Padding', 'elementor-sonaar' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .menu-item a' => 'padding-top: {{SIZE}}{{UNIT}}; padding-bottom: {{SIZE}}{{UNIT}}',
				],
			]
		);

		$this->add_responsive_control(
			'item_spacing',
			[
				'label' => __( 'Space Between', 'elementor-sonaar' ) . ' (px)',
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 500,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sr-menu--horizontal ul:not(.sub-menu) > li:not(:last-child)' => 'margin-right: {{SIZE}}px!important;',
				],
				'condition' => [
					'layout' => 'horizontal',
				],
			]
		);

		$this->end_controls_section();


		/*---------------------------------*/
		/*---------------------------------*/
		// D R O P D O W N   S E C T I O N
		/*---------------------------------*/
		/*---------------------------------*/
		$this->start_controls_section(
			'section_style_dropdown',
			[
				'label' => __( 'Dropdown', 'elementor-sonaar' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'dropdown_description',
			[
				'raw' => __( 'On desktop, this will affect the submenu. On mobile, this will affect the entire menu.', 'elementor-sonaar' ),
				'type' => Controls_Manager::RAW_HTML,
				'content_classes' => 'elementor-descriptor',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'subitem_typography',
				'label' => __( 'Typography', 'elementor-sonaar' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .sub-menu .menu-item ',
			]
		);

		/*------------------*/
		$this->start_controls_tabs( 'tabs_menu_subitem_style' );
			$this->start_controls_tab(
				'tab_menu_subitem_normal',
				[
					'label' => __( 'Normal', 'elementor-sonaar' ),
				]
			);
			$this->add_control(
				'subitem_color',
				[
					'label'                 => __( 'Text Color', 'elementor-sonaar' ),
					'type'                  => Controls_Manager::COLOR,
					'default'               => '',
					'selectors'             => [
						'{{WRAPPER}} .sub-menu .menu-item a' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_control(
				'subitem_bg_color',
				[
					'label'                 => __( 'Background Color', 'elementor-sonaar' ),
					'type'                  => Controls_Manager::COLOR,
					'default'               => '',
					'selectors'             => [
						'{{WRAPPER}} .sub-menu .menu-item a' => 'background-color: {{VALUE}}',
					],
				]
			);
		$this->end_controls_tab();
		/*------------------*/

		$this->start_controls_tab(
			'tab_menu_subitem_hover',
			[
				'label' => __( 'Hover', 'elementor-sonaar' ),
			]
		);
		$this->add_control(
			'subitem_hover_color',
			[
				'label' => __( 'Text Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'global' => [
					'default' => Global_Colors::COLOR_ACCENT,
				],
				'selectors' => [
					'{{WRAPPER}} .sub-menu .menu-item:not(.active) a:hover,
					{{WRAPPER}} .sub-menu .menu-item:not(.active) a:focus' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'subitem_hover_bg_color',
			[
				'label'                 => __( 'Background Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .sub-menu .menu-item:not(.active) a:hover,
					{{WRAPPER}} .sub-menu .menu-item:not(.active) a:focus' => 'background-color: {{VALUE}}',
				],
			]
		);
		$this->end_controls_tab();
		/*------------------*/

		$this->start_controls_tab(
			'tab_menu_subitem_active',
			[
				'label' => __( 'Active', 'elementor-sonaar' ),
			]
		);

		$this->add_control(
			'subitem_active_color',
			[
				'label' => __( 'Text Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .sub-menu .menu-item.active > a' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'subitem_active_bg_color',
			[
				'label'                 => __( 'Background Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .sub-menu .menu-item.active > a' => 'background-color: {{VALUE}}',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();


		$this->add_responsive_control(
			'padding_horizontal_submenu_item',
			[
				'label' => __( 'Horizontal Padding', 'elementor-sonaar' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sub-menu .menu-item a' => 'padding-left: {{SIZE}}{{UNIT}}; padding-right: {{SIZE}}{{UNIT}}',
				],
			]
		);
		$this->add_responsive_control(
			'padding_vertical_submenu_item',
			[
				'label' => __( 'Vertical Padding', 'elementor-sonaar' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sub-menu .menu-item a' => 'padding-top: {{SIZE}}{{UNIT}}; padding-bottom: {{SIZE}}{{UNIT}}',
				],
			]
		);
		$this->add_responsive_control(
			'dropdown_top_distance',
			[
				'label' => __( 'Distance', 'elementor-sonaar' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sr-menu--horizontal > ul > li > .sub-menu' => 'padding-top: {{SIZE}}{{UNIT}} !important',
					/*'{{WRAPPER}} .elementor-nav-menu--main > .elementor-nav-menu > li > .elementor-nav-menu--dropdown, {{WRAPPER}} .elementor-nav-menu__container.elementor-nav-menu--dropdown' => 'margin-top: {{SIZE}}{{UNIT}} !important',*/
				],
				'separator' => 'before',
				'condition' => [
					'layout' => 'horizontal',
				],
			]
		);
		$this->add_responsive_control(
			'dropdown_container_margin',
			[
				'label' => __( 'Dropdown Block Margin', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sr-e-menu .sub-menu > li:first-of-type' => 'margin-top: {{TOP}}{{UNIT}};',
					'{{WRAPPER}} .sr-e-menu .sub-menu > li:last-of-type' => 'margin-bottom: {{BOTTOM}}{{UNIT}};',
					'{{WRAPPER}} .sr-e-menu .sub-menu' => 'margin-left: {{LEFT}}{{UNIT}}; margin-right:{{RIGHT}}{{UNIT}}',
					//'{{WRAPPER}} .sr-e-menu .sub-menu' => 'margin-right: {{RIGHT}}{{UNIT}};',
				],
				//'separator' => 'before',
			]
		);
		$this->end_controls_section();

		$this->start_controls_section( 'style_toggle',
			[
				'label' => __( 'Toggle Menu', 'elementor-sonaar' ),
				'tab' => Controls_Manager::TAB_STYLE,
				'condition' => [
					'toggle!' => '',
					'dropdown!' => 'none',
				],
			]
		);

		$this->start_controls_tabs( 'tabs_toggle_style' );

		$this->start_controls_tab(
			'tab_toggle_style_normal',
			[
				'label' => __( 'Normal', 'elementor-sonaar' ),
			]
		);

		$this->add_control(
			'toggle_color',
			[
				'label' => __( 'Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div.sr-e-menu-toggle' => 'color: {{VALUE}}', // Harder selector to override text color control
				],
			]
		);

		$this->add_control(
			'toggle_background_color',
			[
				'label' => __( 'Background Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sr-e-menu-toggle' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_toggle_style_hover',
			[
				'label' => __( 'Hover', 'elementor-sonaar' ),
			]
		);

		$this->add_control(
			'toggle_color_hover',
			[
				'label' => __( 'Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} div.sr-e-menu-toggle:hover' => 'color: {{VALUE}}', // Harder selector to override text color control
				],
			]
		);

		$this->add_control(
			'toggle_background_color_hover',
			[
				'label' => __( 'Background Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sr-e-menu-toggle:hover' => 'background-color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();
		$this->add_control(
			'dropdown_bg_color',
			[
				'label'                 => __( 'Menu Background Color ', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '#fff',
				'selectors'             => [
					'{{WRAPPER}} .sr-e-mobile.sr-menu--vertical' => 'background-color: {{VALUE}}',
				],
			]
		);
		$this->add_responsive_control(
			'toggle_size',
			[
				'label' => __( 'Toggle Size', 'elementor-sonaar' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 15,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sr-e-menu-toggle' => 'font-size: {{SIZE}}{{UNIT}}',
				],
				'separator' => 'before',
			]
		);

		$this->add_responsive_control(
			'toggle_border_width',
			[
				'label' => __( 'Toggle Border Width', 'elementor-sonaar' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 10,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sr-e-menu-toggle' => 'border-width: {{SIZE}}{{UNIT}}',
				],
			]
		);

		$this->add_responsive_control(
			'toggle_border_radius',
			[
				'label' => __( 'Toggle Border Radius', 'elementor-sonaar' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sr-e-menu-toggle' => 'border-radius: {{SIZE}}{{UNIT}}',
				],
			]
		);

		$this->end_controls_section();
	}

	protected function render() {
		$available_menus = $this->get_available_menus();

		if ( ! $available_menus ) {
			return;
		}

		$settings = $this->get_active_settings();
		
		$menu_args = [
			'echo' => false,
			//'menu' => $settings['sr_menu'],
			'menu_class' => 'sr-e-menu',
			'menu_id' => 'menu-' . $this->get_nav_menu_index() . '-' . $this->get_id(),
			//'fallback_cb' => '__return_empty_string',
			//'container' => '',
		];

		$args = [
			'echo' => false,
			'menu' => $settings['sr_menu'],
			'menu_class' => '',
			'menu_id' => 'menu-' . $this->get_nav_menu_index() . '-' . $this->get_id(),
			'fallback_cb' => '__return_empty_string',
			'container' => '',
		];

		$menu_html = wp_nav_menu( $args );

		// Dropdown Menu.
		$menu_args['menu_id'] = 'menu-' . $this->get_nav_menu_index() . '-' . $this->get_id();
		//$args['menu_class'] = 'sr-e-menu sr-menu--vertical';
		$isSameMenu = ( $settings['sr_menu_second'] == $settings['sr_menu'] ) ? true : false;

		if ( '' != $settings['sr_menu_second'] && '' != $settings['merge_menu'] && !$isSameMenu ) { // PREPARE THE MENU WRAP TO INCLUDE THE SECOND MENU
			$args['items_wrap'] = '%3$s';
		}
		$responsive_menu_html = wp_nav_menu( $args );

		if ( '' != $settings['sr_menu_second'] && '' != $settings['merge_menu'] && !$isSameMenu ) {
			$args['menu'] = $settings['sr_menu_second'];
			if( '' != $settings['sr_menu_second_make_primary'] ){
				$args['items_wrap'] = '<ul>%3$s ' . $responsive_menu_html . '</ul>';
			}else{
				$args['items_wrap'] = '<ul>' . $responsive_menu_html . '%3$s</ul>';
			}
	
			$responsive_menu_html = wp_nav_menu( $args );

		}

		if ( empty( $menu_html ) ) {
			return;
		}

		$this->add_render_attribute( 'menu-toggle', [
			'class' => 'sr-e-menu-toggle',
			'role' => 'button',
			'tabindex' => '0',
			'aria-label' => __( 'Menu Toggle', 'elementor-sonaar' ),
			'aria-expanded' => 'false',
		] );

		if ( \Elementor\Plugin::instance()->editor->is_edit_mode() ) {
			$this->add_render_attribute( 'menu-toggle', [
				'class' => 'elementor-clickable',
			] );
		}

		$this->add_render_attribute( 'main-menu', 'role', 'navigation' );

		if ( $settings['pointer'] ) :
			$this->add_render_attribute( 'main-menu', 'class', 'sr-pointer--' . $settings['pointer']);
			$this->add_render_attribute( 'main-menu', 'pointer-animation', $settings['pointer_animation']);
		endif;
		

		/*****************************/
		/*****************************/
		// MENU HORIZONTAL / VERTICAL 
		/*****************************/
		if ( 'vertical' === $settings['layout'] ) {
			$menuLayout = 'sr-menu--vertical';
		}else{
			$menuLayout = 'sr-menu--horizontal';
		}
		$this->add_render_attribute( 'main-menu', 'class', 'sr-e-desktop');
		$this->add_render_attribute( 'main-menu', 'class', $menu_args['menu_class']);
		$this->add_render_attribute( 'main-menu', 'class', $menuLayout);
		?>
		<nav <?php echo $this->get_render_attribute_string( 'main-menu' ); ?> ><?php echo $menu_html; ?></nav>
		<?php
		$this->remove_render_attribute( 'main-menu', 'class', 'sr-e-desktop');
		$this->remove_render_attribute( 'main-menu', 'class', $menuLayout);
	


		/*****************************/
		/*****************************/
		// MENU MOBILE / TOGGLE 
		/*****************************/
		$this->add_render_attribute( 'main-menu', 'class', 'sr-e-mobile sr-menu--vertical');
		$this->add_render_attribute( 'main-menu', 'class', $menu_args['menu_class']);
		?>
		<div <?php echo $this->get_render_attribute_string( 'menu-toggle' ); ?>>
			<i class="eicon-menu-bar" aria-hidden="true"></i>
			<span class="elementor-screen-only"><?php _e( 'Menu', 'elementor-sonaar' ); ?></span>
		</div>
		<nav <?php echo $this->get_render_attribute_string( 'main-menu' ); ?> ><?php echo $responsive_menu_html; ?></nav>
		<?php
	}	
	public function render_plain_content() {
	}
}
Plugin::instance()->widgets_manager->register( new SR_E_Menu() );