<?php
namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Base;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;



/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */

class SR_Music_Player extends Widget_Base {

	public function get_name() {
		return 'music-player';
	}

	public function get_title() {
		return __( 'Music Player', 'elementor-sonaar' );
	}

	public function get_icon() {
		return 'fas fa-music sonaar-badge';
	}
	public function get_help_url() {
		return 'https://support.sonaar.io';
	}
	public function get_keywords() {
		return [ 'mp3', 'player', 'audio', 'sonaar', 'music', 'beat', 'radio' ,'stream', 'track', 'beat', 'playlist','album'];
	}
	public function get_categories() {
		return [ 'elementor-sonaar' ];
	}

	public function get_script_depends() {
		return [ 'elementor-sonaar' ];
	}

	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Music Player Settings', 'elementor-sonaar' ),
			]
		);
			
			$this->add_control(
				'playlist_list',
					[
						'label'                 => esc_html__( 'Select Playlist(s)', 'elementor-sonaar' ),
						'label_block' => true,
						'description' => 'Leave blank if you want to display your latest published playlist',
						'type' => \Elementor\Controls_Manager::SELECT2,
						'multiple' => true,
						'options'               => sr_elementor_select_playlist(),   
						'condition' => [
							'play_current_id' => '',
						]         	
					]
			);
			$this->add_control(
				'playlist_autoplay',
				[
					'label' => __( 'Popup player in the footer when page loads', 'elementor-sonaar' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => __( 'Yes', 'elementor-sonaar' ),
					'label_off' => __( 'No', 'elementor-sonaar' ),
					'return_value' => '1',
					'default' => '0',
				]
			);
			$this->add_control(
				'playlist_shuffle',
				[
					'label' => __( 'Shuffle Track', 'elementor-sonaar' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => __( 'Yes', 'elementor-sonaar' ),
					'label_off' => __( 'No', 'elementor-sonaar' ),
					'return_value' => '1',
					'default' => 'yes',
				]
			);
			$this->add_control(
				'playlist_show_artwork',
				[
					'label' => __( 'Show Artwork', 'elementor-sonaar' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => __( 'Yes', 'elementor-sonaar' ),
					'label_off' => __( 'No', 'elementor-sonaar' ),
					'return_value' => '1',
					'default' => '1',
				]
			);
			$this->add_control(
				'playlist_show_playlist',
				[
					'label' => __( 'Show Playlist', 'elementor-sonaar' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => __( 'Yes', 'elementor-sonaar' ),
					'label_off' => __( 'No', 'elementor-sonaar' ),
					'return_value' => '1',
					'default' => '0',
				]
			);
			$this->add_control(
				'playlist_show_album_market',
				[
					'label' => __( 'Show Album Stores', 'elementor-sonaar' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => __( 'Yes', 'elementor-sonaar' ),
					'label_off' => __( 'No', 'elementor-sonaar' ),
					'return_value' => '1',
					'default' => '0',
				]
			);
			$this->add_control(
				'playlist_show_soundwave',
				[
					'label' => __( 'Show Soundwave', 'elementor-sonaar' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => __( 'Yes', 'elementor-sonaar' ),
					'label_off' => __( 'No', 'elementor-sonaar' ),
					'condition' => [
						'playlist_show_playlist!' => '1',
					],
					'return_value' => '1',
					'default' => '0',
				]
			);
			/*if (  function_exists( 'elementor_theme_do_location') )  {*/
			$this->add_control(
				'play_current_id',
				[
					'label' => __( 'Play its own Post ID track', 'elementor-sonaar' ),
					'description' => __( 'Check this case if this player is intended to be displayed on its own single post', 'elementor-sonaar' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'yes' => __( 'Yes', 'elementor-sonaar' ),
					'no' => __( 'No', 'elementor-sonaar' ),
					'return_value' => 'yes',
					'default' => '',

				]

			);
			$this->add_control(
				'sr_playlist_title_tag',
				[
					'label' => __( 'HTML Title Tag', 'elementor-sonaar' ),
					'type' => Controls_Manager::SELECT,
					'options' => [
						'h1' => 'H1',
						'h2' => 'H2',
						'h3' => 'H3',
						'h4' => 'H4',
						'h5' => 'H5',
						'h6' => 'H6',
						'div' => 'div',
						'span' => 'span',
						'p' => 'p',
					],
					'default' => 'h1',
				]
			);
			/*}*/
		$this->end_controls_section();

		/**
         * STYLE: PLAYLIST
         * -------------------------------------------------
         */
			
		$this->start_controls_section(
            'artwork_style',
            [
                'label'                 => __( 'Artwork', 'elementor-sonaar' ),
				'tab'                   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'playlist_show_artwork!' => '',
				],
            ]
		);
		$this->add_responsive_control(
			'artwork_width',
			[
				'label' => __( 'Artwork Width', 'elementor-sonaar' ) . ' (px)',
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 1000,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .srt_player-container .iron-audioplayer .album .album-art' => 'max-width: {{SIZE}}px;',
				],
			]
		);
		$this->add_responsive_control(
			'artwork_padding',
			[
				'label' => __( 'Artwork Padding', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .iron_music_player[data-skin="music"].srt_player-container .iron-audioplayer .sonaar-grid .album' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'artwork_align',
			[
				'label' => __( 'Artwork Alignment', 'elementor-sonaar' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'elementor' ),
						'icon' => 'eicon-h-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'elementor' ),
						'icon' => 'eicon-h-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'elementor' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .iron_music_player[data-skin="music"].srt_player-container .iron-audioplayer .sonaar-Artwort-box' => 'justify-self: {{VALUE}}; text-align: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

        /**
         * STYLE: PLAYLIST
         * -------------------------------------------------
         */
			
		$this->start_controls_section(
            'playlist_style',
            [
                'label'                 => __( 'Playlist', 'elementor-sonaar' ),
				'tab'                   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'playlist_show_playlist' => '1',
				],
            ]
		);
		/*------------------*/
		$this->add_control(
			'title_btshow',
			[
				'label' => esc_html__( 'Hide Title', 'sonaar-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => '',
				'return_value' => 'none',
				'selectors' => [
						 '{{WRAPPER}} .playlist .sr_it-playlist-title' => 'display:{{VALUE}};',
				 ],
			]
		);
		$this->add_control(
			'title_color',
			[
				'label'                 => __( 'Title Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'condition' => [
					'title_btshow' => '',
				],
				'selectors'             => [
					'{{WRAPPER}} .playlist .sr_it-playlist-title' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => __( 'Title Typography', 'elementor-sonaar' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'condition' => [
					'title_btshow' => '',
				],
				'selector' => '{{WRAPPER}} .srt_player-container .iron-audioplayer .sr_it-playlist-title',
			]
		);
		$this->add_responsive_control(
			'title_indent',
			[
				
				'label' => __( 'Title Indent', 'elementor-sonaar' ) . ' (px)',
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => -500,
					],
				],
				'condition' => [
					'title_btshow' => '',
				],
				'selectors' => [
					'{{WRAPPER}} .sr_it-playlist-title' => 'margin-left: {{SIZE}}px;',
					'{{WRAPPER}} .sr_it-playlist-artists' => 'margin-left: {{SIZE}}px;',
					'{{WRAPPER}} .sr_it-playlist-release-date' => 'margin-left: {{SIZE}}px;',
				],
			]
		);
		$this->add_responsive_control(
			'title_align',
			[
				'label' => __( 'Title Alignment', 'elementor-sonaar' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'elementor' ),
						'icon' => 'eicon-h-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'elementor' ),
						'icon' => 'eicon-h-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'elementor' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .sr_it-playlist-title, {{WRAPPER}} .sr_it-playlist-artists, {{WRAPPER}} .sr_it-playlist-release-date' => 'text-align: {{VALUE}};',
				],
			]
		);

		/*------------------*/
		$this->add_control(
			'hr',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
				'style' => 'thick',
			]
		);
		$this->add_control(
			'artist_name_btshow',
			[
				'label' => esc_html__( 'Hide Artist Name', 'sonaar-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => '',
				'return_value' => 'none',
				'selectors' => [
						 '{{WRAPPER}} .sr_it-playlist-artists' => 'display:{{VALUE}};',
				 ],
			]
		);
		$this->add_control(
			'artist_name_color',
			[
				'label'                 => __( 'Artist Name Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'condition' => [
					'artist_name_btshow' => '',
				],
				'selectors'             => [
					'{{WRAPPER}} .sr_it-playlist-artists' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'artist_name_typography',
				'label' => __( 'Artist Name Typography', 'elementor-sonaar' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'condition' => [
					'artist_name_btshow' => '',
				],
				'selector' => '{{WRAPPER}} .sr_it-playlist-artists',
			]
		);
		/*------------------*/
		$this->add_control(
			'hr2',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
				'style' => 'thick',
			]
		);
		$this->add_control(
			'release_date_btshow',
			[
				'label' => esc_html__( 'Hide Release Date', 'sonaar-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => '',
				'return_value' => 'none',
				'selectors' => [
						 '{{WRAPPER}} .sr_it-playlist-release-date' => 'display:{{VALUE}};',
				 ],
			]
		);
		$this->add_control(
			'release-date-color',
			[
				'label'                 => __( 'Release Date Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'condition' => [
					'release_date_btshow' => '',
				],
				'selectors'             => [
					'{{WRAPPER}} .sr_it-playlist-release-date' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'release_date_typography',
				'label' => __( 'Release Date Typography', 'elementor-sonaar' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'condition' => [
					'release_date_btshow' => '',
				],
				'selector' => '{{WRAPPER}} .sr_it-playlist-release-date',
			]
		);
		/*------------------*/
		$this->add_control(
			'hr3',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
				'style' => 'thick',
			]
		);
		$this->add_control(
			'track_title_color',
			[
				'label'                 => __( 'Track Title Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .srt_player-container .iron-audioplayer .playlist .audio-track, {{WRAPPER}} .srt_player-container .iron-audioplayer .playlist .track-number' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'track_title_typography',
				'label' => __( 'Track Title Typography', 'elementor-sonaar' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .srt_player-container .iron-audioplayer .playlist .audio-track, {{WRAPPER}} .srt_player-container .iron-audioplayer .playlist .track-number',
			]
		);
		$this->add_responsive_control(
			'tracks_gap',
			[
				'label' => __( 'Tracks Gap', 'elementor-sonaar' ) . ' (px)',
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .srt_player-container .iron-audioplayer .playlist li + li' => 'margin-top: {{SIZE}}px;',
				],
			]
		);
		/*------------------*/
		$this->add_control(
			'hr4',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
				'style' => 'thick',
			]
		);
		$this->add_control(
			'tracklist_controls_color',
			[
				'label'                 => __( 'Play/Pause Button Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .srt_player-container .iron-audioplayer .playlist .audio-track path, {{WRAPPER}} .srt_player-container .iron-audioplayer .playlist .audio-track rect' => 'fill: {{VALUE}}',
				],
			]
		);
		$this->add_responsive_control(
			'tracklist_controls_size',
			[
				'label' => __( 'Play/Pause Button Size', 'elementor-sonaar' ) . ' (px)',
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .srt_player-container .iron-audioplayer .track-number svg' => 'width: {{SIZE}}px; height: {{SIZE}}px;',
					'{{WRAPPER}} .srt_player-container .iron-audioplayer .track-number' => 'padding-left: calc({{SIZE}}px + 12px);',
				],
			]
		);
		/*------------------*/
		$this->add_control(
			'hr7',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
				'style' => 'thick',
			]
		);
		$this->add_control(
			'hide_icon_btshow',
			[
				'label' => esc_html__( 'Hide Track Link(s)', 'sonaar-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => '',
				'return_value' => 'none',
				'selectors' => [
						 '{{WRAPPER}} .song-store' => 'display:{{VALUE}};',
						 '{{WRAPPER}} .srt_player-container .iron-audioplayer .playlist ul' => 'display:inline-block;',
						 '{{WRAPPER}} .tracklist-item-title' => 'max-width: 100% !important;',
				 ],
			]
		);
		$this->add_control(
			'tracklist_icons_color',
			[
				'label'                 => __( 'Track Link Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'condition' => [
					'hide_icon_btshow' => '',
				],
				'selectors'             => [
					'{{WRAPPER}} .srt_player-container .iron-audioplayer .playlist a.song-store' => 'color: {{VALUE}}',
					'{{WRAPPER}} .srt_player-container .playlist .store-list svg' => 'fill: {{VALUE}}',

				],
			]
		);
		$this->add_responsive_control(
			'tracklist_icons_size',
			[
				'label' => __( 'Track Link Size', 'elementor-sonaar' ) . ' (px)', 
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 50,
					],
				],
				'condition' => [
					'hide_icon_btshow' => '',
				],
				'selectors' => [
					'{{WRAPPER}} .iron_widget_radio .playlist .store-list .fa' => 'font-size: {{SIZE}}px;',
					'{{WRAPPER}} .iron_widget_radio .playlist .store-list svg' => 'width: {{SIZE}}px; height: {{SIZE}}px;',
				],
			]
		);
		/*------------------*/
		$this->add_control(
			'hr10',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
				'style' => 'thick',
			]
		);
		$this->add_control(
			'tracklist_hover_color',
			[
				'label'                 => __( 'Tracklist Hover Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .srt_player-container .iron-audioplayer .playlist .audio-track:hover, {{WRAPPER}} .srt_player-container .iron-audioplayer .playlist .audio-track:hover .track-number, {{WRAPPER}} .srt_player-container .iron-audioplayer .playlist a.song-store:hover, {{WRAPPER}} .srt_player-container .iron-audioplayer .playlist .current a.song-store:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .srt_player-container .iron-audioplayer .playlist .audio-track:hover path, {{WRAPPER}} .srt_player-container .iron-audioplayer .playlist .audio-track:hover rect, {{WRAPPER}} .srt_player-container .playlist .store-list a.song-store:hover svg' => 'fill: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'tracklist_active_color',
			[
				'label'                 => __( 'Tracklist Active Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .srt_player-container .audio-playing .playlist .current .audio-track, {{WRAPPER}} .srt_player-container .audio-playing .playlist .current .audio-track .track-number, {{WRAPPER}} .srt_player-container .audio-playing .playlist .current a.song-store' => 'color: {{VALUE}}',
					'{{WRAPPER}} .srt_player-container .audio-playing .playlist .current .audio-track path, {{WRAPPER}} .srt_player-container .audio-playing .playlist .current .audio-track rect, {{WRAPPER}} .srt_player-container .audio-playing .playlist .current .store-list a.song-store svg' => 'fill: {{VALUE}}',
				],
			]
		);
		/*------------------*/
		$this->add_control(
			'hr8',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
				'style' => 'thick',
			]
		);
		$this->add_responsive_control(
			'tracklist_margin',
			[
				'label' => __( 'Tracklist Margin', 'elementor-sonaar' ) . ' (px)', 
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .srt_player-container .iron-audioplayer .playlist ul' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'playlist_margin',
			[
				'label' => __( 'Container Margin', 'elementor-sonaar' ) . ' (px)', 
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .playlist' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'container_align',
			[
				'label' => __( 'Container Alignment', 'elementor-sonaar' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'elementor' ),
						'icon' => 'eicon-h-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'elementor' ),
						'icon' => 'eicon-h-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'elementor' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .sonaar-grid>div:last-of-type' => 'text-align: {{VALUE}}; justify-self: {{VALUE}};',
				],
			]
		);
		$this->add_responsive_control(
			'playlist_width',
			[
				'label' => __( 'Container Width', 'elementor-sonaar' ) . ' (px)',
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 1000,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .srt_player-container .iron-audioplayer .playlist' => 'width: {{SIZE}}px;',
				],
			]
		);
		/*------------------*/
		$this->add_control(
			'hr9',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
				'style' => 'thick',
			]
		);
		$this->add_control(
			'hide_number_btshow',
			[
				'label' => esc_html__( 'Hide Track Number', 'sonaar-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => '',
				'return_value' => 'none',
				'selectors' => [
						 '{{WRAPPER}} .srt_player-container .iron-audioplayer .track-number .number' => 'display:{{VALUE}};',
						 '{{WRAPPER}} .srt_player-container .iron-audioplayer .track-number' => 'padding-right:0;',
						 '{{WRAPPER}} .srt_player-container .iron-audioplayer .track-number' => 'display: inline;',
				 ],
			]
		);
		$this->end_controls_section();
		/**
         * STYLE: Album Stores
         * -------------------------------------------------
         */
			
		$this->start_controls_section(
            'album_stores',
            [
                'label'                 => __( 'Album Stores', 'elementor-sonaar' ),
				'tab'                   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'playlist_show_album_market!' => '',
				],
				
            ]
		);
		/*------------------*/
		$this->add_control(
			'store_title_btshow',
			[
				'label' => esc_html__( 'Hide Store Title', 'sonaar-elementor' ),
				'type' => Controls_Manager::SWITCHER,
				'default' => '',
				'return_value' => 'none',
				'selectors' => [
						 '{{WRAPPER}} .available-now' => 'display:{{VALUE}};',
				 ],
			]
		);
		$this->add_control(
			'store_title_text',
			[
				'label' => __( 'Store Title', 'sonaar-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'default' => '',
				'condition' => [
					'store_title_btshow' => '',
				],
				'label_block' => false,
			]
		);
		$this->add_control(
			'store_title_color',
			[
				'label'                 => __( 'Store Title Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'condition' => [
					'store_title_btshow' => '',
				],
				'selectors'             => [
					'{{WRAPPER}} .available-now' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'store_title_typography',
				'label' => __( 'Store Title Typography', 'elementor-sonaar' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'condition' => [
					'store_title_btshow' => '',
				],
				'selector' => '{{WRAPPER}} .available-now',
			]
		);
		$this->add_responsive_control(
			'store_title_align',
			[
				'label' => __( 'Store Title Alignment', 'elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'elementor' ),
						'icon' => 'eicon-h-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'elementor' ),
						'icon' => 'eicon-h-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'elementor' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'default' => '',
				'condition' => [
					'store_title_btshow' => '',
				],
				'selectors' => [
					'{{WRAPPER}} .available-now' => 'text-align: {{VALUE}};',
				],
			]
		);
		/*-----------------*/
		$this->add_control(
			'hr5',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
				'style' => 'thick',
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'store_button_typography',
				'label' => __( 'Store Button Typography', 'elementor-sonaar' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} a.button',
			]
		);

		$this->start_controls_tabs( 'tabs_button_style' );

		$this->start_controls_tab(
			'tab_button_normal',
			[
				'label' => __( 'Normal', 'elementor' ),
			]
		);

		$this->add_control(
			'button_text_color',
			[
				'label' => __( 'Button Text Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} a.button' => 'color: {{VALUE}};',
					'{{WRAPPER}} .buttons-block svg' => 'fill: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'background_color',
			[
				'label' => __( 'Button Background Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				/*'scheme' => [
					'type' => Scheme_Color::get_type(),
					'value' => Scheme_Color::COLOR_4,
				],*/
				'selectors' => [
					'{{WRAPPER}} a.button' => 'background: {{VALUE}}',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => __( 'Hover', 'elementor' ),
			]
		);

		$this->add_control(
			'button_hover_color',
			[
				'label' => __( 'Button Text Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.button:hover' => 'color: {{VALUE}}',
					'{{WRAPPER}} .buttons-block a.button:hover svg' => 'fill: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'button_background_hover_color',
			[
				'label' => __( 'Button Background Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} a.button:hover' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'button_hover_border_color',
			[
				'label' => __( 'Button Border Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'border_border!' => '',
				],
				'selectors' => [
					'{{WRAPPER}} a.button:hover' => 'border-color: {{VALUE}};',
				],
			]
		);
		/*
		$this->add_control(
			'hover_animation',
			[
				'label' => __( 'Hover Animation', 'elementor' ),
				'type' => Controls_Manager::HOVER_ANIMATION,
			]
		);
		*/
		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'border',
				'selector' => '{{WRAPPER}} .store-list .button',
				'separator' => 'before',
			]
		);
		$this->add_control(
			'button_border_radius',
			[
				'label' => __( 'Button Border Radius', 'elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .iron_widget_radio .store-list .button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'button_box_shadow',
				'selector' => '{{WRAPPER}} .store-list .button',
			]
		);
		$this->add_responsive_control(
			'button_text_padding',
			[
				'label' => __( 'Button Padding', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .iron_widget_radio .store-list .button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'space_between_store_button',
			[
				'label' => __( 'Buttons Space', 'sonaar-elementor' ) . ' (px)',
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .buttons-block li' => 'padding-right: {{SIZE}}px; padding-bottom: {{SIZE}}px;', 
				],
			]
		);
		$this->add_control(
			'hr6',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
				'style' => 'thick',
			]
		);
		$this->add_responsive_control(
			'icon-font-size',
			[
				'label' => __( 'Icon Font Size', 'sonaar-elementor' ) . ' (px)',
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .iron_widget_radio .buttons-block .store-list .fa' => 'font-size: {{SIZE}}px;',
					'{{WRAPPER}} .buttons-block svg' => 'width: {{SIZE}}px; height: {{SIZE}}px;', 
				],
			]
		);
		$this->add_responsive_control(
			'icon_indent',
			[
				'label' => __( 'Icon Spacing', 'elementor' ) . ' (px)',
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 50,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .iron_widget_radio .buttons-block .store-list .fa' => 'padding-right: {{SIZE}}px;',
					'{{WRAPPER}} .buttons-block svg' => 'margin-right: {{SIZE}}px;',
				],
			]
		);

		$this->add_control(
			'hr11',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
				'style' => 'thick',
			]
		);
		$this->add_responsive_control(
			'album_stores_padding',
			[
				'label' => __( 'Album Stores Padding', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .srt_player-container .iron-audioplayer.show-playlist .buttons-block' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'album_stores_align',
			[
				'label' => __( 'Album Store Alignment', 'elementor' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'elementor' ),
						'icon' => 'eicon-h-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'elementor' ),
						'icon' => 'eicon-h-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'elementor' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .buttons-block .store-list, {{WRAPPER}} .buttons-block' => 'text-align: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();



		/**
         * STYLE: CONTROLS
         * -------------------------------------------------
         */
			
		$this->start_controls_section(
            'Audio Player Controls',
            [
                'label'                 => __( 'Controls', 'elementor-sonaar' ),
				'tab'                   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'playlist_show_playlist!' => '1',
				],
            ]
		);
		/*------------------*/
		$this->add_control(
		'audio_player_controls_color',
		[
			'label'                 => __( 'Audio Player Controls Color', 'elementor-sonaar' ),
			'type'                  => Controls_Manager::COLOR,
			'default'               => '',
			'selectors'             => [
				'{{WRAPPER}} .iron_music_player .control rect, {{WRAPPER}} .iron_music_player .control path, {{WRAPPER}} .iron_music_player .control polygon' => 'fill: {{VALUE}}',
			],
		]
		);
		$this->end_controls_section();

		/**
         * STYLE: SOUNDWAVE 
         * -------------------------------------------------
         */
			
		$this->start_controls_section(
            'soundwave',
            [
                'label'                 => __( 'Soundwave', 'elementor-sonaar' ),
				'tab'                   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'playlist_show_playlist!' => '1',
					'playlist_show_soundwave' => '1',
				],
            ]
		);
		$this->add_control(
			'soundWave_progress_bar_color',
			[
				'label'                 => __( 'SoundWave Progress Bar Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .iron_music_player .spectro rect' => 'fill: {{VALUE}}',
				],
			]
			);
		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings();
		
		if ($settings['play_current_id']=='yes' ){
			$postid = get_the_ID();
			$shortcode = '[iron_audioplayer skin="music" titletag="'. $settings['sr_playlist_title_tag'] .'" albums="' . $postid . '" autoplay="' . $settings['playlist_autoplay'] . '" shuffle="' . $settings['playlist_shuffle'] .'" show_artwork="' . $settings['playlist_show_artwork'] .'" show_playlist="' . $settings['playlist_show_playlist'] .'" show_album_market="' . $settings['playlist_show_album_market'] .'" show_soundwave="' . $settings ['playlist_show_soundwave'] .'"]';
		}else{
			$display_playlist_ar = $settings['playlist_list'];

			if(is_array($display_playlist_ar)){
				$display_playlist_ar = implode(", ", $display_playlist_ar); 
			}
			if (!$display_playlist_ar) {
				$shortcode = '[iron_audioplayer play-latest="yes" skin="music" titletag="'. $settings['sr_playlist_title_tag'] .'" autoplay="' . $settings['playlist_autoplay'] . '" store_title_text="' . $settings['store_title_text'] .'" shuffle="' . $settings['playlist_shuffle'] .'" show_artwork="' . $settings['playlist_show_artwork'] .'" show_playlist="' . $settings['playlist_show_playlist'] .'" show_album_market="' . $settings['playlist_show_album_market'] .'" show_soundwave="' . $settings ['playlist_show_soundwave'] .'"]';
			}else{
				$shortcode = '[iron_audioplayer skin="music" titletag="'. $settings['sr_playlist_title_tag'] .'" albums="' . $display_playlist_ar . '" autoplay="' . $settings['playlist_autoplay'] . '" store_title_text="' . $settings['store_title_text'] .'" shuffle="' . $settings['playlist_shuffle'] .'" show_artwork="' . $settings['playlist_show_artwork'] .'" show_playlist="' . $settings['playlist_show_playlist'] .'" show_album_market="' . $settings['playlist_show_album_market'] .'" show_soundwave="' . $settings ['playlist_show_soundwave'] .'"]';
			}
		
		}
		//var_dump($shortcode);
		echo do_shortcode( $shortcode );
	}
	public function render_plain_content() {
		$settings = $this->get_settings();
		if ($settings['play_current_id']=='yes'){
			$postid = get_the_ID();
			$shortcode = '[iron_audioplayer skin="music" titletag="'. $settings['sr_playlist_title_tag'] .'" albums="' . $postid . '" autoplay="' . $settings['playlist_autoplay'] . '" store_title_text="' . $settings['store_title_text'] .'" shuffle="' . $settings['playlist_shuffle'] .'" show_artwork="' . $settings['playlist_show_artwork'] .'" show_playlist="' . $settings['playlist_show_playlist'] .'" show_album_market="' . $settings['playlist_show_album_market'] .'" show_soundwave="' . $settings ['playlist_show_soundwave'] .'"]';
		}else{
			$display_playlist_ar = $settings['playlist_list'];

			if(is_array($display_playlist_ar)){
				$display_playlist_ar = implode(", ", $display_playlist_ar); 
			}
			if (!$display_playlist_ar) {
				$shortcode = '[iron_audioplayer play-latest="yes" skin="music" titletag="'. $settings['sr_playlist_title_tag'] .'" autoplay="' . $settings['playlist_autoplay'] . '" store_title_text="' . $settings['store_title_text'] .'" shuffle="' . $settings['playlist_shuffle'] .'" show_artwork="' . $settings['playlist_show_artwork'] .'" show_playlist="' . $settings['playlist_show_playlist'] .'" show_album_market="' . $settings['playlist_show_album_market'] .'" show_soundwave="' . $settings ['playlist_show_soundwave'] .'"]';
			}else{
				$shortcode = '[iron_audioplayer skin="music" titletag="'. $settings['sr_playlist_title_tag'] .'" albums="' . $display_playlist_ar . '" autoplay="' . $settings['playlist_autoplay'] . '" store_title_text="' . $settings['store_title_text'] .'" shuffle="' . $settings['playlist_shuffle'] .'" show_artwork="' . $settings['playlist_show_artwork'] .'" show_playlist="' . $settings['playlist_show_playlist'] .'" show_album_market="' . $settings['playlist_show_album_market'] .'" show_soundwave="' . $settings ['playlist_show_soundwave'] .'"]';
			}
		
		}
		echo $shortcode;
	}
	
	

}
Plugin::instance()->widgets_manager->register( new SR_Music_Player() );