<?php
namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;


/**
 * SR OffCanvas
 *
 * Off Canvas widget by Sonaar.
 *
 * @since 1.0.0
 */

class SR_OffCanvas extends Widget_Base {
	protected $nav_menu_index = 1;
	public function get_name() {
		return 'sr-offcanvas';
	}
	public function get_title() {
		return __( 'Off Canvas', 'elementor-sonaar' );
	}
	public function get_icon() {
		return 'eicon-sidebar sonaar-badge';
    }
    public function get_help_url() {
		return 'https://support.sonaar.io';
	}
	public function get_keywords() {
		return [ 'menu', 'nav', 'sonaar', 'sonar', 'sonnar', 'canva', 'offcanvas', 'sidebar', 'popup' ];
	}
	public function get_categories() {
		return [ 'elementor-sonaar' ];
	}
    public function get_custom_help_url() {
        return 'https://support.sonaar.io';
    }

    public function contentTransition(){
        $transition=[];
        $transition['slide'] =__('Slide', 'elementor-sonaar');
        $transition['overlay'] =__('Overlay', 'elementor-sonaar');
        if( class_exists('Iron_sonaar')){
            $transition['3dyatch'] =__('3D Perspective', 'elementor-sonaar');
            $transition['reveal'] =__('Reveal', 'elementor-sonaar');
            $transition['push'] =__('Push', 'elementor-sonaar');
        }
        return $transition;
    }      


	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Canvas Content', 'elementor-sonaar' ),
			]
		);
		$this->add_control(
            'content_template',
            [
                'label' => __('Choose Elementor Template', 'elementor-sonaar'),
                'type' => Controls_Manager::SELECT,
                'options' => sr_get_elementor_templates('page'),
                'default' => '-1',
                /*'condition' => [
                    'content_type' => 'template',
                ],*/
            ]
        );
		$this->add_control(
			'important_note',
			[
				'label' => __( 'Message', 'elementor-sonaar' ),
				'show_label' => false,
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' => __( '<br>Manage templates <a href="./edit.php?post_type=elementor_library&tabs_group=library&elementor_library_type=page" target="_blank">here</a>', 'elementor-sonaar' ),
				'content_classes' => 'elementor-sonaar-raw-html',
			]
		);
        $this->add_control(
            'open_offcanvas_default',
            [
                'label' => __('Opens on page load', 'elementor-sonaar'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'no',
                'label_on' => __('Yes', 'elementor-sonaar'),
                'label_off' => __('No', 'elementor-sonaar'),
                'return_value' => 'yes',
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'close_button',
            [
                'label' => __('Show Close Button', 'elementor-sonaar'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'label_on' => __('Yes', 'elementor-sonaar'),
                'label_off' => __('No', 'elementor-sonaar'),
                'return_value' => 'yes',
            ]
        );

        $this->add_control(
            'esc_close',
            [
                'label' => __('Esc to Close', 'elementor-sonaar'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'label_on' => __('Yes', 'elementor-sonaar'),
                'label_off' => __('No', 'elementor-sonaar'),
                'return_value' => 'yes',
            ]
        );

        $this->add_control(
            'body_click_close',
            [
                'label' => __('Click anywhere to Close', 'elementor-sonaar'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
                'label_on' => __('Yes', 'elementor-sonaar'),
                'label_off' => __('No', 'elementor-sonaar'),
                'return_value' => 'yes',
            ]
        );
        $this->end_controls_section(); #section_content

        /**
         * Content Tab: Toggle Button
         * -------------------------------------------------
         */
        $this->start_controls_section(
            'section_button_settings',
            [
                'label' => __('Toggle Buttons', 'elementor-sonaar'),
            ]
        );

        $this->add_control(
            'button_text',
            [
                'label' => __('Open Label', 'elementor-sonaar'),
                'type' => Controls_Manager::TEXT,
                'dynamic' => [
                    'active' => true,
                ],
                'default' => __('Menu', 'elementor-sonaar'),
            ]
        );
        $this->add_control(
			'selected_icon',
			[
				'label' => __( 'Open Icon', 'elementor' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'fas fa-bars',
					'library' => 'fa-solid',
				],
			]
        );

        $this->add_control(
            'close_button_icon_new',
            [
                'label' => __('Close Icon', 'elementor-sonaar'),
                'type' => Controls_Manager::ICONS,
                'fa4compatibility' => 'close_button_icon',
                'separator' => 'before',
                'default' => [
                    'value' => 'fas fa-times',
                    'library' => 'fa-solid',
                ],
                'condition' => [
                    'close_button' => 'yes',
                ],
            ]
        );

        $this->add_control(
			'class_toggle_offCanvas',
			[
				'label' => __( 'Class selector that toggle the OffCanvas', 'sonaar-elementor' ),
				'type' => Controls_Manager::TEXT,
				'default' => '',
				'label_block' => false,
			]
		);

        $this->end_controls_section(); #section_button_settings


        /*-----------------------------------------------------------------------------------*/
        /*    STYLE TAB
        /*-----------------------------------------------------------------------------------*/

        /**
         * Style Tab: Offcanvas Bar
         * -------------------------------------------------
         */
        $this->start_controls_section(
            'section_offcanvas_bar_style',
            [
                'label' => __('Canvas Layout', 'elementor-sonaar'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'content_transition',
            [
                'label' => __('Content Transition', 'elementor-sonaar'),
                'type' => Controls_Manager::SELECT,
                'default' => 'slide',
                'options' => $this->contentTransition(),
                'frontend_available' => true,
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'direction',
            [
                'label' => __('Position', 'elementor-sonaar'),
                'type' => Controls_Manager::CHOOSE,
                'label_block' => false,
                'toggle' => false,
                'default' => 'left',
                'options' => [
                    'left' => [
                        'title' => __('Left', 'elementor-sonaar'),
                        'icon' => 'eicon-h-align-left',
                    ],
                    'right' => [
                        'title' => __('Right', 'elementor-sonaar'),
                        'icon' => 'eicon-h-align-right',
                    ],
                ],
                'frontend_available' => true,
                'condition' => [
                    'content_transition!' => 'overlay',
                ],
            ]
        );
        $this->add_responsive_control(
            'offcanvas_width',
            [
                'label' => __('Width', 'elementor-sonaar'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px', '%'],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 700,
                        'step' => 5,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => 300,
                ],
                'selectors' => [
                    //OffCanvas Container LEFT
                    '.sr-offcanvas-content-open.sr-offcanvas-content-left[sr-oc-transition="push"] .sr-offcanvas-container.sr-offcanvas-content-visible>header .sr-sticky,
                    .sr-offcanvas-content-open.sr-offcanvas-content-left[sr-oc-transition="reveal"] .sr-offcanvas-container.sr-offcanvas-content-visible:after,
                    .sr-offcanvas-content-open.sr-offcanvas-content-left[sr-oc-transition="reveal"] .sr-offcanvas-container.sr-offcanvas-content-visible>header .sr-sticky,
                    .sr-offcanvas-content-open.sr-offcanvas-content-left[sr-oc-transition="push"] .sr-offcanvas-container.sr-offcanvas-content-visible #sonaar-player.srt_sticky-player.enable,
                    .sr-offcanvas-content-open.sr-offcanvas-content-left[sr-oc-transition="reveal"] .sr-offcanvas-container.sr-offcanvas-content-visible #sonaar-player.srt_sticky-player.enable,
                    .sr-offcanvas-content-open.sr-offcanvas-content-left[sr-oc-transition="push"] .sr-offcanvas-container.sr-offcanvas-content-visible #overlay, 
                    .sr-offcanvas-content-open.sr-offcanvas-content-left[sr-oc-transition="reveal"] .sr-offcanvas-container.sr-offcanvas-content-visible #overlay, 
                    .sr-offcanvas-content-open.sr-offcanvas-content-left[sr-oc-transition="push"] .sr-offcanvas-container.sr-offcanvas-content-visible #pusher,
                    .sr-offcanvas-content-open.sr-offcanvas-content-left[sr-oc-transition="reveal"] .sr-offcanvas-container.sr-offcanvas-content-visible #pusher,
                    .elementor-html .block-template.sr-offcanvas-content-open.sr-offcanvas-content-left[sr-oc-transition="push"] .sr-offcanvas-container.sr-offcanvas-content-visible,
                    .elementor-html .block-template.sr-offcanvas-content-open.sr-offcanvas-content-left[sr-oc-transition="reveal"] .sr-offcanvas-container.sr-offcanvas-content-visible' => 'transform: translateX({{SIZE}}{{UNIT}});',
                    '.sr-offcanvas-content-open.sr-offcanvas-content-left[sr-oc-transition="push"] .sr-offcanvas-container.sr-offcanvas-content-visible #sonaar-player.srt_sticky-player:not(.enable),
                    .sr-offcanvas-content-open.sr-offcanvas-content-left[sr-oc-transition="reveal"] .sr-offcanvas-container.sr-offcanvas-content-visible #sonaar-player.srt_sticky-player:not(.enable)' => 'transform: translate3d({{SIZE}}{{UNIT}}, 94px, 0);',
                    //OffCanvas Container Right
                    '.sr-offcanvas-content-open.sr-offcanvas-content-right[sr-oc-transition="push"] .sr-offcanvas-container.sr-offcanvas-content-visible>header .sr-sticky,
                    .sr-offcanvas-content-open.sr-offcanvas-content-right[sr-oc-transition="reveal"] .sr-offcanvas-container.sr-offcanvas-content-visible:after,
                    .sr-offcanvas-content-open.sr-offcanvas-content-right[sr-oc-transition="reveal"] .sr-offcanvas-container.sr-offcanvas-content-visible>header .sr-sticky,
                    .sr-offcanvas-content-open.sr-offcanvas-content-right[sr-oc-transition="push"] .sr-offcanvas-container.sr-offcanvas-content-visible #sonaar-player.srt_sticky-player.enable,
                    .sr-offcanvas-content-open.sr-offcanvas-content-right[sr-oc-transition="reveal"] .sr-offcanvas-container.sr-offcanvas-content-visible #sonaar-player.srt_sticky-player.enable,
                    .sr-offcanvas-content-open.sr-offcanvas-content-right[sr-oc-transition="push"] .sr-offcanvas-container.sr-offcanvas-content-visible #overlay, 
                    .sr-offcanvas-content-open.sr-offcanvas-content-right[sr-oc-transition="reveal"] .sr-offcanvas-container.sr-offcanvas-content-visible #overlay, 
                    .sr-offcanvas-content-open.sr-offcanvas-content-right[sr-oc-transition="push"] .sr-offcanvas-container.sr-offcanvas-content-visible #pusher,
                    .sr-offcanvas-content-open.sr-offcanvas-content-right[sr-oc-transition="reveal"] .sr-offcanvas-container.sr-offcanvas-content-visible #pusher,
                    .elementor-html .block-template.sr-offcanvas-content-open.sr-offcanvas-content-right[sr-oc-transition="push"] .sr-offcanvas-container.sr-offcanvas-content-visible,
                    .elementor-html .block-template.sr-offcanvas-content-open.sr-offcanvas-content-right[sr-oc-transition="reveal"] .sr-offcanvas-container.sr-offcanvas-content-visible' => 'transform: translateX(-{{SIZE}}{{UNIT}});',
                    '.sr-offcanvas-content-open.sr-offcanvas-content-right[sr-oc-transition="push"] .sr-offcanvas-container.sr-offcanvas-content-visible #sonaar-player.srt_sticky-player:not(.enable),
                    .sr-offcanvas-content-open.sr-offcanvas-content-right[sr-oc-transition="reveal"] .sr-offcanvas-container.sr-offcanvas-content-visible #sonaar-player.srt_sticky-player:not(.enable)' => 'transform: translate3d(-{{SIZE}}{{UNIT}}, 94px, 0);',
                    //OffCanvas Content
                    '.sr-offcanvas-content-{{ID}}' => 'width: {{SIZE}}{{UNIT}};',
                 ],
                 'condition' => [
                    'content_transition!' => 'overlay',
                ],
            ]
        );
        $this->add_responsive_control(
            'offcanvas_fullwidth_width',
            [
                'label' => __('Width', 'elementor-sonaar'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'min' => 0,
                    'max' => 100,
                ],
                'default' => [
                    'size' => 100,
                ],
                'selectors' => [
                    '.sr-offcanvas-content-{{ID}}.sr-offcanvas-overlay' => 'width:{{SIZE}}vw; height:{{SIZE}}vh',
                 ],
                 'condition' => [
                    'content_transition' => 'overlay',
                ],
            ]
        );
        $this->add_responsive_control(
            'scaling_animation',
            [
                'label' => __('Scaling Animation', 'elementor-sonaar'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'min' => 0,
                    'max' => 200,
                ],
                'default' => [
                    'size' => 80,
                ],
                'selectors' => [
                    '.sr-offcanvas-content-{{ID}}.sr-offcanvas-overlay:not(.sr-offcanvas-opened)' => '-webkit-transform: translate(-50%, -50%) scale(calc({{SIZE}} / 100)); transform: translate(-50%, -50%) scale(calc({{SIZE}} / 100));',
                 ],
                 'condition' => [
                    'content_transition' => 'overlay',
                ],
            ]
        );
        $this->add_control(
			'time_transition',
			[
				'label' => __( 'Time transition(ms)', 'elementor-sonaar'),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 1000,
				'step' => 10,
				'default' => 200,
                'selectors' => [
                    '.sr-offcanvas-content-{{ID}}.sr-offcanvas-overlay' => 'transition: transform {{VALUE}}ms, opacity {{VALUE}}ms',
                    '.sr-offcanvas-content-{{ID}}.sr-offcanvas-overlay .sr-offcanvas-body' => 'transition: opacity {{VALUE}}ms;',
                ],
                'condition' => [
                    'content_transition' => 'overlay',
                ],
			]
		);
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'offcanvas_bar_bg',
                'label' => __('Sidebar Background', 'elementor-sonaar'),
                'types' => ['classic', 'gradient'],
                'selector' => 'body .sr-offcanvas-content-{{ID}}',
            ]
        );
        $this->add_responsive_control(
            '3dyatch_positionX',
            [
                'label' => __('Container Left/Right', 'elementor-sonaar'),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'size' => '100',
                    'unit' => 'px',
                ],
                'range' => [
                    'px' => [
                        'min' => -500,
                        'max' => 500,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px'],
                 'selectors' => [
                    ':root' => '--3dPositionX:{{SIZE}}{{UNIT}}',
                ],
                'condition' => [
                    'content_transition' => '3dyatch',
                ],
            ]
        );
        $this->add_responsive_control(
            '3dyatch_positionZ',
            [
                'label' => __('Container Zoom', 'elementor-sonaar'),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'size' => '0',
                    'unit' => 'px',
                ],
                'range' => [
                    'px' => [
                        'min' => -10000,
                        'max' => 10000,
                        'step' => 1,
                    ],
                ],
                //'size_units' => ['px'],
                 'selectors' => [
                    ':root' => '--3dPositionZ:{{SIZE}}{{UNIT}}',
                ],
                'condition' => [
                    'content_transition' => '3dyatch',
                ],
            ]
        );
         $this->add_responsive_control(
            '3dyatch_degree',
            [
                'label' => __('3D Perspective', 'elementor-sonaar'),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'size' => '20',
                    'unit' => 'deg',
                ],
                'range' => [
                    'deg' => [
                        'min' => -90,
                        'max' => 90,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['deg'],
                'selectors' => [
                    ':root' => '--3dPerspective:{{SIZE}}{{UNIT}}',
                ],
                'condition' => [
                    'content_transition' => '3dyatch',
                ],
            ]
        );
        $this->add_control(
            '3dyatch_bg_color',
            [
                'label' => __('Body Background', 'elementor-sonaar'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    'body[sr-oc-id="{{ID}}"] #overlay' => 'background-color: {{VALUE}}',
                ],
                'condition' => [
                    'content_transition' => '3dyatch',
                ],
            ]
        );


        $this->add_responsive_control(
            'offcanvas_bar_padding',
            [
                'label' => __('Padding', 'elementor-sonaar'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    'body .sr-offcanvas-content-{{ID}} .sr-offcanvas-body' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'offcanvas_border',
                'label' => __('Border', 'elementor-sonaar'),
                'placeholder' => '1px',
                'default' => '1px',
                'selector' => 'body .sr-offcanvas-content-{{ID}}',
                'condition' => [
                    'content_transition' => 'overlay',
                ],
            ]
        );

        $this->add_control(
            'offcanvas_border_radius',
            [
                'label' => __('Border Radius', 'elementor-sonaar'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    'body .sr-offcanvas-content-{{ID}}' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'condition' => [
                    'content_transition' => 'overlay',
                ],
            ]
        );

        $this->end_controls_section(); #section_offcanvas_bar_style

        /**
         * Style Tab: Icon
         * -------------------------------------------------
         */
        $this->start_controls_section(
            'section_icon_style',
            [
                'label' => __('Icon', 'elementor-sonaar'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'trigger' => 'on-click',
                    'trigger_type!' => 'button',
                ],
            ]
        );

        $this->add_control(
            'icon_color',
            [
                'label' => __('Color', 'elementor-sonaar'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .sr-trigger-icon' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'trigger' => 'on-click',
                    'trigger_type' => 'icon',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_size',
            [
                'label' => __('Size', 'elementor-sonaar'),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'size' => '28',
                    'unit' => 'px',
                ],
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 80,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .sr-trigger-icon' => 'font-size: {{SIZE}}{{UNIT}}',
                ],
                'condition' => [
                    'trigger' => 'on-click',
                    'trigger_type' => 'icon',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_image_width',
            [
                'label' => __('Width', 'elementor-sonaar'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 1200,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .sr-trigger-image' => 'width: {{SIZE}}{{UNIT}}',
                ],
                'condition' => [
                    'trigger' => 'on-click',
                    'trigger_type' => 'image',
                ],
            ]
        );

        $this->end_controls_section(); #section_icon_style

        /**
         * Style Tab: Toggle Button
         * -------------------------------------------------
         */
        $this->start_controls_section(
            'section_toggle_button_style',
            [
                'label' => __('Open Button', 'elementor-sonaar'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'button_typography',
                'label' => __('Typography', 'elementor-sonaar'),
                'scheme' => Typography::TYPOGRAPHY_4,
                'selector' => '{{WRAPPER}} .sr-offcanvas-toggle .sr-toggle-text',
            ]
        );
        $this->add_responsive_control(
            'button_align',
            [
                'label' => __('Alignment', 'elementor-sonaar'),
                'type' => Controls_Manager::CHOOSE,
                'default' => 'left',
                'options' => [
                    'left' => [
                        'title' => __('Left', 'elementor-sonaar'),
                        'icon' => 'eicon-h-align-left',
                    ],
                    'center' => [
                        'title' => __('Center', 'elementor-sonaar'),
                        'icon' => 'eicon-h-align-center',
                    ],
                    'right' => [
                        'title' => __('Right', 'elementor-sonaar'),
                        'icon' => 'eicon-h-align-right',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .sr-offcanvas-toggle-wrap' => 'text-align: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'label_position',
            [
                'label' => __('Text Position', 'elementor-sonaar'),
                'type' => Controls_Manager::CHOOSE,
                'label_block' => false,
                'toggle' => false,
                'default' => 'left',
                'options' => [
                    'left' => [
                        'title' => __('Left', 'elementor-sonaar'),
                        'icon' => 'eicon-h-align-left',
                    ],
                    'right' => [
                        'title' => __('Right', 'elementor-sonaar'),
                        'icon' => 'eicon-h-align-right',
                    ],
                ],
                'frontend_available' => true,
                'selectors_dictionary' => [
                    'left' => 'direction: rtl',
                    'right' => 'direction: inherit',
                ],
                'prefix_class' => 'sr-offcanva-txt-align-',
                'selectors' => [
                    '{{WRAPPER}} .sr-offcanvas-toggle' => '{{VALUE}}',
                ],
            ]
        );


        $this->add_responsive_control(
            'toggle_button_icon_size',
            [
                'label' => __('Icon Size', 'elementor-sonaar'),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'size' => '28',
                    'unit' => 'px',
                ],
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 80,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .sr-offcanvas-toggle-wrap .sr-offcanvas-toggle-icon' => 'font-size: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'toggle_button_icon_space',
            [
                'label' => __('Icon Space', 'elementor-sonaar'),
                'type' => Controls_Manager::SLIDER,
                /*'default' => [
                    'size' => '10',
                    'unit' => 'px',
                ],*/
                'range' => [
                    'px' => [
                        'max' => 50,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}}.sr-offcanva-txt-align-right .sr-offcanvas-toggle-wrap .sr-offcanvas-toggle-icon' => 'margin-right: {{SIZE}}{{UNIT}}',
                    '{{WRAPPER}}.sr-offcanva-txt-align-left .sr-offcanvas-toggle-wrap .sr-offcanvas-toggle-icon' => 'margin-left: {{SIZE}}{{UNIT}}',
                    /*'{{WRAPPER}} .sr-offcanvas-toggle-wrap .sr-offcanvas-toggle-icon.sr-offcanvas-toggle-svg-icon' => 'right: {{SIZE}}{{UNIT}};',*/
                ],
            ]
        );

        $this->start_controls_tabs('tabs_button_style');

        $this->start_controls_tab(
            'tab_button_normal',
            [
                'label' => __('Normal', 'elementor-sonaar'),
            ]
        );

        $this->add_control(
            'button_bg_color_normal',
            [
                'label' => __('Background Color', 'elementor-sonaar'),
                'type' => Controls_Manager::COLOR,
                'default' => '#00000000',
                'selectors' => [
                    '{{WRAPPER}} .sr-offcanvas-toggle' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'button_text_color_normal',
            [
                'label' => __('Color', 'elementor-sonaar'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .sr-offcanvas-toggle' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .sr-offcanvas-toggle svg' => 'fill: {{VALUE}};',
                    //'{{WRAPPER}} .sr-offcanvas-toggle svg' => 'stroke: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'button_border_normal',
                'label' => __('Border', 'elementor-sonaar'),
                'placeholder' => '1px',
                'default' => '1px',
                'selector' => '{{WRAPPER}} .sr-offcanvas-toggle',
            ]
        );

        $this->add_control(
            'button_border_radius',
            [
                'label' => __('Border Radius', 'elementor-sonaar'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .sr-offcanvas-toggle' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'button_padding',
            [
                'label' => __('Padding', 'elementor-sonaar'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .sr-offcanvas-toggle' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'button_box_shadow',
                'selector' => '{{WRAPPER}} .sr-offcanvas-toggle',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_button_hover',
            [
                'label' => __('Hover', 'elementor-sonaar'),
            ]
        );

        $this->add_control(
            'button_bg_color_hover',
            [
                'label' => __('Background Color', 'elementor-sonaar'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .sr-offcanvas-toggle:hover' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'button_text_color_hover',
            [
                'label' => __('Color', 'elementor-sonaar'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .sr-offcanvas-toggle:hover' => 'color: {{VALUE}}',
                    '{{WRAPPER}} .sr-offcanvas-toggle:hover svg' => 'fill: {{VALUE}}',
                    //'{{WRAPPER}} .sr-offcanvas-toggle:hover svg' => 'stroke: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'button_border_color_hover',
            [
                'label' => __('Border Color', 'elementor-sonaar'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .sr-offcanvas-toggle:hover' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'button_animation',
            [
                'label' => __('Animation', 'elementor-sonaar'),
                'type' => Controls_Manager::HOVER_ANIMATION,
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'button_box_shadow_hover',
                'selector' => '{{WRAPPER}} .sr-offcanvas-toggle:hover',
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

        /**
         * Style Tab: Close Button
         * -------------------------------------------------
         */
        $this->start_controls_section(
            'section_close_button_style',
            [
                'label' => __('Close Button', 'elementor-sonaar'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'close_button' => 'yes',
                ],
            ]
        );

        $this->add_control(
            'close_button_text_color',
            [
                'label' => __('Color', 'elementor-sonaar'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '.sr-offcanvas-close-{{ID}}' => 'color: {{VALUE}};',
                    '.sr-offcanvas-close-{{ID}} svg' => 'fill: {{VALUE}};',
                ],
                'condition' => [
                    'close_button' => 'yes',
                ],
            ]
        );

        $this->add_responsive_control(
            'close_button_size',
            [
                'label' => __('Size', 'elementor-sonaar'),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'size' => '28',
                    'unit' => 'px',
                ],
                'range' => [
                    'px' => [
                        'min' => 10,
                        'max' => 80,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px', '%'],
                'selectors' => [
                    '.sr-offcanvas-content-{{ID}} .sr-offcanvas-close-{{ID}}, .sr-offcanvas-content-{{ID}} .sr-offcanvas-close-{{ID}} .elementor-icon' => 'font-size: {{SIZE}}{{UNIT}}',
                    /*'body .sr-offcanvas-content-{{ID}} .sr-offcanvas-close-{{ID}} .sr-offcanvas-close-svg-icon' => 'width: {{SIZE}}{{UNIT}};',*/
                ],
                'condition' => [
                    'close_button' => 'yes',
                ],
            ]
        );
        /*$this->add_control(
            'close_position',
            [
                'label' => __('Position', 'elementor-sonaar'),
                'type' => Controls_Manager::CHOOSE,
                'label_block' => false,
                'toggle' => false,
                'default' => 'left',
                'options' => [
                    'left' => [
                        'title' => __('Left', 'elementor-sonaar'),
                        'icon' => 'eicon-h-align-left',
                    ],
                    'right' => [
                        'title' => __('Right', 'elementor-sonaar'),
                        'icon' => 'eicon-h-align-right',
                    ],
                ],
                'condition' => [
                    'close_button' => 'yes',
                ],
                'frontend_available' => true,
                'selectors_dictionary' => [
                    'left' => 'right:unset!important;',
                    'right' => 'left:unset!important;',
                ],
                'selectors' => [
                    '.sr-offcanvas-content-{{ID}} .sr-offcanvas-close-{{ID}}' => '{{VALUE}}',
                ],
                //'prefix_class' => 'sr-offcanva-txt-align-',
                
            ]
        );*/
        $this->add_responsive_control(
            'close_positionX',
            [
                'label' => __('Position Left/Right', 'elementor-sonaar'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px', '%'],
                'selectors' => [
                    '.sr-offcanvas-content-{{ID}} .sr-offcanvas-close-{{ID}}' => 'left: {{SIZE}}{{UNIT}}',
                    '.sr-offcanvas-content-{{ID}} .sr-offcanvas-close-{{ID}}' => 'right: {{SIZE}}{{UNIT}}',
                ],
                'condition' => [
                    'close_button' => 'yes',
                ],
            ]
        );
        $this->add_responsive_control(
            'close_positionY',
            [
                'label' => __('Position Top/Bottom', 'elementor-sonaar'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -100,
                        'max' => 500,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'size_units' => ['px', '%'],
                'selectors' => [
                    '.sr-offcanvas-content-{{ID}} .sr-offcanvas-close-{{ID}}' => 'top: {{SIZE}}{{UNIT}}',
                ],
                'condition' => [
                    'close_button' => 'yes',
                ],
            ]
        );


        $this->end_controls_section();

        /**
         * Style Tab: Overlay
         * -------------------------------------------------
         */
        $this->start_controls_section(
            'section_overlay_style',
            [
                'label' => __('Overlay', 'elementor-sonaar'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'overlay_bg_color',
            [
                'label' => __('Color', 'elementor-sonaar'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    'body.sr-offcanvas-content-{{ID}}-open .sr-offcanvas-container:after' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'overlay_opacity',
            [
                'label' => __('Opacity', 'elementor-sonaar'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1,
                        'step' => 0.01,
                    ],
                ],
                'selectors' => [
                    'body.sr-offcanvas-content-{{ID}}-open .sr-offcanvas-container:after' => 'opacity: {{SIZE}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Render close button for offcanvas output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @access protected
     */
    protected function render_close_button()
    {
        $settings = $this->get_settings_for_display();

        if ($settings['close_button'] != 'yes') {
            return;
        }

        $this->add_render_attribute(
            'close-button', 'class',
            [
                'sr-offcanvas-close',
                'sr-offcanvas-close-' . esc_attr($this->get_id()),
            ]
        );

        $this->add_render_attribute('close-button', 'role', 'button');
        ?>
       
            <div <?php echo $this->get_render_attribute_string('close-button'); ?>>
                <?php if (isset($settings['__fa4_migrated']['close_button_icon_new']) || empty($settings['close_button_icon'])) {?>
                    <?php if (isset($settings['close_button_icon_new']['value']['url'])): ?>

                        	<div class="elementor-icon sr-offcanvas-close-svg-icon">
	                        	<?php
								Icons_Manager::render_icon( $settings['close_button_icon_new'], [ 'aria-hidden' => 'true' ] );
	                        	?>
                        	</div>

                        <!-- <img class="sr-offcanvas-close-svg-icon" src="<?php echo esc_url($settings['close_button_icon_new']['value']['url']); ?>" alt="<?php echo esc_attr(get_post_meta($settings['close_button_icon_new']['value']['id'], '_wp_attachment_image_alt', true)); ?>"> -->



                    <?php else: ?>
                        <span class="<?php echo esc_attr($settings['close_button_icon_new']['value']); ?>"></span>
                    <?php endif;?>
                <?php } else {?>
                    <span class="<?php echo esc_attr($settings['close_button_icon']); ?>"></span>
                <?php }?>
            </div>
        
        <?php
}

    /**
     * Render offcanvas content widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @access protected
     */
    protected function render()
    {
        $settings = $this->get_settings_for_display();

        $setting_attr = [
            'content_id' => esc_attr($this->get_id()),
            'direction' => esc_attr($settings['direction']),
            'transition' => esc_attr($settings['content_transition']),
            'time_transition' => esc_attr($settings['time_transition']),
            'esc_close' => esc_attr($settings['esc_close']),
            'body_click_close' => esc_attr($settings['body_click_close']),
            'open_offcanvas' => esc_attr($settings['open_offcanvas_default']),
            'class_toggle_offCanvas' => esc_attr($settings['class_toggle_offCanvas']),
        ];

        $this->add_render_attribute(
            'content-wrap',
            [
                'class' => 'sr-offcanvas-content-wrap',
                'data-settings' => htmlspecialchars(json_encode($setting_attr)),
            ]
        );

        $this->add_render_attribute(
            'content',
            [
                'class' => [
                    'sr-offcanvas-content',
                    'sr-offcanvas-content-' . esc_attr($this->get_id()),
                    'sr-offcanvas-' . $setting_attr['transition'],
                    'elementor-element-' . $this->get_id(),
                    'sr-offcanvas-content-' . $setting_attr['direction'],
                ],
            ]
        );

        $this->add_render_attribute(
            'toggle-button',
            [
                'class' => [
                    'sr-offcanvas-toggle',
                    'sr-offcanvas-toogle-' . esc_attr($this->get_id()),
                    'elementor-button',
                    //'elementor-size-' . esc_attr($settings['button_size']),
                ],
            ]
        );

        if ($settings['button_animation']) {
            $this->add_render_attribute('toggle-button', 'class', 'elementor-animation-' . esc_attr($settings['button_animation']));
        }

        ?>
        <div <?php echo $this->get_render_attribute_string('content-wrap'); ?>>

            <div class="sr-offcanvas-toggle-wrap">
                <div <?php echo $this->get_render_attribute_string('toggle-button'); ?>>
                    <?php if (isset($settings['__fa4_migrated']['selected_icon']) || empty($settings['button_icon'])) {?>
                        <?php if (isset($settings['selected_icon']['value']['url'])): ?>

                        	<div class="elementor-icon sr-offcanvas-toggle-icon sr-offcanvas-toggle-svg-icon">
	                        	<?php
								Icons_Manager::render_icon( $settings['selected_icon'], [ 'aria-hidden' => 'true' ] );
	                        	?>
                        	</div>
                            <!--<img class="sr-offcanvas-toggle-icon sr-offcanvas-toggle-svg-icon" src="<?php echo esc_url($settings['selected_icon']['value']['url']); ?>" alt="<?php echo esc_attr(get_post_meta($settings['selected_icon']['value']['id'], '_wp_attachment_image_alt', true)); ?>">-->



                        <?php else: ?>
                            <span class="sr-offcanvas-toggle-icon <?php echo esc_attr($settings['selected_icon']['value']); ?>"></span>
                        <?php endif;?>
                    <?php } else {?>
                        <span class="sr-offcanvas-toggle-icon <?php echo esc_attr($settings['button_icon']); ?>"></span>
                    <?php }?>
                    <?php if ($settings['button_text'] != ''): ?>
                        <span class="sr-toggle-text">
                            <?php echo $settings['button_text']; ?>
                        </span>
                    <?php endif;?>
                </div>
            </div>

            <div <?php echo $this->get_render_attribute_string('content'); ?>>
                <div class="sr-offcanvas-body">
                <?php $this->render_close_button();?>
                    <?php if (!empty($settings['content_template'])) {
                        if ( 'publish' == get_post_status ( $settings['content_template'] ) ) {
                            echo \Elementor\Plugin::$instance->frontend->get_builder_content_for_display($settings['content_template']);
                        }else{
                            if( current_user_can('editor') || current_user_can('administrator') )
                                echo '<br>OffCanvas template is not selected.';
                            }  
                        }
                    ?>
                </div>
            </div>
        </div>
        <?php
    }

    protected function content_template()
    {}
}
Plugin::instance()->widgets_manager->register( new SR_OffCanvas() );