<?php
namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Base;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;



/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */

class SR_ParallaxGrid extends Widget_Base {

	public function get_name() {
		return 'parallaxgrid';
	}

	public function get_title() {
		return __( 'Parallax Grid', 'elementor-sonaar' );
	}

	public function get_icon() {
		return 'eicon-gallery-grid sonaar-badge';
	}
	public function get_help_url() {
		return 'https://support.sonaar.io';
	}
	public function get_categories() {
		return [ 'elementor-sonaar' ];
	}

	public function get_script_depends() {
		return [ 'elementor-sonaar' ];
	}
	public function get_keywords() {
		return [ 'grid', 'parallax', 'artist', 'album', 'playlist', 'sonaar'];
	}
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Parallax Grid Settings', 'elementor-sonaar' ),
			]
		);
			
		$gridPostType = [
			'album' => __( 'Playlist', 'elementor-sonaar' ),
			'artist'  => __( 'Artist', 'elementor-sonaar' ),	
		];
		$defaultGridPostType = 'album';
		if( class_exists('Sonaar_Music') ){ //if mp3 player plugin is activated
			$CPTtoAdd = ['sr_playlist' => __( 'Playlist (Audio Player by Sonaar)', 'elementor-sonaar' )];
			$gridPostType = array_merge( $CPTtoAdd, $gridPostType);
			$defaultGridPostType = 'sr_playlist';
		}
				$this->add_control(
					'grid_post_type',
						[
							'label'                 => esc_html__( 'Display', 'elementor-sonaar' ),
							'type'                  => Controls_Manager::SELECT,
							'label_block'           => true,
							'options' => $gridPostType,
			                'default'               => $defaultGridPostType,
			                
			               				             	
						]
				);
			$this->add_control(
				'display_specific_playlist',
				[
					'label' => __( 'Choose your specific playlist(s)', 'plugin-domain' ),
					'description' => 'Leave blank if you want to display all your playlist',
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'yes' => __( 'Yes', 'your-plugin' ),
					'no' => __( 'No', 'your-plugin' ),
					'return_value' => 'yes',
					'default' => 'no',
					'condition' => [
						'grid_post_type' => ['album', 'sr_playlist']
					]
				]
			);
			$this->add_control(
				'playlist_list',
					[
						'label'                 => esc_html__( 'Select Playlist(s)', 'elementor-sonaar' ),
						'label_block' => true,
						'description' => 'Leave blank if you want to display all your playlist',
						'type' => \Elementor\Controls_Manager::SELECT2,
						'multiple' => true,
						'options'               => sr_elementor_select_playlist(),            	
						'condition' => [
							'display_specific_playlist' => 'yes',
							'grid_post_type' => 'album'
					]
					]
				
			);

			$this->add_control(
				'sr_playlist_list',
					[
						'label'                 => esc_html__( 'Select Playlist(s)', 'elementor-sonaar' ),
						'label_block' => true,
						'description' => 'Leave blank if you want to display all your playlist',
						'type' => \Elementor\Controls_Manager::SELECT2,
						'multiple' => true,
						'options'               => sr_elementor_select_playlist('sr_playlist'),            	
						'condition' => [
							'display_specific_playlist' => 'yes',
							'grid_post_type' => 'sr_playlist'
					]
					]
				
			);
			$this->add_control(
				'display_specific_artist',
				[
					'label' => __( 'Choose your specific artist(s)', 'plugin-domain' ),
					'description' => 'Leave blank if you want to display all your artist',
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'yes' => __( 'Yes', 'your-plugin' ),
					'no' => __( 'No', 'your-plugin' ),
					'return_value' => 'yes',
					'default' => 'no',
					'condition' => [
						'grid_post_type!' => 'sr_playlist'
					]
				]
			);
			$this->add_control(
				'artist_list',
					[
						'label'                 => esc_html__( 'Select Artist(s)', 'elementor-sonaar' ),
						'label_block' => true,
						'description' => 'Leave blank if you want to display all your artists',
						'type' => \Elementor\Controls_Manager::SELECT2,
						'multiple' => true,
						'options'               => sr_elementor_select_artist(),            	
						'condition' => [
							'display_specific_artist' => 'yes',
							'grid_post_type!' => 'sr_playlist'
					]
					]
				
			);





			$this->add_control(
				'grid_columns',
					[
						'label'                 => esc_html__( 'Columns', 'elementor-sonaar' ),
						'type'                  => Controls_Manager::SELECT,
						'label_block'           => false,
						'options' => [
									'2'  => __( '2 Columns', 'elementor-sonaar' ),
									'3' => __( '3 Columns', 'elementor-sonaar' ),
								],
		                'default'               => '3',
		                
		               				             	
					]
			);
			$this->add_control(
				'parallax_enabled',
					[
						'label'                 => esc_html__( 'Enable Parallax FX when scrolling?', 'elementor-sonaar' ),
						'type'                  => Controls_Manager::SELECT,
						'label_block'           => false,
						'options' => [
									'yes'  => __( 'Yes', 'elementor-sonaar' ),
									'no' => __( 'No', 'elementor-sonaar' ),
								],
		                'default'               => 'yes',
		                
		               				             	
					]
			);
		
			$this->add_control(
				'parallax_speed',
					[
						'label' 		=> __( 'Speed of your parallax', 'elementor-sonaar' ),
						'label_block'	=> false,
						'type' 			=> \Elementor\Controls_Manager::TEXT,
						'placeholder'	=> __( '2, -2, 1', 'elementor-sonaar' ),
						'default'		=> '2, -2, 1',
						'condition' => [
							'parallax_enabled' => 'yes',
							
					]
					]
			);


		$this->end_controls_section();


		 /**
        * STYLE: STYLE
        * -------------------------------------------------
        */
		
		//-- CONTENT
		$this->start_controls_section(
            'container_style',
            [
                'label'                 => __( 'Container', 'elementor-sonaar' ),
                'tab'                   => Controls_Manager::TAB_STYLE,
            ]
		);
		$this->add_responsive_control(
			'container_padding',
			[
				'label' => __( 'Container Padding', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sr_it-grid article header' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'container_h_align',
			[
				'label' => __( 'Horizontal Alignment', 'elementor-sonaar' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'elementor' ),
						'icon' => 'eicon-h-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'elementor' ),
						'icon' => 'eicon-h-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'elementor' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .sr_it-grid article .entry-header, {{WRAPPER}} .sr_it-grid article .author' => 'text-align: {{VALUE}};',
				],
			]
		);
		$this->add_responsive_control(
			'container_v_align',
			[
				'label' => __( 'Vertical Alignment', 'elementor-sonaar' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'100' => [
						'title' => __( 'top', 'elementor' ),
						'icon' => 'eicon-v-align-top',
					],
					'50' => [
						'title' => __( 'middle', 'elementor' ),
						'icon' => 'eicon-v-align-middle',
					],
					'0' => [
						'title' => __( 'Bottom', 'elementor' ),
						'icon' => 'eicon-v-align-bottom',
					],
				],
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .sr_it-grid article header' => 'bottom: {{VALUE}}%; transform: translateY( {{VALUE}}% );',
				],
			]
		);
		$this->end_controls_section();

		//-- RELEASE DATE
		$this->start_controls_section(
			'release_date',
			[
				'label'                 => __( 'Release Date', 'elementor-sonaar' ),
				'tab'                   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'grid_post_type' => 'album'
				],
            ]
		);
		$this->add_control(
			'release_date_color',
			[
				'label'                 => __( 'Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .sr_it-grid article .sr_it-meta .entry-date' => 'color: {{VALUE}}; border-color:{{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'release_date_typography',
				'label' => __( 'Typography', 'elementor-sonaar' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .sr_it-grid article .sr_it-meta .entry-date',
			]
		);
		$this->add_responsive_control(
			'release_date_padding',
			[
				'label' => __( 'Padding', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sr_it-grid article .sr_it-meta .entry-date' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'release_date_margin',
			[
				'label' => __( 'Margin', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sr_it-grid article .sr_it-meta .entry-date' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'release_date_border_type',
				[
					'label'                 => esc_html__( 'Border Type', 'elementor-sonaar' ),
					'type'                  => Controls_Manager::SELECT,
					'options' => [
								'none'  => __( 'None', 'elementor' ),
								'solid' => __( 'Solid', 'elementor' ),
								'double' => __( 'Double', 'elementor' ),
								'dotted' => __( 'Dotted', 'elementor' ),
								'dashed' => __( 'Dashed', 'elementor' ),
								'groove' => __( 'Groove', 'elementor' )
							],
					'default'               => 'solid',
					'selectors'             => [
						'{{WRAPPER}} .sr_it-grid article .sr_it-meta .entry-date' => 'border-bottom-style: {{VALUE}}',
					],													
				]
		);
		$this->add_responsive_control(
			'release_date_border_width',
			[
				'label' => __( 'Border Width', 'sonaar-elementor' ) . ' (px)',
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 10,
					],
				],
				'default' => [
					'size' => 1,
					],
				'selectors' => [
					'{{WRAPPER}} .sr_it-grid article .sr_it-meta .entry-date' => '    border-bottom-width: {{SIZE}}px', 
				],
				'condition' => [
					'release_date_border_type!' => 'none',
				] 
			]
		);
		$this->end_controls_section();


		//-- TITLE
		$this->start_controls_section(
			'title',
			[
				'label'                 => __( 'Title', 'elementor-sonaar' ),
				'tab'                   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'title_color',
			[
				'label'                 => __( 'Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .sr_it-grid article .sr_it-item-title' => 'color: {{VALUE}}; border-color:{{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => __( 'Typography', 'elementor-sonaar' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .sr_it-grid article .sr_it-item-title',
			]
		);
		$this->add_responsive_control(
			'title_padding',
			[
				'label' => __( 'Padding', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sr_it-grid article .sr_it-item-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'title_margin',
			[
				'label' => __( 'Margin', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sr_it-grid article .sr_it-item-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'title_border_type',
				[
					'label'                 => esc_html__( 'Border Type', 'elementor-sonaar' ),
					'type'                  => Controls_Manager::SELECT,
					'options' => [
								'none'  => __( 'None', 'elementor' ),
								'solid' => __( 'Solid', 'elementor' ),
								'double' => __( 'Double', 'elementor' ),
								'dotted' => __( 'Dotted', 'elementor' ),
								'dashed' => __( 'Dashed', 'elementor' ),
								'groove' => __( 'Groove', 'elementor' )
							],
					'default'               => 'none',
					'selectors'             => [
						'{{WRAPPER}} .sr_it-grid article .sr_it-item-title' => 'border-bottom-style: {{VALUE}}',
					],													
				]
		);
		$this->add_responsive_control(
			'title_border_width',
			[
				'label' => __( 'Border Width', 'sonaar-elementor' ) . ' (px)',
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 10,
					],
				],
				'default' => [
					'size' => 1,
					],
				'selectors' => [
					'{{WRAPPER}} .sr_it-grid article .sr_it-item-title' => '    border-bottom-width: {{SIZE}}px', 
				],
				'condition' => [
					'title_border_type!' => 'none',
				] 
			]
		);
		$this->end_controls_section();

		//-- ARTIST NAME
		$this->start_controls_section(
			'artist',
			[
				'label'                 => __( 'Artist Name', 'elementor-sonaar' ),
				'tab'                   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'grid_post_type' => 'album'
				],
			]
		);
		$this->add_control(
			'artist_color',
			[
				'label'                 => __( 'Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .sr_it-grid article .author' => 'color: {{VALUE}}; border-color:{{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'artist_typography',
				'label' => __( 'Typography', 'elementor-sonaar' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .sr_it-grid article .author',
			]
		);
		$this->add_responsive_control(
			'artist_padding',
			[
				'label' => __( 'Padding', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sr_it-grid article .author' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'artist_margin',
			[
				'label' => __( 'Margin', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sr_it-grid article .author' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_control(
			'artist_border_type',
				[
					'label'                 => esc_html__( 'Border Type', 'elementor-sonaar' ),
					'type'                  => Controls_Manager::SELECT,
					'options' => [
								'none'  => __( 'None', 'elementor' ),
								'solid' => __( 'Solid', 'elementor' ),
								'double' => __( 'Double', 'elementor' ),
								'dotted' => __( 'Dotted', 'elementor' ),
								'dashed' => __( 'Dashed', 'elementor' ),
								'groove' => __( 'Groove', 'elementor' )
							],
					'default'               => 'none',
					'selectors'             => [
						'{{WRAPPER}} .sr_it-grid article .author' => 'border-bottom-style: {{VALUE}}',
					],													
				]
		);
		$this->add_responsive_control(
			'artist_border_width',
			[
				'label' => __( 'Border Width', 'sonaar-elementor' ) . ' (px)',
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 10,
					],
				],
				'default' => [
					'size' => 1,
					],
				'selectors' => [
					'{{WRAPPER}} .sr_it-grid article .author' => '    border-bottom-width: {{SIZE}}px', 
				],
				'condition' => [
					'artist_border_type!' => 'none',
				] 
			]
		);
		$this->end_controls_section();



		//-- BUTTON
		$this->start_controls_section(
			'button',
				[
					'label' => __( 'Button', 'sonaar-elementor' ),
					'tab' => Controls_Manager::TAB_STYLE,
					'condition' => [
						'grid_post_type' => 'album'
					],
				]
			);		

			$this->add_group_control(
				Group_Control_Typography::get_type(),
					[
						'name' => 'button_typography',
						'label' => __( 'Typography', 'elementor-sonaar' ),
						'scheme' => Typography::TYPOGRAPHY_1,
						'selector' => '{{WRAPPER}} .sr_it-grid article button',
					]
			);
			$this->add_control(
			'hr6',
				[
					'type' => \Elementor\Controls_Manager::DIVIDER,
					'style' => 'default',
				]
			);
			$this->start_controls_tabs( 'button_tabs' );

				// Normal State Tab
				$this->start_controls_tab( 'button_normal', [ 'label' => esc_html__( 'Normal', 'sonaar-elementor' ) ] );

					$this->add_control(
						'button_normal_text_color',
						[
							'label' => esc_html__( 'Text Color', 'sonaar-elementor' ),
							'type' => Controls_Manager::COLOR,
							'default' => '',
							'selectors' => [
								'{{WRAPPER}} .sr_it-grid article button' => 'color: {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'button_normal_bg_color',
						[
							'label' => esc_html__( 'Background Color', 'sonaar-elementor' ),
							'type' => Controls_Manager::COLOR,
							'default' => '',
							'selectors' => [
								'{{WRAPPER}} .sr_it-grid article button' => 'background: {{VALUE}};',
							],
						]
					);

					$this->add_group_control(
						Group_Control_Border::get_type(),
						[
							'name' => 'button_normal_border',
							'label' => esc_html__( 'Border', 'sonaar-elementor' ),
							'selector' => '{{WRAPPER}} .sr_it-grid article button',
						]
					);

					$this->add_group_control(
						Group_Control_Box_Shadow::get_type(),
						[
							'name' => 'button_shadow',
							'selector' => '{{WRAPPER}} .sr_it-grid article button',
							'separator' => 'before'
						]
					);
				$this->end_controls_tab();

				// Hover State Tab
				$this->start_controls_tab( 'button_hover', [ 'label' => esc_html__( 'Hover', 'sonaar-elementor' ) ] );

					$this->add_control(
						'button_hover_text_color',
						[
							'label' => esc_html__( 'Text Color', 'sonaar-elementor' ),
							'type' => Controls_Manager::COLOR,
							'default' => '#fff',
							'selectors' => [
								'{{WRAPPER}} .sr_it-grid article button:hover' => 'color: {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'button_hover_bg_color',
						[
							'label' => esc_html__( 'Background Color', 'sonaar-elementor' ),
							'type' => Controls_Manager::COLOR,
							'default' => '#27bdbd',
							'selectors' => [
								'{{WRAPPER}} .sr_it-grid article button:hover' => 'background: {{VALUE}};',
							],
						]
					);

					$this->add_control(
						'button_hover_border_color',
						[
							'label' => esc_html__( 'Border Color', 'sonaar-elementor' ),
							'type' => Controls_Manager::COLOR,
							'default' => '',
							'selectors' => [
								'{{WRAPPER}} .sr_it-grid article button:hover' => 'border-color: {{VALUE}};',
							],
						]

					);
					$this->add_group_control(
						Group_Control_Box_Shadow::get_type(),
						[
							'name' => 'button_hover_shadow',
							'selector' => '{{WRAPPER}} .sr_it-grid article button:hover',
							'separator' => 'before'
						]
					);
				$this->end_controls_tab();
	
				$this->end_controls_tabs();
				$this->add_control(
				'hr7',
					[
						'type' => \Elementor\Controls_Manager::DIVIDER,
						'style' => 'default',
					]
				);

				$this->add_control(
							'button_border_radius',
							[
								'label' => esc_html__( 'Border Radius', 'sonaar-elementor' ),
								'type' => Controls_Manager::SLIDER,
								'range' => [
									'px' => [
										'max' => 100,
									],
								],
								'selectors' => [
									'{{WRAPPER}} .sr_it-grid article button' => 'border-radius: {{SIZE}}px;',
								],
							]
				);
				$this->add_responsive_control(
					'button_padding',
					[
						'label' => esc_html__( 'Padding', 'sonaar-elementor' ),
						'type' => Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', 'em', '%' ],
						'selectors' => [
									'{{WRAPPER}} .sr_it-grid article button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							],
					]
				);

				$this->add_responsive_control(
					'button_margin',
					[
						'label' => esc_html__( 'Margin', 'sonaar-elementor' ),
						'type' => Controls_Manager::DIMENSIONS,
						'size_units' => [ 'px', 'em', '%' ],
						'selectors' => [
									'{{WRAPPER}} .sr_it-grid article button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							],
					]
				);
	
			$this->end_controls_section();	

	}

	protected function render() {
			$settings = $this->get_settings_for_display();
			$album_numbers ="";
			$artist_numbers ="";

			if($settings['parallax_enabled']=='no'){
				$settings['parallax_enabled']="0";
				$settings['parallax_speed']="0,0,0";
			}

			if($settings['grid_post_type'] == 'sr_playlist'){
				$playlist_list = $settings['sr_playlist_list'];
			}else{
				$playlist_list = $settings['playlist_list'];
			}
			if(is_array($playlist_list)){
				$playlist_list = implode(", ", $playlist_list); 
				$album_numbers = ' albums="' . $playlist_list . '" ';
			}

			$artist_list = $settings['artist_list'];
			if(is_array($artist_list)){
				$artist_list = implode(", ", $artist_list);
				$artist_numbers = ' artists_filter="' . $artist_list . '" ';
			}

			$shortcode = '[iron_grid grip_post_type="' . $settings['grid_post_type'] . '" grid_filter_artists="' . $settings['display_specific_artist'] . '" grid_filter_albums="' . $settings['display_specific_playlist'] . '" ' . $album_numbers .'" ' . $artist_numbers . '" column="' . $settings['grid_columns'] . '" parallax="' . $settings['parallax_enabled'] . '" parallax_speed="' . $settings['parallax_speed'] . '"]';

		echo do_shortcode( $shortcode );
		
	}
	public function render_plain_content() {
			$settings = $this->get_settings_for_display();
			$album_numbers ="";
			$artist_numbers ="";

			if($settings['parallax_enabled']=='no'){
				$settings['parallax_enabled']="0";
				$settings['parallax_speed']="0,0,0";
			}

			$playlist_list = $settings['playlist_list'];
			if(is_array($playlist_list)){
				$playlist_list = implode(", ", $playlist_list); 
				$album_numbers = ' albums="' . $playlist_list . '" ';
			}

			$artist_list = $settings['artist_list'];
			if(is_array($artist_list)){
				$artist_list = implode(", ", $artist_list);
				$artist_numbers = ' artists_filter="' . $artist_list . '" ';
			}

			$shortcode = '[iron_grid grip_post_type="' . $settings['grid_post_type'] . '" grid_filter_artists="' . $settings['display_specific_artist'] . '" grid_filter_albums="' . $settings['display_specific_playlist'] . '" ' . $album_numbers .'" ' . $artist_numbers . '" column="' . $settings['grid_columns'] . '" parallax="' . $settings['parallax_enabled'] . '" parallax_speed="' . $settings['parallax_speed'] . '"]';

		echo $shortcode;
	}

	
}
Plugin::instance()->widgets_manager->register( new SR_ParallaxGrid() );