<?php
namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Base;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;



/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */

class SR_Podcast_Archive extends Widget_Base {

	public function get_name() {
		return 'podcast-archive';
	}

	public function get_title() {
		return __( 'Podcast Archive', 'elementor-sonaar' );
	}

	public function get_icon() {
		return 'eicon-bullet-list sonaar-badge';
	}
	public function get_help_url() {
		return 'https://support.sonaar.io';
	}
	public function get_categories() {
		return [ 'elementor-sonaar' ];
	}

	public function get_script_depends() {
		return [ 'elementor-sonaar' ];
	}
	public function get_keywords() {
		return [ 'mp3', 'player', 'audio', 'podcast', 'radio' ,'stream', 'episode', 'archive', 'list', 'sonaar'];
	}
	protected function register_controls() {

		/**
        * STYLE: CONTENT
        * -------------------------------------------------
        */

		//-- PODCAST ARCHIVE SETTINGS
		$this->start_controls_section(
			'podcast_archive_content',
			[
				'label' => __( 'Podcast Archive Settings', 'elementor-sonaar' ),
			]
		);
		$this->add_control(
			'display_specific_category',
			[
				'label' 			=> __( 'Choose specific category', 'elementor-sonaar' ),
				'type' 				=> \Elementor\Controls_Manager::SWITCHER,
			]
		);
		$this->add_control(
			'category_list',
				[
					'label'			=> esc_html__( 'Select Category', 'elementor-sonaar' ),
					'label_block' 	=> true,
					'type'          => \Elementor\Controls_Manager::SELECT2,
					'multiple' 		=> true,
					'label_block'	=> true,
					'options'		=> sr_elementor_select_category('podcast-category'),
					'condition'		=> ['display_specific_category' => 'yes']
				]
		);
		$this->add_control(
			'episode_number_to_show',
			[
				'label' => __( 'Number of Episodes per Page', 'elementor-sonaar' ),
				'description' => esc_html__( 'Set this setting to -1 to display All', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => -1,
				'max' => 100,
				'step' => 1,
				'default' => 50,
			]
		);
		$this->add_control(
			'hide_artwork',
			[
				'label' => __( 'Hide Thumbnail', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'elementor-sonaar' ),
				'label_off' => __( 'No', 'elementor-sonaar' ),
				'return_value' => '1',
				'default' => '0',
			]
		);
		$this->add_control(
			'hide_duration',
			[
				'label' => __( 'Hide Duration', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'elementor-sonaar' ),
				'label_off' => __( 'No', 'elementor-sonaar' ),
				'return_value' => '1',
				'default' => '0',
			]
		);
		$this->add_control(
			'hide_date',
			[
				'label' => __( 'Hide Date', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'elementor-sonaar' ),
				'label_off' => __( 'No', 'elementor-sonaar' ),
				'return_value' => '1',
				'default' => '0',
			]
		);
		$this->add_control(
			'hide_category',
			[
				'label' => __( 'Hide Category', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'elementor-sonaar' ),
				'label_off' => __( 'No', 'elementor-sonaar' ),
				'return_value' => '1',
				'default' => '0',
			]
		);
		$this->add_control(
			'hide_excerpt',
			[
				'label' => __( 'Hide Excerpt', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'elementor-sonaar' ),
				'label_off' => __( 'No', 'elementor-sonaar' ),
				'return_value' => '1',
				'default' => '0',
			]
		);
		$this->add_control(
			'hide_pagination',
			[
				'label' => __( 'Hide Pagination', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'elementor-sonaar' ),
				'label_off' => __( 'No', 'elementor-sonaar' ),
				'return_value' => '1',
				'default' => '1',
			]
		);
		$this->end_controls_section();

		//-- ADVANCED
		$this->start_controls_section(
			'advanced_content',
			[
				'label' => __( 'Advanced', 'elementor-sonaar' ),
			]
		);
		$this->add_control(
			'maximum_episodes',
			[
				'label' => __( 'Maximum Episodes', 'elementor-sonaar' ),
				'description' => esc_html__( 'Set this setting to -1 to display All', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => -1,
				'max' => 1000,
				'step' => 1,
				'default' => -1,
			]
		);
		$this->add_control(
			'excerpt_lenght',
			[
				'label' => __( 'Excerpt Lenght', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 100000,
				'step' => 1,
				'condition' => [
					'hide_excerpt!' => '1',
				],
			]
		);
		$this->add_control(
			'strip_html_excerpt',
			[
				'label' => __( 'Strip HTML', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'elementor-sonaar' ),
				'label_off' => __( 'No', 'elementor-sonaar' ),
				'return_value' => '1',
				'default' => '0',
			]
		);
		$this->add_control(
			'disable_post_link',
			[
				'label' => __( 'Disable Redirection to Single Page', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'elementor-sonaar' ),
				'label_off' => __( 'No', 'elementor-sonaar' ),
				'return_value' => '1',
				'default' => '0',
			]
		);
		
		$this->end_controls_section();



        /**
        * STYLE: STYLE
        * -------------------------------------------------
        */
		
		//-- TYPOGRAPHY
		$this->start_controls_section(
            'typography_style',
            [
                'label'                 => __( 'Typography & Colors', 'elementor-sonaar' ),
                'tab'                   => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_control(
			'text_color',
			[
				'label'                 => __( 'Text Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .sonaar-podcast-list-item .sr_it-item-title, {{WRAPPER}} .sonaar-podcast-list-item, {{WRAPPER}} .sonaar-date, {{WRAPPER}} .sonaar-category a, {{WRAPPER}} .sonaar-podcast-list-description li'  => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'title_color',
			[
				'label'                 => __( 'Title Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} article.sonaar-podcast-list-item a .sr_it-item-title'  => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_group_control(
		Group_Control_Typography::get_type(),
		[
			'name' => 'title_typography',
			'label' => __( 'Title Typography', 'elementor-sonaar' ),
			'scheme' => Typography::TYPOGRAPHY_1,
			'selector' => '{{WRAPPER}} .sonaar-podcast-list-item .sr_it-item-title',
		]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'excerpt_typography',
				'label' => __( 'Excerpt Typography', 'elementor-sonaar' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .sonaar-podcast-list-description',
				'condition' => [
					'hide_excerpt!' => '1',
				],
			]
		);
		$this->add_control(
			'meta_color',
			[
				'label'                 => __( 'Meta Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .meta-podcast, {{WRAPPER}} .meta-podcast a, {{WRAPPER}} .sonaar-date'  => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'meta_typography',
				'label' => __( 'Meta Typography', 'elementor-sonaar' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .sonaar-category, {{WRAPPER}} .meta-podcast .sonaar-date, {{WRAPPER}} .meta-podcast .sonaar-duration',
			]
		);
		$this->end_controls_section();


		//-- THUMPNAIL
		$this->start_controls_section(
            'image_style',
            [
                'label'                 => __( 'Thumbnail', 'elementor-sonaar' ),
				'tab'                   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'hide_artwork!' => '1',
				],
            ]
		);
		$this->add_responsive_control(
			'image_width',
			[
				'label' => __( 'Thumbnail Width', 'elementor-sonaar' ),
				'size_units' => [ 'px', '%' ],
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 500,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sonaar-podcast-list-img' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'border_thumbnail',
				'selector' => '{{WRAPPER}} .sonaar-podcast-list-img img',
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'thumbnail_border_radius',
			[
				'label' => __( 'Thumbnail Border Radius', 'elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sonaar-podcast-list-img img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'thumbnail_margin',
			[
				'label' => __( 'Thumbnail Margin', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sonaar-podcast-list-img' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);
		$this->add_control(
			'hide_thumbnail_mobile',
			[
				'label' => __( 'Hide Thumbnail On Mobile', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Hide', 'elementor-sonaar' ),
				'label_off' => __( 'SHOW', 'elementor-sonaar' ),
				'return_value' => 'none',
				'default' => 'table',
				'selectors' => [
					'(mobile){{WRAPPER}} .sonaar-podcast-list-img img' => 'display:{{VALUE}};',
			],
				'separator' => 'before',
			]
		);
		$this->end_controls_section();


		//-- PLAY BUTTON STYLE
		
		$this->start_controls_section(
			'play_button_style',
			[
				'label'                 => __( 'Play Button', 'elementor-sonaar' ),
				'tab'                   => Controls_Manager::TAB_STYLE,
			]
		);


		$this->start_controls_tabs( 'tabs_button_style_play_button' );
		$this->start_controls_tab(
			'tab_button_normal_play_button',
			[
				'label' => __( 'Normal', 'elementor' ),
			]
		);
		$this->add_control(
			'button_play_color',
			[
				'label'                 => __( 'Button Play Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .sonaar-play-button .sonaar-play-circle circle' => 'stroke: {{VALUE}}',
					'{{WRAPPER}} .sonaar-play-button rect, {{WRAPPER}} .sonaar-play-button path, {{WRAPPER}} .sonaar-play-button polygon' => 'fill: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'Button_play_background',
			[
				'label'                 => __( 'Button Play Background Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .sonaar-play-button .sonaar-play-circle circle, {{WRAPPER}} .sonaar-podcast-list-item.sr-button-left:not(.no-image) .sonaar-play-button .sonaar-play-circle circle'  => 'fill: {{VALUE}}',
				],
			]
		);
		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover_play_button',
			[
				'label' => __( 'Hover', 'elementor' ),
			]
		);
		$this->add_control(
			'button_play_color_hover',
			[
				'label'                 => __( 'Button Play Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .sonaar-play-button:hover .sonaar-play-circle circle' => 'stroke: {{VALUE}}',
					'{{WRAPPER}} .sonaar-play-button:hover rect, {{WRAPPER}} .sonaar-play-button:hover path, {{WRAPPER}} .sonaar-play-button:hover polygon' => 'fill: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'Button_play_background_hover',
			[
				'label'                 => __( 'Button Play Background Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .sonaar-play-button:hover .sonaar-play-circle circle, {{WRAPPER}} .sonaar-podcast-list-item.sr-button-left:not(.no-image) .sonaar-play-button:hover .sonaar-play-circle circle'  => 'fill: {{VALUE}}',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();


		$this->add_responsive_control(
			'play_button_width',
			[
				'label' => esc_html__( 'Play Button Width', 'essential-addons-elementor' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 300,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sonaar-play-button' => 'width: {{SIZE}}px; height: {{SIZE}}px;',
					'{{WRAPPER}} .sr-button-right .sonaar-play-button-box' => 'right: calc({{SIZE}}px + 40px);',
				],
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'play_icon_width',
			[
				'label' => esc_html__( 'Control Icon Width', 'essential-addons-elementor' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 250,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sonaar-play-button .sonaar-play-icon' => 'width: {{SIZE}}px; height: {{SIZE}}px;',
				],
			]
		);
		$this->add_responsive_control(
			'play_border_width',
			[
				'label' => esc_html__( 'Border Width', 'essential-addons-elementor' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sonaar-play-button .sonaar-play-circle circle' => 'stroke-width: {{SIZE}};',
				],
			]
		);
		$this->add_control(
			'play_button_location',
				[
					'label'                 => __( 'Play Button Location', 'elementor-sonaar' ),
					'type'                  => Controls_Manager::SELECT,
					'label_block'           => false,
					'options' => [
								'right'  => __( 'Right', 'elementor-sonaar' ),
								'left' => __( 'Left', 'elementor-sonaar' ),
							],
					'default'               => 'right',	
					'separator' => 'before',					
				]
		);
		$this->add_responsive_control(
			'play_button_offset_x',
			[
				'label' => __( 'Horizontal Offset', 'elementor' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => -1000,
						'max' => 1000,
						'step' => 1,
					],
				],
				'default' => [
					'size' => '0',
				],
				'selectors' => [
					'{{WRAPPER}} .sr-button-right .sonaar-play-button' => 'left: {{SIZE}}px;',
					'{{WRAPPER}} .sr-button-left .sonaar-play-button' => 'right: calc({{SIZE}}px * -1);',
					'(mobile){{WRAPPER}} .sr-button-right .sonaar-play-button' => 'right: calc(50% - {{SIZE}}px); left: unset;',
					'(mobile){{WRAPPER}} .sr-button-left .sonaar-play-button' => 'right: calc(50% - {{SIZE}}px); left: unset;',
				],
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'play_button_offset_y',
			[
				'label' => __( 'Vertical Offset', 'elementor' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => -500,
						'max' => 500,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'size_units' => [ '%', 'px' ],
				'default' => [
					'size' => '50',
					'unit' => '%',
				],
				'selectors' => [
					'{{WRAPPER}} .sr-button-right .sonaar-play-button-box' => 'top: {{SIZE}}{{UNIT}};',
					'(mobile){{WRAPPER}} .sr-button-right .sonaar-play-button' => 'top: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .sr-button-left.no-image .sonaar-podcast-list-img' => 'top: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .sr-button-left:not(.no-image) .sonaar-play-button' => 'top: {{SIZE}}{{UNIT}};',
				],
			]
		);
	
		$this->end_controls_section();


		//-- CTA BUTTON STYLE

		$this->start_controls_section(
			'button_style',
			[
				'label'                 => __( 'CTA Button', 'elementor-sonaar' ),
				'tab'                   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'label' => __( 'Button Typography', 'elementor-sonaar' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .sonaar-callToAction',
			]
		);

		$this->start_controls_tabs( 'tabs_button_style' );

		$this->start_controls_tab(
			'tab_button_normal',
			[
				'label' => __( 'Normal', 'elementor' ),
			]
		);

		$this->add_control(
			'button_text_color',
			[
				'label' => __( 'Button Text Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .sonaar-callToAction' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_background_color',
			[
				'label' => __( 'Button Background Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sonaar-callToAction' => 'background: {{VALUE}}',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => __( 'Hover', 'elementor' ),
			]
		);

		$this->add_control(
			'button_hover_color',
			[
				'label' => __( 'Button Text Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sonaar-callToAction:hover' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'button_background_hover_color',
			[
				'label' => __( 'Button Background Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sonaar-callToAction:hover' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'button_hover_border_color',
			[
				'label' => __( 'Button Border Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'border_border!' => '',
				],
				'selectors' => [
					'{{WRAPPER}} .sonaar-callToAction:hover' => 'border-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'border',
				'selector' => '{{WRAPPER}} .sonaar-callToAction',
				'separator' => 'before',
			]
		);
		$this->add_control(
			'button_border_radius',
			[
				'label' => __( 'Button Border Radius', 'elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sonaar-callToAction' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'button_box_shadow',
				'selector' => '{{WRAPPER}} .sonaar-callToAction',
			]
		);
		$this->add_responsive_control(
			'button_padding',
			[
				'label' => __( 'Button Padding', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sonaar-callToAction' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'button_container_margin',
			[
				'label' => __( 'Button Container Margin', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sonaar-callToAction-box' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'space_between_store_button',
			[
				'label' => __( 'Buttons Space', 'sonaar-elementor' ) . ' (px)',
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 500,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sonaar-callToAction+.sonaar-callToAction' => 'margin-left: {{SIZE}}px;', 
				],
			]
		);
		$this->add_control(
			'hr1',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
				'style' => 'thick',
			]
		);
		$this->end_controls_section();


        //-- CONTAINER STYLE

		$this->start_controls_section(
            'container_style',
            [
                'label'                 => __( 'Container', 'elementor-sonaar' ),
                'tab'                   => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
		Group_Control_Background::get_type(),
		[
			'name' => 'background',
			'label' => __( 'Background', 'elementor-sonaar' ),
			'types' => [ 'classic', 'gradient'],
			'selector' => '{{WRAPPER}} .sonaar-podcast-list-item',
		]
		);

		$this->add_responsive_control(
			'container_padding',
			[
				'label' => esc_html__( 'Container Padding', 'essential-addons-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
						'{{WRAPPER}} .sonaar-podcast-list-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'content_padding',
			[
				'label' => esc_html__( 'Content Padding', 'essential-addons-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
						'{{WRAPPER}} .sonaar-podcast-list-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'item_spacing',
			[
				'label' => esc_html__( 'Item Spacing', 'essential-addons-elementor' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sonaar-podcast-list-item' => 'margin-bottom: {{SIZE}}px;',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'container_border',
				'label' => esc_html__( 'Border', 'essential-addons-elementor' ),
				'selector' => '{{WRAPPER}} .sonaar-podcast-list-item',
			]
		);

		$this->add_responsive_control(
			'sr_dch_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'essential-addons-elementor' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 500,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sonaar-podcast-list-item' => 'border-radius: {{SIZE}}px;',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'sr_dch_shadow',
				'selector' => '{{WRAPPER}} .sonaar-podcast-list-item',
			]
		);
		$this->end_controls_section();


		//-- PAGINATION STYLE

		$this->start_controls_section(
            'pagination_style',
            [
                'label'                 => __( 'Pagination', 'elementor-sonaar' ),
				'tab'                   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'hide_pagination!' => '1',
				],
            ]
		);

		$this->add_control(
			'prev_button_text',
			[
				'label' => __( 'Previous Button Label', 'sonaar-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'default' => '',
				'label_block' => false,
			]
		);

		$this->add_control(
			'next_button_text',
			[
				'label' => __( 'Next Button Label', 'sonaar-elementor' ),
				'type' => Controls_Manager::TEXT,
				'dynamic' => [
					'active' => true,
				],
				'default' => '',
				'label_block' => false,
			]
		);

		$this->add_responsive_control(
			'pagination_align',
			[
				'label' => __( 'Pagination Alignment', 'elementor-sonaar' ),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __( 'Left', 'elementor' ),
						'icon' => 'eicon-h-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'elementor' ),
						'icon' => 'eicon-h-align-center',
					],
					'right' => [
						'title' => __( 'Right', 'elementor' ),
						'icon' => 'eicon-h-align-right',
					],
				],
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .sonaar-pagination' => 'text-align: {{VALUE}};',
				],
				'separator' => 'before',
			]
		);

		$this->add_control(
			'min_height_widget',
			[
				'label' => __( 'Min Height Of The Widget', 'elementor-sonaar' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 2000,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .list' => 'min-height: {{SIZE}}px;',
				],
			]
		);

		$this->add_control(
			'hr',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
				'style' => 'default',
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'pagination_button_typography',
				'label' => __( 'Button Typography', 'elementor-sonaar' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .sonaar-pagination button',
			]
		);

		$this->start_controls_tabs( 'tabs_pagination_button_style' );

		$this->start_controls_tab(
			'tab_pagination_button_normal',
			[
				'label' => __( 'Normal', 'elementor' ),
			]
		);

		$this->add_control(
			'pagination_button_text_color',
			[
				'label' => __( 'Button Text Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .sonaar-pagination button' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'pagination_button_background_color',
			[
				'label' => __( 'Button Background Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sonaar-pagination button' => 'background: {{VALUE}}',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_pagination_button_hover',
			[
				'label' => __( 'Hover', 'elementor' ),
			]
		);

		$this->add_control(
			'pagination_button_hover_color',
			[
				'label' => __( 'Button Text Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sonaar-pagination button:hover' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'pagination_button_background_hover_color',
			[
				'label' => __( 'Button Background Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sonaar-pagination button:hover' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'pagination_button_hover_border_color',
			[
				'label' => __( 'Button Border Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'border_border!' => '',
				],
				'selectors' => [
					'{{WRAPPER}} .sonaar-pagination button:hover' => 'border-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'pagination_border',
				'selector' => '{{WRAPPER}} .sonaar-pagination button',
				'separator' => 'before',
			]
		);
		$this->add_control(
			'pagination_button_border_radius',
			[
				'label' => __( 'Button Border Radius', 'elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sonaar-pagination button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'pagination_button_box_shadow',
				'selector' => '{{WRAPPER}} .sonaar-pagination button',
			]
		);
		$this->add_responsive_control(
			'pagination_button_padding',
			[
				'label' => __( 'Button Padding', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sonaar-pagination button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'pagination_button_margin',
			[
				'label' => __( 'Button Margin', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sonaar-pagination button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
		'pagination_padding',
		[
			'label' => __( 'Pagination Container Padding', 'elementor-sonaar' ),
			'type' => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'{{WRAPPER}} .sonaar-pagination' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'separator' => 'before',
		]
	);
		$this->end_controls_section();
	}

	
	protected function render() {
		$settings = $this->get_settings();
		$numberOfEpisodes = $settings['episode_number_to_show'];
		$maximumEpisodes = $settings['maximum_episodes'];
		$playButtonLocation = $settings['play_button_location'];
		$hide_artwork = $settings['hide_artwork'];
		$hide_duration = $settings['hide_duration'];
		$hide_date = $settings['hide_date'];
		$hide_category = $settings['hide_category'];
		$hide_excerpt = $settings['hide_excerpt'];
		$hide_pagination = $settings['hide_pagination'];
		$category_list = $settings['category_list'];
		$excerpt_lenght = $settings['excerpt_lenght'];
		$strip_html_excerpt = $settings['strip_html_excerpt'];
		$disable_post_link = $settings['disable_post_link'];
		$next_button_text = $settings['next_button_text'];
		$prev_button_text = $settings['prev_button_text'];
		
		if(is_array($category_list)){
			$category_list = implode(", ", $category_list); 
		}
		if($settings['display_specific_category']!='yes' || $category_list == ''){
			$category_list = 'all-categories';
		};

		
		echo do_shortcode( '[iron_podcast_archive category="' . $category_list .'" number-of-episode="' . $numberOfEpisodes . '" maximum-episodes="' . $maximumEpisodes . '" play-location="' . $playButtonLocation . '" hide-artwork="' . $hide_artwork . '" hide-duration="' . $hide_duration . '" hide-date="' . $hide_date . '" hide-category="' . $hide_category . '" hide-excerpt="' . $hide_excerpt . '" hide-pagination="' . $hide_pagination . '" strip-html-excerpt="' . $strip_html_excerpt . '" excerpt-lenght="' . $excerpt_lenght . '" disable-post-link="' . $disable_post_link . '" next-button-text="' . $next_button_text . '" prev-button-text="' . $prev_button_text . '" ]');
	}
	public function render_plain_content() {
		$settings = $this->get_settings();
		$numberOfEpisodes = $settings['episode_number_to_show'];
		$maximumEpisodes = $settings['maximum_episodes'];
		$playButtonLocation = $settings['play_button_location'];
		$hide_artwork = $settings['hide_artwork'];
		$hide_duration = $settings['hide_duration'];
		$hide_date = $settings['hide_date'];
		$hide_category = $settings['hide_category'];
		$hide_excerpt = $settings['hide_excerpt'];
		$hide_pagination = $settings['hide_pagination'];
		$category_list = $settings['category_list'];
		$excerpt_lenght = $settings['excerpt_lenght'];
		$strip_html_excerpt = $settings['strip_html_excerpt'];
		$disable_post_link = $settings['disable_post_link'];
		$next_button_text = $settings['next_button_text'];
		$prev_button_text = $settings['prev_button_text'];
		
		if(is_array($category_list)){
			$category_list = implode(", ", $category_list); 
		}
		if($settings['display_specific_category']!='yes' || $category_list == ''){
			$category_list = 'all-categories';
		};


		echo do_shortcode( '[iron_podcast_archive category="' . $category_list .'" number-of-episode="' . $numberOfEpisodes . '" maximum-episodes="' . $maximumEpisodes . '" play-location="' . $playButtonLocation . '" hide-artwork="' . $hide_artwork . '" hide-duration="' . $hide_duration . '" hide-date="' . $hide_date . '" hide-category="' . $hide_category . '" hide-excerpt="' . $hide_excerpt . '" hide-pagination="' . $hide_pagination . '"  strip-html-excerpt="' . $strip_html_excerpt . '" excerpt-lenght="' . $excerpt_lenght . '" disable-post-link="' . $disable_post_link . '" next-button-text="' . $next_button_text . '" prev-button-text="' . $prev_button_text . '" ]');
	}
	
}
Plugin::instance()->widgets_manager->register( new SR_Podcast_Archive() );