<?php
namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Base;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;



/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */

class SR_Podcast_Player extends Widget_Base {

	public function get_name() {
		return 'podcast-player';
	}
	public function get_title() {
		return __( 'Podcast Player', 'elementor-sonaar' );
	}
	public function get_icon() {
		return 'eicon-posts-ticker sonaar-badge';
	}
	public function get_help_url() {
		return 'https://support.sonaar.io';
	}
	public function get_categories() {
		return [ 'elementor-sonaar' ];
	}
	public function get_script_depends() {
		return [ 'elementor-sonaar' ];
	}
	public function get_keywords() {
		return [ 'mp3', 'player', 'audio', 'podcast', 'radio' ,'stream', 'episode', 'sonaar' ];
	}
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Podcast Player Settings', 'elementor-sonaar' ),
			]
		);
			
			$this->add_control(
				'episode_list',
					[
						'label'                 => esc_html__( 'Select Episode', 'elementor-sonaar' ),
						'type'                  => Controls_Manager::SELECT,
						'label_block'           => true,
						'options'               => sr_elementor_select_episode(),
		                'default'               => '0',
		                'condition' => [
							'play_current_id' => '',
						]
		               				             	
					]
			);
			$this->add_control(
				'hide_artwork',
				[
					'label' => __( 'Show Artwork', 'elementor-sonaar' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => __( 'SHOW', 'elementor-sonaar' ),
					'label_off' => __( 'HIDE', 'elementor-sonaar' ),
					'return_value' => '1',
					'default' => '1',
				]
			);
			$this->add_control(
				'hide_date',
				[
					'label' => __( 'Hide Date', 'elementor-sonaar' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => __( 'Hide', 'elementor-sonaar' ),
					'label_off' => __( 'SHOW', 'elementor-sonaar' ),
					'return_value' => '1',
					'default' => '0',
				]
			);
			$this->add_control(
				'hide_category',
				[
					'label' => __( 'Hide Category', 'elementor-sonaar' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => __( 'Hide', 'elementor-sonaar' ),
					'label_off' => __( 'SHOW', 'elementor-sonaar' ),
					'return_value' => '1',
					'default' => '0',
				]
			);
			$this->add_control(
				'hide_duration',
				[
				'label' => __( 'Hide Duration', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => __( 'Hide', 'elementor-sonaar' ),
					'label_off' => __( 'SHOW', 'elementor-sonaar' ),
					'return_value' => '1',
					'default' => '0',
				]
			);
			$this->add_control(
				'hide_cta-button',
				[
				'label' => __( 'Hide CTA Button', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'label_on' => __( 'Hide', 'elementor-sonaar' ),
					'label_off' => __( 'SHOW', 'elementor-sonaar' ),
					'return_value' => 'none',
					'default' => 'inline-block',
					'selectors' => [
						'{{WRAPPER}} .iron_podcast_player .sonaar-callToAction' => 'display:{{VALUE}};',
					]
				]
			);
			$this->add_control(
				'sr_podcastplayer_title_tag',
				[
					'label' => __( 'HTML Title Tag', 'elementor-sonaar' ),
					'type' => Controls_Manager::SELECT,
					'options' => [
						'h1' => 'H1',
						'h2' => 'H2',
						'h3' => 'H3',
						'h4' => 'H4',
						'h5' => 'H5',
						'h6' => 'H6',
						'div' => 'div',
						'span' => 'span',
						'p' => 'p',
					],
					'default' => 'div',
				]
			);
			$this->add_control(
				'play_current_id',
				[
					'label' => __( 'Play its own Post ID track', 'elementor-sonaar' ),
					'description' => __( 'Check this case if this player is intended to be displayed on its own custom post', 'elementor-sonaar' ),
					'type' => \Elementor\Controls_Manager::SWITCHER,
					'yes' => __( 'Yes', 'elementor-sonaar' ),
					'no' => __( 'No', 'elementor-sonaar' ),
					'return_value' => 'yes',
					'default' => '',

				]
			);
		$this->end_controls_section();

		/**
        * STYLE: STYLE
        * -------------------------------------------------
        */
		
		//-- TYPOGRAPHY
		$this->start_controls_section(
            'typography_style',
            [
                'label'                 => __( 'Typography', 'elementor-sonaar' ),
                'tab'                   => Controls_Manager::TAB_STYLE,
            ]
		);
		$this->add_control(
			'title_text_color',
			[
				'label'                 => __( 'Text Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .track-title, {{WRAPPER}} .meta-podcast, {{WRAPPER}} .iron_podcast_player.srt_player-container .iron-audioplayer, {{WRAPPER}} .sonaar-category a' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'content_typography',
				'label' => __( 'Typography', 'elementor-sonaar' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .track-title',
			]
		);
		
		$this->end_controls_section();


		//-- THUMPNAIL
		$this->start_controls_section(
            'image_style',
            [
                'label'                 => __( 'Thumbnail', 'elementor-sonaar' ),
				'tab'                   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'hide_artwork' => '1',
				],
            ]
		);
		$this->add_responsive_control(
			'image_width',
			[
				'label' => __( 'Thumbnail Width', 'elementor-sonaar' ),
				'size_units' => [ 'px', '%' ],
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 1,
						'max' => 500,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .srt_player-container .iron-audioplayer .album .album-art img' => 'width: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .srt_player-container .iron-audioplayer .album .album-art' => 'max-width: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .iron_podcast_player .artwork-col' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'border_thumbnail',
				'selector' => '{{WRAPPER}} .srt_player-container .iron-audioplayer .album-art img',
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'thumbnail_border_radius',
			[
				'label' => __( 'Thumbnail Border Radius', 'elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .srt_player-container .iron-audioplayer .album-art img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'thumbnail_margin',
			[
				'label' => __( 'Thumbnail Margin', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .srt_player-container .iron-audioplayer .artwork-col' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);
		
		$this->add_control(
			'show_thumbnail_mobile',
			[
				'label' => __( 'Show Thumbnail On Mobile', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'SHOW', 'elementor-sonaar' ),
				'label_off' => __( 'HIDE', 'elementor-sonaar' ),
				'return_value' => 'inline-block',
				'selectors' => [
					'(mobile){{WRAPPER}} .iron_podcast_player .artwork-col' => 'display:{{VALUE}};',
			],
				'separator' => 'before',
			]
		);

		$this->end_controls_section();

			//-- PLAY BUTTON STYLE
	
			$this->start_controls_section(
				'play_button_style',
				[
					'label'                 => __( 'Play Button', 'elementor-sonaar' ),
					'tab'                   => Controls_Manager::TAB_STYLE,
				]
			);
	
	
			$this->start_controls_tabs( 'tabs_button_style_play_button' );
			$this->start_controls_tab(
				'tab_button_normal_play_button',
				[
					'label' => __( 'Normal', 'elementor' ),
				]
			);
			$this->add_control(
				'button_play_color',
				[
					'label'                 => __( 'Button Play Color', 'elementor-sonaar' ),
					'type'                  => Controls_Manager::COLOR,
					'default'               => '',
					'selectors'             => [
						'{{WRAPPER}} .sonaar-play-button .sonaar-play-circle circle' => 'stroke: {{VALUE}}',
						'{{WRAPPER}} .sonaar-play-button rect, {{WRAPPER}} .sonaar-play-button path, {{WRAPPER}} .sonaar-play-button polygon' => 'fill: {{VALUE}}',
					],
				]
			);
			$this->add_control(
				'Button_play_background',
				[
					'label'                 => __( 'Button Play Background Color', 'elementor-sonaar' ),
					'type'                  => Controls_Manager::COLOR,
					'default'               => '',
					'selectors'             => [
						'{{WRAPPER}} .sonaar-play-button .sonaar-play-circle circle, {{WRAPPER}} .sonaar-podcast-list-item.sr-button-left:not(.no-image) .sonaar-play-button .sonaar-play-circle circle'  => 'fill: {{VALUE}}',
					],
				]
			);
			$this->end_controls_tab();
			$this->start_controls_tab(
				'tab_button_hover_play_button',
				[
					'label' => __( 'Hover', 'elementor' ),
				]
			);
			$this->add_control(
				'button_play_color_hover',
				[
					'label'                 => __( 'Button Play Color', 'elementor-sonaar' ),
					'type'                  => Controls_Manager::COLOR,
					'default'               => '',
					'selectors'             => [
						'{{WRAPPER}} .sonaar-play-button:hover .sonaar-play-circle circle' => 'stroke: {{VALUE}}',
						'{{WRAPPER}} .sonaar-play-button:hover rect, {{WRAPPER}} .sonaar-play-button:hover path, {{WRAPPER}} .sonaar-play-button:hover polygon' => 'fill: {{VALUE}}',
					],
				]
			);
			$this->add_control(
				'Button_play_background_hover',
				[
					'label'                 => __( 'Button Play Background Color', 'elementor-sonaar' ),
					'type'                  => Controls_Manager::COLOR,
					'default'               => '',
					'selectors'             => [
						'{{WRAPPER}} .sonaar-play-button:hover .sonaar-play-circle circle, {{WRAPPER}} .sonaar-podcast-list-item.sr-button-left:not(.no-image) .sonaar-play-button:hover .sonaar-play-circle circle'  => 'fill: {{VALUE}}',
					],
				]
			);
			
			$this->end_controls_tab();
			$this->end_controls_tabs();

			$this->add_responsive_control(
				'play_button_width',
				[
					'label' => esc_html__( 'Play Button Width', 'essential-addons-elementor' ),
					'type' => Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'max' => 300,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .sonaar-play-button' => 'width: {{SIZE}}px; height: {{SIZE}}px;',
						//'{{WRAPPER}} .sonaar-play-button-box' => 'right: calc({{SIZE}}px + 40px);',
					],
					'separator' => 'before',
				]
			);
			$this->add_responsive_control(
				'play_icon_width',
				[
					'label' => esc_html__( 'Control Icon Width', 'essential-addons-elementor' ),
					'type' => Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'max' => 250,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .sonaar-play-button .sonaar-play-icon' => 'width: {{SIZE}}px; height: {{SIZE}}px;',
					],
				]
			);
			$this->add_responsive_control(
				'play_border_width',
				[
					'label' => esc_html__( 'Border Width', 'essential-addons-elementor' ),
					'type' => Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'max' => 100,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .sonaar-play-button .sonaar-play-circle circle' => 'stroke-width: {{SIZE}};',
					],
				]
			);
			$this->add_responsive_control(
				'play_button_offset_x',
				[
					'label' => __( 'Horizontal Offset', 'elementor' ),
					'type' => Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => -1000,
							'max' => 1500,
							'step' => 1,
						],
					],
					'default' => [
						'size' => '0',
					],
					'selectors' => [
						'{{WRAPPER}} .sonaar-play-button' => 'right: {{SIZE}}px;',
					],
					'separator' => 'before',
				]
			);
			$this->add_responsive_control(
				'play_button_offset_y',
				[
					'label' => __( 'Vertical Offset', 'elementor' ),
					'type' => Controls_Manager::SLIDER,
					'range' => [
						'px' => [
							'min' => -500,
							'max' => 500,
							'step' => 1,
						],
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'size_units' => [ '%', 'px' ],
					'default' => [
						'size' => '50',
						'unit' => '%',
					],
					'selectors' => [
						'{{WRAPPER}} .sonaar-play-button-box' => 'top: {{SIZE}}{{UNIT}};',
					],
				]
			);
			
		$this->end_controls_section();

		//-- META STYLE

		$this->start_controls_section(
			'meta',
			[
				'label'                 => __( 'Meta', 'elementor-sonaar' ),
				'tab'                   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'meta_color',
			[
				'label'                 => __( 'Meta Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .meta-podcast, {{WRAPPER}} .meta-podcast a, {{WRAPPER}} .sonaar-date'  => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'meta_typography',
				'label' => __( 'Meta Typography', 'elementor-sonaar' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .sonaar-category a, {{WRAPPER}} .meta-podcast .sonaar-date, {{WRAPPER}} .meta-podcast .sonaar-duration',
			]
		);
		$this->add_responsive_control(
			'button_container_margin',
			[
				'label' => __( 'Button Container Margin', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sonaar-podcast-player-bottom' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->end_controls_section();

		//-- CTA BUTTON STYLE

		$this->start_controls_section(
			'button_style',
			[
				'label'                 => __( 'CTA Button', 'elementor-sonaar' ),
				'tab'                   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'button_typography',
				'label' => __( 'Button Typography', 'elementor-sonaar' ),
				'scheme' => Typography::TYPOGRAPHY_1,
				'selector' => '{{WRAPPER}} .iron_podcast_player .sonaar-callToAction',
			]
		);

		$this->start_controls_tabs( 'tabs_button_style' );

		$this->start_controls_tab(
			'tab_button_normal',
			[
				'label' => __( 'Normal', 'elementor' ),
			]
		);

		$this->add_control(
			'button_text_color',
			[
				'label' => __( 'Button Text Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .iron_podcast_player .sonaar-callToAction' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_background_color',
			[
				'label' => __( 'Button Background Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .iron_podcast_player .sonaar-callToAction' => 'background: {{VALUE}}',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => __( 'Hover', 'elementor' ),
			]
		);

		$this->add_control(
			'button_hover_color',
			[
				'label' => __( 'Button Text Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .iron_podcast_player .sonaar-callToAction:hover' => 'color: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'button_background_hover_color',
			[
				'label' => __( 'Button Background Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .iron_podcast_player .sonaar-callToAction:hover' => 'background-color: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'button_hover_border_color',
			[
				'label' => __( 'Button Border Color', 'elementor-sonaar' ),
				'type' => Controls_Manager::COLOR,
				'condition' => [
					'border_border!' => '',
				],
				'selectors' => [
					'{{WRAPPER}} .iron_podcast_player .sonaar-callToAction:hover' => 'border-color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'border',
				'selector' => '{{WRAPPER}} .iron_podcast_player .sonaar-callToAction',
				'separator' => 'before',
			]
		);
		$this->add_control(
			'button_border_radius',
			[
				'label' => __( 'Button Border Radius', 'elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .iron_podcast_player .sonaar-callToAction' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'button_box_shadow',
				'selector' => '{{WRAPPER}} .iron_podcast_player .sonaar-callToAction',
			]
		);
		$this->add_responsive_control(
			'button_padding',
			[
				'label' => __( 'Button Padding', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .iron_podcast_player .sonaar-callToAction' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'space_between_store_button',
			[
				'label' => __( 'Buttons Space', 'sonaar-elementor' ) . ' (px)',
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 500,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .iron_podcast_player .sonaar-callToAction+.sonaar-callToAction' => 'margin-left: {{SIZE}}px;', 
				],
			]
		);
		$this->add_control(
			'hr1',
			[
				'type' => \Elementor\Controls_Manager::DIVIDER,
				'style' => 'thick',
			]
		);
		$this->end_controls_section();

		//-- SOUNDWAVE STYLE

		$this->start_controls_section(
			'soundwave_style',
			[
				'label'                 => __( 'SoundWave', 'elementor-sonaar' ),
				'tab'                   => Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_control(
			'spectro_color',
			[
				'label'                 => __( 'SoundWave Color Bars', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .spectro svg rect'  => 'fill: {{VALUE}}',
				],
			]
		);
		$this->add_responsive_control(
			'spectro_height',
			[
				'label' => esc_html__( 'SoundWave Bars Height', 'essential-addons-elementor' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 500,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .iron_podcast_player .main-player-col .player' => 'height: {{SIZE}}px;',
				],
				'separator' => 'before',
			]
		);

		$this->end_controls_section();

		//-- CONTAINER STYLE

		$this->start_controls_section(
            'container_style',
            [
                'label'                 => __( 'Container', 'elementor-sonaar' ),
                'tab'                   => Controls_Manager::TAB_STYLE,
            ]
        );
		$this->add_group_control(
		Group_Control_Background::get_type(),
		[
			'name' => 'background',
			'label' => __( 'Background', 'elementor-sonaar' ),
			'types' => [ 'classic', 'gradient'],
			'selector' => '{{WRAPPER}} .iron_podcast_player',
		]
		);

		$this->add_responsive_control(
			'container_padding',
			[
				'label' => esc_html__( 'Container Padding', 'essential-addons-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
						'{{WRAPPER}} .srt_player-container .iron-audioplayer' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'content_padding',
			[
				'label' => esc_html__( 'Content Padding', 'essential-addons-elementor' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
						'{{WRAPPER}} .main-player-col' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'container_border',
				'label' => esc_html__( 'Border', 'essential-addons-elementor' ),
				'selector' => '{{WRAPPER}} .iron_podcast_player',
			]
		);

		$this->add_responsive_control(
			'sr_dch_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'essential-addons-elementor' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 500,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .iron_podcast_player' => 'border-radius: {{SIZE}}px;',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'sr_dch_shadow',
				'selector' => '{{WRAPPER}} .iron_podcast_player',
			]
		);
		$this->end_controls_section();
	}


	protected function render() {
		$settings = $this->get_settings();

		$hide_category = $settings['hide_category'];
		$hide_date = $settings['hide_date'];
		$hide_duration = $settings['hide_duration'];

		$postid = get_the_ID();
		if ($settings['play_current_id']=='yes'){
				echo do_shortcode( '[iron_podcastplayer albums="' . $postid . '" ]' );
		}else{
			if ($settings['episode_list']=='0'){
				echo do_shortcode( '[iron_podcastplayer play-latest="yes" albums="' . $settings['episode_list'] . '" titletag="'. $settings['sr_podcastplayer_title_tag'] .'" show_artwork="' . $settings['hide_artwork'] .'" hide_category="' . $settings['hide_category'] .'" hide_date="' . $settings['hide_date'] .'" hide_duration="' . $settings['hide_duration'] .'" ]' );
			}else{
				echo do_shortcode( '[iron_podcastplayer albums="' . $settings['episode_list'] . '" titletag="'. $settings['sr_podcastplayer_title_tag'] .'" show_artwork="' . $settings['hide_artwork'] .'" hide_category="' . $settings['hide_category'] .'" hide_date="' . $settings['hide_date'] .'" hide_duration="' . $settings['hide_duration'] .'" ]' );
			}
		}
	}
	public function render_plain_content() {
		$settings = $this->get_settings();

		$postid = get_the_ID();
		if ($settings['play_current_id']=='yes'){
				echo do_shortcode( '[iron_podcastplayer albums="' . $postid . '" ]' );
		}else{
			if ($settings['episode_list']=='0'){
				echo do_shortcode( '[iron_podcastplayer play-latest="yes" albums="' . $settings['episode_list'] . '" ]' );
			}else{
				echo do_shortcode( '[iron_podcastplayer albums="' . $settings['episode_list'] . '" ]' );
			}
		}
	}
	
}
Plugin::instance()->widgets_manager->register( new SR_Podcast_Player() );