<?php
namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Base;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */

class SR_Promobox extends Widget_Base {

	public function get_name() {
		return 'promobox';
	}
	public function get_title() {
		return __( 'Promo Box', 'elementor-sonaar' );
	}
	public function get_icon() {
		return 'eicon-accordion sonaar-badge';
	}
	public function get_help_url() {
		return 'https://support.sonaar.io';
	}
	public function get_categories() {
		return [ 'elementor-sonaar' ];
	}
	public function get_script_depends() {
		return [ 'elementor-sonaar' ];
	}
	public function get_keywords() {
		return [ 'promo', 'box', 'sonaar'];
	}
	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Promobox Settings', 'elementor-sonaar' ),
			]
		);
				$this->add_control(
					'image',
					[
						'label' => __( 'Choose Background Image', 'plugin-domain' ),
						'type' => \Elementor\Controls_Manager::MEDIA,
						'default' => [
							'url' => \Elementor\Utils::get_placeholder_image_src(),
						],
					]
				);
				$this->add_control(
					'image_size',
						[
							'label'                 => esc_html__( 'Image Size', 'elementor-sonaar' ),
							'type'                  => Controls_Manager::SELECT,
							'label_block'           => false,
							'options' => [
										'medium' 	=> __( 'medium', 'elementor-sonaar' ),
										'large' 	=> __( 'large', 'elementor-sonaar' ),
										'full' 		=> __( 'full', 'elementor-sonaar' ),
									],
			                'default'               => 'medium',
			                
			               				             	
						]
				);
				$this->add_control(
					'my_title',
						[
							'label' 		=> __( 'Title', 'elementor-sonaar' ),
							'label_block'	=> true,
							'type' 			=> \Elementor\Controls_Manager::TEXT,
							'placeholder'	=> __( 'Type your title here', 'elementor-sonaar' ),
							'default'		=> 'Your Title',
						]
				);
				$this->add_control(
					'title_heading',
						[
							'label'                 => esc_html__( 'Title Heading', 'elementor-sonaar' ),
							'type'                  => Controls_Manager::SELECT,
							'label_block'           => false,
							'options' => [
										'h1' 	=> __( 'h1', 'elementor-sonaar' ),
										'h2' 	=> __( 'h2', 'elementor-sonaar' ),
										'h3' 	=> __( 'h3', 'elementor-sonaar' ),
										'h4' 	=> __( 'h4', 'elementor-sonaar' ),
										'h5' 	=> __( 'h5', 'elementor-sonaar' ),
										'h6' 	=> __( 'h6', 'elementor-sonaar' ),
										'div' 	=> __( 'div', 'elementor-sonaar' ),
										'p' 	=> __( 'p', 'elementor-sonaar' ),
									],
			                'default'               => 'h3',
			                
			               				             	
						]
				);

				$this->add_control(
					'my_subtitle',
						[
							'label'			=> __( 'Sub Title', 'elementor-sonaar' ),
							'label_block'	=> true,
							'type'			=> \Elementor\Controls_Manager::TEXT,
							'placeholder'	=> __( 'Type your sub title here', 'elementor-sonaar' ),
							'default'		=> 'COOL SUB TITLE',
						]
				);
				$this->add_control(
					'subtitle_heading',
						[
							'label'                 => esc_html__( 'Sub Title Heading', 'elementor-sonaar' ),
							'type'                  => Controls_Manager::SELECT,
							'label_block'           => false,
							'options' => [
										'h1' 	=> __( 'h1', 'elementor-sonaar' ),
										'h2' 	=> __( 'h2', 'elementor-sonaar' ),
										'h3' 	=> __( 'h3', 'elementor-sonaar' ),
										'h4' 	=> __( 'h4', 'elementor-sonaar' ),
										'h5' 	=> __( 'h5', 'elementor-sonaar' ),
										'h6' 	=> __( 'h6', 'elementor-sonaar' ),
										'div' 	=> __( 'div', 'elementor-sonaar' ),
										'p' 	=> __( 'p', 'elementor-sonaar' ),
									],
			                'default'               => 'h4',
			                
			               				             	
						]
				);
				$this->add_control(
					'website_link',
						[
							'label' => __( 'Link', 'elementor-sonaar' ),
							'type' => \Elementor\Controls_Manager::URL,
							'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
							'show_external' => true,
							'default' => [
								'url' => '',
								'is_external' => true,
								'nofollow' => true,
							],
						]
				);

		$this->end_controls_section();

        /**
         * STYLE: LOOK AND FEEL
         * -------------------------------------------------
         */
        $this->start_controls_section(
            'typography_style',
            [
                'label'                 => __( 'Look and feel', 'elementor-sonaar' ),
                'tab'                   => Controls_Manager::TAB_STYLE,
            ]
        );
				$this->add_group_control(
					Group_Control_Typography::get_type(),
						[
							'name' => 'title_typography',
							'label' => __( 'Title Typography', 'elementor-sonaar' ),
							'scheme' => Typography::TYPOGRAPHY_1,
							'selector' => '{{WRAPPER}} .promotext, {{WRAPPER}} .promotext h1, {{WRAPPER}} .promotext h2, {{WRAPPER}} .promotext h3, {{WRAPPER}} .promotext h4, {{WRAPPER}} .promotext h5, {{WRAPPER}} .promotext h6, {{WRAPPER}} .promotext p, {{WRAPPER}} .promotext div',
						]
				);
				$this->add_control(
						'title_color',
						[
							'label' 	=> esc_html__( 'Title Color', 'elementor-sonaar' ),
							'type' 		=> Controls_Manager::COLOR,
							'default'	=> '#ffffff',
						]
				);
				$this->add_group_control(
					Group_Control_Typography::get_type(),
						[
							'name' => 'subtitle_typography',
							'label' => __( 'Sub Title Typography', 'elementor-sonaar' ),
							'scheme' => Typography::TYPOGRAPHY_1,
							'selector' => '{{WRAPPER}} .promosubtext, {{WRAPPER}} .promosubtext h1, {{WRAPPER}} .promosubtext h2, {{WRAPPER}} .promosubtext h3, {{WRAPPER}} .promosubtext h4, {{WRAPPER}} .promosubtext h5, {{WRAPPER}} .promosubtext h6, {{WRAPPER}} .promosubtext p, {{WRAPPER}} .promosubtext div',
						]
				);
				$this->add_control(
						'subtitle_color',
						[
							'label' => esc_html__( 'Sub Title Color', 'elementor-sonaar' ),
							'type' => Controls_Manager::COLOR,
							'default'	=> '#ffffff',
						]
				);
				$this->add_control(
						'overlay_color',
						[
							'label' => esc_html__( 'Image Overlay Color', 'elementor-sonaar' ),
							'type' => Controls_Manager::COLOR,
							'default'	=> 'rgba(0,0,0,0.3)',
						]
				);
				$this->add_responsive_control(
		           		'heading_alignment',
			            [
			                'label'                 => __( 'Text Alignment', 'elementor-sonaar' ),
							'type'                  => Controls_Manager::CHOOSE,
							'options'               => [
								'left'      => [
									'title' => __( 'Left', 'elementor-sonaar' ),
									'icon'  => 'fa fa-align-left',
								],
								'center'    => [
									'title' => __( 'Center', 'elementor-sonaar' ),
									'icon'  => 'fa fa-align-center',
								],
								'right'     => [
									'title' => __( 'Right', 'elementor-sonaar' ),
									'icon'  => 'fa fa-align-right',
								],
							],
							'default'               => 'center',
							'selectors'             => [
								'{{WRAPPER}} .promocontent div, {{WRAPPER}} .promocontent p, {{WRAPPER}} .promocontent.right .promotext h1, {{WRAPPER}} .promocontent.right .promotext h2, {{WRAPPER}} .promocontent.right .promotext h3, {{WRAPPER}} .promocontent.right .promotext h4, {{WRAPPER}} .promocontent.right .promotext h5, {{WRAPPER}} .promocontent.right .promotext h6, {{WRAPPER}} .promocontent.right .promosubtext h1, {{WRAPPER}} .promocontent.right .promosubtext h2, {{WRAPPER}} .promocontent.right .promosubtext h3, {{WRAPPER}} .promocontent.right .promosubtext h4, {{WRAPPER}} .promocontent.right .promosubtext h5, {{WRAPPER}} .promocontent.right .promosubtext h6, {{WRAPPER}} .promocontent.left .promotext h1, {{WRAPPER}} .promocontent.left .promotext h2, {{WRAPPER}} .promocontent.left .promotext h3, {{WRAPPER}} .promocontent.left .promotext h4, {{WRAPPER}} .promocontent.left .promotext h5, {{WRAPPER}} .promocontent.left .promotext h6, {{WRAPPER}} .promocontent.left .promosubtext h1, {{WRAPPER}} .promocontent.left .promosubtext h2, {{WRAPPER}} .promocontent.left .promosubtext h3, {{WRAPPER}} .promocontent.left .promosubtext h4, {{WRAPPER}} .promocontent.left .promosubtext h5, {{WRAPPER}} .promocontent.left .promosubtext h6, {{WRAPPER}} .promocontent.center .promotext h1, {{WRAPPER}} .promocontent.center .promotext h2, {{WRAPPER}} .promocontent.center .promotext h3, {{WRAPPER}} .promocontent.center .promotext h4, {{WRAPPER}} .promocontent.center .promotext h5, {{WRAPPER}} .promocontent.center .promotext h6, {{WRAPPER}} .promocontent.center .promosubtext h1, {{WRAPPER}} .promocontent.center .promosubtext h2, {{WRAPPER}} .promocontent.center .promosubtext h3, {{WRAPPER}} .promocontent.center .promosubtext h4, {{WRAPPER}} .promocontent.center .promosubtext h5, {{WRAPPER}} .promocontent.center .promosubtext h6' => 'text-align: {{VALUE}};',
							],
						]
				);
				$this->add_control(
					'hover_animation',
						[
							'label'                 => esc_html__( 'Hover Animation FX', 'elementor-sonaar' ),
							'type'                  => Controls_Manager::SELECT,
							'label_block'           => false,
							'options' => [
										'zoom'  => __( 'Zoom', 'elementor-sonaar' ),
										'slide' => __( 'Slide', 'elementor-sonaar' ),
									],
			                'default'               => 'zoom',
			                
			               				             	
						]
				);

				$this->add_responsive_control(
						'promobox_padding',
						[
							'label' => esc_html__( 'Box Padding', 'essential-addons-elementor' ),
							'type' => Controls_Manager::DIMENSIONS,
							'size_units' => [ 'px', 'em', '%' ],
							'selectors' => [
								'{{WRAPPER}} .promocontent' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
							],
						]
				);

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$shortcode = '[iron_promotion title="' . $settings['my_title'] . '" title_tag_name="' . $settings['title_heading'] . '" title_color="' . $settings['title_color'] . '" subtitle="' . $settings['my_subtitle'] . '" subtitle_tag_name="' . $settings['subtitle_heading'] . '" subtitle_color="' . $settings['subtitle_color'] . '" title_align="' . $settings['heading_alignment'] . '" line_height="" overlay_color="' . $settings['overlay_color'] . '" link_page="" link_external="' . $settings['website_link']['url'] . '" hover_animation="' . $settings['hover_animation'] . '" target="' . (bool)$settings['website_link']['is_external'] . '" image="' . $settings['image']['id'] . '" imagesize="' . $settings['image_size'] . '"]';
		echo do_shortcode( $shortcode );
	}
	public function render_plain_content() {
		$settings = $this->get_settings_for_display();
		$shortcode = '[iron_promotion title="' . $settings['my_title'] . '" title_tag_name="' . $settings['title_heading'] . '" title_color="' . $settings['title_color'] . '" subtitle="' . $settings['my_subtitle'] . '" subtitle_tag_name="' . $settings['subtitle_heading'] . '" subtitle_color="' . $settings['subtitle_color'] . '" title_align="' . $settings['heading_alignment'] . '" line_height="" overlay_color="' . $settings['overlay_color'] . '" link_page="" link_external="' . $settings['website_link']['url'] . '" hover_animation="' . $settings['hover_animation'] . '" target="' . (bool)$settings['website_link']['is_external'] .'" image="' . $settings['image']['id'] . '"]';
		echo $shortcode;
	}

	
}
Plugin::instance()->widgets_manager->register( new SR_Promobox() );