<?php
namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

use Elementor\Controls_Manager;
use Elementor\Control_Media;
use Elementor\Utils;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Core\Schemes\Typography;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;
use Elementor\Group_Control_Css_Filter;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Plugin;
use Elementor\Widget_Base;
use Iron_sonaar;


/**
 * SR Site Logo
 *
 * Site logo widget by Sonaar.
 *
 * @since 4.20
 */

class SR_SiteLogo extends Widget_Base {
	
	public function get_name() {
		return 'sr-sitelogo';
	}
	public function get_title() {
		return __( 'Site Logo', 'elementor-sonaar' );
	}
	public function get_icon() {
		return 'eicon-banner sonaar-badge';
	}
	public function get_help_url() {
		return 'https://support.sonaar.io';
	}
	public function get_keywords() {
		return [ 'logo', 'identity', 'brand', 'sonaar', 'sonar', 'sonnar', 'header', 'menu', 'logos'];
	}
	public function get_categories() {
		return [ 'elementor-sonaar' ];
	}

	/**
	 * Register Site Logo.
	 *
	 * @since 1.3.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->register_content_site_logo_controls();
		$this->register_site_logo_styling_controls();
		$this->register_site_logo_caption_styling_controls();
	}
	protected function register_content_site_logo_controls() {
		$this->start_controls_section(
			'section_site_image',
			[
				'label' => __( 'Site Logo', 'elementor-sonaar' ),
			]
		);
		if( class_exists('Iron_sonaar') && Iron_sonaar::getOption('menu_type') == "elementor-menu" ){
			$this->add_control(
				'logo_source',
				[
					'label'   => __( 'Logo source', 'elementor-sonaar' ),
					'type'    => Controls_Manager::SELECT,
					'options' => [
						'site_identity'  => __( 'Site Identity logo', 'elementor-sonaar' ),
						'custom_logo' => __( 'Custom Logo Image', 'elementor-sonaar' ),
					],
					'default' => 'site_identity',
				]
			);
		}else{
			$this->add_control(
				'logo_source',
				[
					'label'   => __( 'Logo source', 'elementor-sonaar' ),
					'type'    => Controls_Manager::HIDDEN,
					'default' => 'custom_logo',
				]
			);
		}
		$this->add_control(
			'important_note',
			[
				'label' => __( 'Message', 'elementor-sonaar' ),
				'show_label' => false,
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' => __( 'Upload logo in the <a href="./customize.php?return=%2Fwp-admin%2Fedit.php%3Fpost_type=block" target="_blank">Customizer > Site Identity</a>', 'elementor-sonaar' ),
				'content_classes' => 'elementor-sonaar-raw-html',
				'condition' => [
					'logo_source' => 'site_identity',
				],
			]
		);
		$this->add_control(
			'logo_selected',
			[
				'label'   => __( 'Logo to be used', 'elementor-sonaar' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'primary'  => __( 'Primary Logo', 'elementor-sonaar' ),
					'secondary' => __( 'Secondary Logo', 'elementor-sonaar' ),
					'sticky' => __( 'Sticky Logo', 'elementor-sonaar' ),
				],
				'separator' => 'before',
				'default' => 'primary',
				'condition' => [
					'logo_source' => 'site_identity',
				],
			]
		);
		$this->add_control(
			'custom_image_primary',
			[
				'label'     => __( 'Primary Logo', 'elementor-sonaar' ),
				'type'      => Controls_Manager::MEDIA,
				'dynamic'   => [
					'active' => true,
				],
				'default'   => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'logo_source' => 'custom_logo',
				],
			]
		);
		if( class_exists('Iron_sonaar') && Iron_sonaar::getOption('menu_type') == "elementor-menu" ){
			$this->add_control(
				'custom_image_secondary',
				[
					'label'     => __( 'Secondary Logo (Optional)', 'elementor-sonaar' ),
					'description'     => __( 'Only used if defined in individual page settings. If no logo specified, fallback is the primary logo.', 'elementor-sonaar' ),
					'type'      => Controls_Manager::MEDIA,
					'dynamic'   => [
						'active' => true,
					],
					'default'   => [
						'url' => Utils::get_placeholder_image_src(),
					],
					'condition' => [
						'logo_source' => 'custom_logo',
					],
				]
			);
		}

		$this->add_control(
			'custom_image_sticky',
			[
				'label'     => __( 'Logo when sticky (Optional)', 'elementor-sonaar' ),
				'description'     => __( 'Logo to be used when sticky section is active. If no logo specified, fallback is the primary logo.', 'elementor-sonaar' ),
				'type'      => Controls_Manager::MEDIA,
				'dynamic'   => [
					'active' => true,
				],
				/*'default'   => [
					'url' => Utils::get_placeholder_image_src(),
				],*/
				'condition' => [
					'logo_source' => 'custom_logo',
				],
			]
		);
		
		$this->add_group_control(
			Group_Control_Image_Size::get_type(),
			[
				'name'    => 'site_logo_size',
				'label'   => __( 'Image Size', 'elementor-sonaar' ),
				'separator' => 'before',
				'default' => 'medium',
			]
		);
		$this->add_responsive_control(
			'align',
			[
				'label'     => __( 'Alignment', 'elementor-sonaar' ),
				'type'      => Controls_Manager::CHOOSE,
				'options'   => [
					'left'   => [
						'title' => __( 'Left', 'elementor-sonaar' ),
						'icon'  => 'eicon-h-align-left',
					],
					'center' => [
						'title' => __( 'Center', 'elementor-sonaar' ),
						'icon'  => 'eicon-h-align-center',
					],
					'right'  => [
						'title' => __( 'Right', 'elementor-sonaar' ),
						'icon'  => 'eicon-h-align-right',
					],
				],
				'default'   => 'center',
				'selectors' => [
					'{{WRAPPER}} .sr-site-logo-container, {{WRAPPER}} .sr-caption-width figcaption' => 'text-align: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'caption_source',
			[
				'label'   => __( 'Caption', 'elementor-sonaar' ),
				'type'    => Controls_Manager::SELECT,
				'options' => [
					'no'  => __( 'No', 'elementor-sonaar' ),
					'yes' => __( 'Yes', 'elementor-sonaar' ),
				],
				'default' => 'no',
			]
		);

		$this->add_control(
			'caption',
			[
				'label'       => __( 'Custom Caption', 'elementor-sonaar' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => '',
				'placeholder' => __( 'Enter caption', 'elementor-sonaar' ),
				'condition'   => [
					'caption_source' => 'yes',
				],
				'dynamic'     => [
					'active' => true,
				],
				'label_block' => true,
			]
		);

		$this->add_control(
			'link_to',
			[
				'label'   => __( 'Link', 'elementor-sonaar' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'default',
				'options' => [
					'default' => __( 'Default', 'elementor-sonaar' ),
					'none'    => __( 'None', 'elementor-sonaar' ),
					'custom'  => __( 'Custom URL', 'elementor-sonaar' ),
				],
			]
		);

		$this->add_control(
			'link',
			[
				'label'       => __( 'Link', 'elementor-sonaar' ),
				'type'        => Controls_Manager::URL,
				'dynamic'     => [
					'active' => true,
				],
				'placeholder' => __( 'https://your-link.com', 'elementor-sonaar' ),
				'condition'   => [
					'link_to' => 'custom',
				],
				'show_label'  => false,
			]
		);

		$this->add_control(
			'view',
			[
				'label'   => __( 'View', 'elementor-sonaar' ),
				'type'    => Controls_Manager::HIDDEN,
				'default' => 'traditional',
			]
		);
		$this->end_controls_section();
	}
	/**
	 * Register Site Image Style Controls.
	 *
	 * @since 1.3.0
	 * @access protected
	 */
	protected function register_site_logo_styling_controls() {
		$this->start_controls_section(
			'section_style_site_logo_image',
			[
				'label' => __( 'Site logo', 'elementor-sonaar' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'height',
			[
				'label'          => __( 'Logo Height', 'elementor-sonaar' ),
				'type'           => Controls_Manager::SLIDER,
				'default'        => [
					'size' => 90,
					'unit' => 'px',
				],
				'size_units'     => [ '%', 'px'],
				'range'          => [
					'%'  => [
						'min' => 1,
						'max' => 100,
					],
					'px' => [
						'min' => 1,
						'max' => 100,
					],
				],
				'selectors'      => [
					'{{WRAPPER}} .sr-site-logo .sr-site-logo-container img' => 'max-height: {{SIZE}}{{UNIT}}; width:auto;',
				],
			]
		);
		
		$this->add_responsive_control(
			'height_logo_sticky',
			[
				'label'          => __( 'Logo Height When Sticky', 'elementor-sonaar' ),
				'type'           => Controls_Manager::SLIDER,
				'default'        => [
					'size' => 45,
					'unit' => 'px',
				],
				'size_units'     => [ '%', 'px'],
				'range'          => [
					'%'  => [
						'min' => 1,
						'max' => 100,
					],
					'px' => [
						'min' => 1,
						'max' => 100,
					],
				],
				'selectors'      => [
					'.sr_sticky_showup .elementor-element-{{ID}} .sr-site-logo .sr-site-logo-container img' => 'max-height: {{SIZE}}{{UNIT}}!important; width: auto!important;',
				],
			]
		);
		/*$this->add_responsive_control(
			'space',
			[
				'label'          => __( 'Max Width', 'elementor-sonaar' ),
				'type'           => Controls_Manager::SLIDER,
				'default'        => [
					'unit' => 'px',
				],
				'size_units'     => [ '%', 'px', 'vw' ],
				'range'          => [
					'%'  => [
						'min' => 1,
						'max' => 100,
					],
					'px' => [
						'min' => 1,
						'max' => 1000,
					],
					'vw' => [
						'min' => 1,
						'max' => 100,
					],
				],
				'selectors'      => [
					'{{WRAPPER}} .sr-site-logo img' => 'max-width: {{SIZE}}{{UNIT}};',
				],
			]
		);*/

		$this->add_control(
			'separator_panel_style',
			[
				'type'  => Controls_Manager::DIVIDER,
				'style' => 'thick',
			]
		);

		$this->add_control(
			'site_logo_background_color',
			[
				'label'     => __( 'Background Color', 'elementor-sonaar' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .sr-site-logo-set .sr-site-logo-container' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'site_logo_image_border',
			[
				'label'       => __( 'Border Style', 'elementor-sonaar' ),
				'type'        => Controls_Manager::SELECT,
				'default'     => 'none',
				'label_block' => false,
				'options'     => [
					'none'   => __( 'None', 'elementor-sonaar' ),
					'solid'  => __( 'Solid', 'elementor-sonaar' ),
					'double' => __( 'Double', 'elementor-sonaar' ),
					'dotted' => __( 'Dotted', 'elementor-sonaar' ),
					'dashed' => __( 'Dashed', 'elementor-sonaar' ),
				],
				'selectors'   => [
					'{{WRAPPER}} .sr-site-logo-container .sr-site-logo-img' => 'border-style: {{VALUE}};',
				],
			]
		);
		$this->add_control(
			'site_logo_image_border_size',
			[
				'label'      => __( 'Border Width', 'elementor-sonaar' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px' ],
				'default'    => [
					'top'    => '1',
					'bottom' => '1',
					'left'   => '1',
					'right'  => '1',
					'unit'   => 'px',
				],
				'condition'  => [
					'site_logo_image_border!' => 'none',
				],
				'selectors'  => [
					'{{WRAPPER}} .sr-site-logo-container .sr-site-logo-img' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'site_logo_image_border_color',
			[
				'label'     => __( 'Border Color', 'elementor-sonaar' ),
				'type'      => Controls_Manager::COLOR,
				'condition' => [
					'site_logo_image_border!' => 'none',
				],
				'default'   => '',
				'selectors' => [
					'{{WRAPPER}} .sr-site-logo-container .sr-site-logo-img' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'image_border_radius',
			[
				'label'      => __( 'Border Radius', 'elementor-sonaar' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .sr-site-logo img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->start_controls_tabs( 'image_effects' );

		$this->start_controls_tab(
			'normal',
			[
				'label' => __( 'Normal', 'elementor-sonaar' ),
			]
		);

		$this->add_control(
			'opacity',
			[
				'label'     => __( 'Opacity', 'elementor-sonaar' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => [
					'px' => [
						'max'  => 1,
						'min'  => 0.10,
						'step' => 0.01,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sr-site-logo img' => 'opacity: {{SIZE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Css_Filter::get_type(),
			[
				'name'     => 'css_filters',
				'selector' => '{{WRAPPER}} .sr-site-logo img',
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'hover',
			[
				'label' => __( 'Hover', 'elementor-sonaar' ),
			]
		);
		$this->add_control(
			'opacity_hover',
			[
				'label'     => __( 'Opacity', 'elementor-sonaar' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => [
					'px' => [
						'max'  => 1,
						'min'  => 0.10,
						'step' => 0.01,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sr-site-logo:hover img' => 'opacity: {{SIZE}};',
				],
			]
		);
		$this->add_control(
			'background_hover_transition',
			[
				'label'     => __( 'Transition Duration', 'elementor-sonaar' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => [
					'px' => [
						'max'  => 3,
						'step' => 0.1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sr-site-logo img' => 'transition-duration: {{SIZE}}s',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Css_Filter::get_type(),
			[
				'name'     => 'css_filters_hover',
				'selector' => '{{WRAPPER}} .sr-site-logo:hover img',
			]
		);

		$this->add_control(
			'hover_animation',
			[
				'label' => __( 'Hover Animation', 'elementor-sonaar' ),
				'type'  => Controls_Manager::HOVER_ANIMATION,
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();

		$this->end_controls_section();
	}

	/**
	 * Register Site Logo style Controls.
	 *
	 * @since 1.3.0
	 * @access protected
	 */
	protected function register_site_logo_caption_styling_controls() {
		$this->start_controls_section(
			'section_style_caption',
			[
				'label'     => __( 'Caption', 'elementor-sonaar' ),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition' => [
					'caption_source!' => 'none',
				],
			]
		);

		$this->add_control(
			'text_color',
			[
				'label'     => __( 'Text Color', 'elementor-sonaar' ),
				'type'      => Controls_Manager::COLOR,
				'default'   => '',
				'selectors' => [
					'{{WRAPPER}} .widget-image-caption' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'caption_background_color',
			[
				'label'     => __( 'Background Color', 'elementor-sonaar' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .widget-image-caption' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'caption_typography',
				'selector' => '{{WRAPPER}} .widget-image-caption',
				'scheme'   => Typography::TYPOGRAPHY_3,
			]
		);

		$this->add_group_control(
			Group_Control_Text_Shadow::get_type(),
			[
				'name'     => 'caption_text_shadow',
				'selector' => '{{WRAPPER}} .widget-image-caption',
			]
		);

		$this->add_responsive_control(
			'caption_padding',
			[
				'label'      => __( 'Padding', 'elementor-sonaar' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors'  => [
					'{{WRAPPER}} .widget-image-caption' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		$this->add_responsive_control(
			'caption_space',
			[
				'label'     => __( 'Spacing', 'elementor-sonaar' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'default'   => [
					'size' => 0,
					'unit' => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .widget-image-caption' => 'margin-top: {{SIZE}}{{UNIT}}; margin-bottom: 0px;',
				],
			]
		);

		$this->end_controls_section();
	}

	/**
	 * Check if the current widget has caption
	 *
	 * @access private
	 * @since 1.3.0
	 *
	 * @param array $settings returns settings.
	 *
	 * @return boolean
	 */
	private function has_caption( $settings ) {
		return ( ! empty( $settings['caption_source'] ) && 'no' !== $settings['caption_source'] );
	}

	/**
	 * Get the caption for current widget.
	 *
	 * @access private
	 * @since 1.3.0
	 * @param array $settings returns the caption.
	 *
	 * @return string
	 */
	private function get_caption( $settings ) {
		$caption = '';
		if ( 'yes' === $settings['caption_source'] ) {
			$caption = ! empty( $settings['caption'] ) ? $settings['caption'] : '';
		}
		return $caption;
	}

	/**
	 * Render Site Image output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.3.0
	 * @param array $size returns the size of an image.
	 * @access public
	 */
	public function site_image_url( $size ) {
		$settings = $this->get_settings_for_display();
		if ( ! empty( $settings['custom_image_primary']['url'] ) ) {
			$logo = wp_get_attachment_image_src( $settings['custom_image_primary']['id'], $size, true );
		} else {
			$logo = wp_get_attachment_image_src( get_theme_mod( 'custom_logo' ), $size, true );
		}
		return $logo[0];
	}

	/**
	 * Render Site Image output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.3.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		$has_caption = $this->has_caption( $settings );

		$this->add_render_attribute( 'wrapper', 'class', 'sr-site-logo' );

		$size = $settings['site_logo_size_size'];

		$site_image = $this->site_image_url( $size );

		if ( site_url() . '/wp-includes/images/media/default.png' === $site_image ) {
			$site_image = site_url() . '/wp-content/plugins/elementor/assets/images/placeholder.png';
		} else {
			$site_image = $site_image;
		}

		if ( 'default' === $settings['link_to'] ) {
			$link = site_url();
			$this->add_render_attribute( 'link', 'href', $link );
		} else {
			$link     = $this->get_link_url( $settings );
			$link_url = isset( $link['url'] ) ? $link['url'] : '';
			$this->add_render_attribute( 'link', 'href', $link_url );
			if ( ! empty( $link['nofollow'] ) ) {
				$this->add_render_attribute( 'link', 'rel', 'nofollow' );
			}
			if ( ! empty( $link['is_external'] ) ) {
				$this->add_render_attribute( 'link', 'target', '_blank' );
			}
		}
		$class = '';
		
		?>
		<div <?php echo $this->get_render_attribute_string( 'wrapper' ); ?>>
		<?php if ( $has_caption ) : ?>
			<figure class="wp-caption">
		<?php endif; ?>
		<?php if ( $link ) : ?>
			<a class='<?php echo  esc_attr( $class ); ?>' <?php echo $this->get_render_attribute_string( 'link' ); ?>>
		<?php endif; ?>
		<?php
		if ( empty( $site_image ) ) {
			return;
		}
		$img_animation = '';

		if ( 'custom' !== $size ) {
			$image_size = $size;
		} else {
			require_once ELEMENTOR_PATH . 'includes/libraries/bfi-thumb/bfi-thumb.php';

			$image_dimension = $settings['site_logo_size_custom_dimension'];

			$image_size = [
				// Defaults sizes.
				0           => null, // Width.
				1           => null, // Height.

				'bfi_thumb' => true,
				'crop'      => true,
			];

			$has_custom_size = false;
			if ( ! empty( $image_dimension['width'] ) ) {
				$has_custom_size = true;
				$image_size[0]   = $image_dimension['width'];
			}

			if ( ! empty( $image_dimension['height'] ) ) {
				$has_custom_size = true;
				$image_size[1]   = $image_dimension['height'];
			}

			if ( ! $has_custom_size ) {
				$image_size = 'full';
			}
		}

		$image_url = $site_image;

		if ( ! empty( $settings['custom_image_primary']['url'] ) ) {

		} else {
			$image_data = wp_get_attachment_image_src( get_theme_mod( 'custom_logo' ), $image_size, true );
			$image_data_secondary = get_theme_mod( 'secondary_header_logo' );
			$image_data_sticky =get_theme_mod( 'sticky_header_logo' );
		}

		$site_image_class = 'elementor-animation-';

		if ( ! empty( $settings['hover_animation'] ) ) {
			$img_animation = $settings['hover_animation'];
		}
		if ( ! empty( $image_data ) ) {
			$image_url = $image_data[0];
		}

		if ( site_url() . '/wp-includes/images/media/default.png' === $image_url ) {
			$image_url = site_url() . '/wp-content/plugins/elementor/assets/images/placeholder.png';
		} else {
			$image_url = $image_url;
		}

		$class_animation = $site_image_class . $img_animation;

		$image_unset = site_url() . '/wp-content/plugins/elementor/assets/images/placeholder.png';

		if ( $image_unset !== $image_url ) {
			$image_url = $image_url;
		}

		if ($settings['logo_source'] == 'custom_logo' && ! empty( $settings['custom_image_secondary']['url'] ) ){
			$url_secondary = $settings['custom_image_secondary']['url'];
		}
		if ($settings['logo_source'] == 'custom_logo' && ! empty( $settings['custom_image_sticky']['url'] ) ){
			$url_sticky = $settings['custom_image_sticky']['url'];
		}
		if ($settings['logo_source'] == 'site_identity' && ! empty( $image_data_secondary )){
			$url_secondary = $image_data_secondary;
		}
		if ($settings['logo_source'] == 'site_identity' && ! empty( $image_data_sticky )){
			$url_sticky = $image_data_sticky;
		}	

		if ( ($settings['logo_source'] == 'custom_logo' && ! empty( $settings['custom_image_sticky']['url'] )) || ($settings['logo_source'] == 'site_identity' && ! empty( $image_data_sticky )) ){
			$this->add_render_attribute( 'container', [
				'sticky-logo' => 'true',
			] );
		}
		if($settings['logo_selected'] == "secondary" && ! empty( $image_data_secondary ) ){
			$image_url = $url_secondary;
		}else if($settings['logo_selected'] == "sticky" && ! empty( $image_data_sticky )){
			$image_url = $url_sticky;
		}
		?>

			<div class="sr-site-logo-set" <?php echo $this->get_render_attribute_string( 'container' ); ?>>           
				<div class="sr-site-logo-container">
					<img class="sr-site-logo-img sr-logo-primary <?php echo esc_attr( $class_animation ); ?>" src="<?php echo esc_url( $image_url ); ?>" alt="<?php echo esc_attr( Control_Media::get_image_alt( $settings['custom_image_primary'] ) ); ?>"/>
					<?php if ( isset($url_secondary)  ): ?>
						<img class="sr-site-logo-img sr-logo-secondary <?php echo esc_attr( $class_animation ); ?>" src="<?php echo esc_url( $url_secondary ); ?>" />
					<?php endif; ?>
					<?php if ( isset($url_sticky )): ?>
						<img class="sr-site-logo-img sr-logo-sticky <?php echo esc_attr( $class_animation ); ?>" src="<?php echo esc_url( $url_sticky ); ?>" />
					<?php endif; ?>	
				</div>
			</div>
		<?php if ( $link ) : ?>
					</a>
		<?php endif; ?>
		<?php
		if ( $has_caption ) :
			$caption_text = $this->get_caption( $settings );
			?>
			<?php if ( ! empty( $caption_text ) ) : ?>
					<div class="sr-caption-width"> 
						<figcaption class="widget-image-caption wp-caption-text"><?php echo wp_kses_post( $caption_text ); ?></figcaption>
					</div>
			<?php endif; ?>
				</figure>
		<?php endif; ?>
		</div>  
			<?php
	}

	/**
	 * Retrieve Site Logo widget link URL.
	 *
	 * @since 1.3.0
	 * @access private
	 *
	 * @param array $settings returns settings.
	 * @return array|string|false An array/string containing the link URL, or false if no link.
	 */
	private function get_link_url( $settings ) {
		if ( 'none' === $settings['link_to'] ) {
			return false;
		}

		if ( 'custom' === $settings['link_to'] ) {
			if ( empty( $settings['link']['url'] ) ) {
				return false;
			}
			return $settings['link'];
		}

		if ( 'default' === $settings['link_to'] ) {
			if ( empty( $settings['link']['url'] ) ) {
				return false;
			}
			return site_url();
		}
	}
}
Plugin::instance()->widgets_manager->register( new SR_SiteLogo() );