<?php

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

use Elementor\Controls_Manager;
use Elementor\Controls_Stack;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Element_Base;


class SR_Sticky {

	public static function register_controls(Element_Base $element) {
		$element->start_controls_section(
            '_srstick',
            [
				'label' => sprintf('<i class="sricons-logo"></i>&nbsp;  %s', __('Sticky', 'elementor-sonaar')),
				'tab' => Controls_Manager::TAB_ADVANCED, 
				'hide_in_inner' => true, 
            ]
        );
		$element->add_control(
			'sr_sticky',
			[
				'label' => __( 'S T I C K Y', 'elementor-sonaar' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'' => __( 'None', 'elementor-sonaar' ),
					'top' => __( 'Top', 'elementor-sonaar' ),
					//'bottom' => __( 'Bottom', 'elementor-sonaar' ),
				],
				'separator' => 'before',
				'frontend_available' => true,
			]
		);
		$element->add_control(
			'sr_sticky_on',
			[
				'label' => __( 'Sticky On', 'elementor-sonaar' ),
				'type' => Controls_Manager::SELECT2,
				'multiple' => true,
				'label_block' => true,
				'default' => [ 'desktop', 'tablet', 'mobile' ],
				'options' => [
					'desktop' => __( 'Desktop', 'elementor-sonaar' ),
					'tablet' => __( 'Tablet', 'elementor-sonaar' ),
					'mobile' => __( 'Mobile', 'elementor-sonaar' ),
				],
				'condition' => [
					'sr_sticky!' => '',
				],

				'frontend_available' => true,
			]
		);
		$element->add_control(
			'sr_sticky_offset',
			[
				'label' => __( 'Offset', 'elementor-sonaar' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 0,
				'min' => 0,
				'required' => true,
				'condition' => [
					'sr_sticky!' => '',
				],

				'frontend_available' => true,
			]
		);
		$element->add_control(
			'sticky_animation',
			[
				'label' => __( 'Enable Animation', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'elementor-sonaar' ),
				'label_off' => __( 'No', 'elementor-sonaar' ),
				'return_value' => 'enable',
				'default' => 'enable',
				'prefix_class' => 'sr-sticky-anim-',
				'condition' => [
					'sr_sticky!' => '',
				],
				/*'condition' => [
					'layout' => 'vertical',
				],*/
			]
		);
		
		$element->add_control(
			'sr_hide_after',
			[
				'label' => __( 'Apply attributes below after how many pixels?', 'elementor-sonaar' ),
				'type' => Controls_Manager::NUMBER,
				'default' => 0,
				'separator' => 'before',
				'condition' => [
					//'sr_sticky_hideonscroll' => '1',
					'sr_sticky!' => '',
				],
				'frontend_available' => true,
			]
		);
        $element->add_responsive_control(
            'sticky_padding',
            [
                'label' => __('Padding', 'elementor-sonaar'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}}.sr_sticky_showup' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition' => [
					'sr_sticky!' => '',
				],
            ]
		);
		$element->add_control(
			'sr_sticky_hideonscroll',
			[
				'label' => __( 'Hide on Scroll Down -> Show on Scroll Up', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'elementor-sonaar' ),
				'label_off' => __( 'No', 'elementor-sonaar' ),
				'return_value' => '1',
				'default' => '0',
				'condition' => [
					'sr_sticky!' => '',
				],
				'frontend_available' => true,
			]
		);
        $element->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'sticky_bg',
                'label' => __('Sticky Background', 'elementor-sonaar'),
                'types' => ['classic', 'gradient'],
				'selector' => '{{WRAPPER}}.sr_sticky_showup',
				'condition' => [
					'sr_sticky!' => '',
				],
            ]
		);
		$element->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'sticky_box_shadow',
				'selector' => '{{WRAPPER}}.sr_sticky_showup',
				'condition' => [
					'sr_sticky!' => '',
				],
            ]
        );
		/*if ( $element instanceof Widget_Base ) {
			$element->add_control(
				'sr_sticky_parent',
				[
					'label' => __( 'Stay In Column', 'elementor-sonaar' ),
					'type' => Controls_Manager::SWITCHER,
					'condition' => [
						'sr_sticky!' => '',
					],

					'frontend_available' => true,
				]
			);
		}*/

		/*$element->add_control(
			'sr_sticky_divider',
			[
				'type' => Controls_Manager::DIVIDER,
			]
		);*/
		$element->end_controls_section();
	}


	public static function init_control(){
		add_action( 'elementor/element/section/section_effects/after_section_end', [  __CLASS__, 'register_controls' ] );
	}
}
SR_Sticky::init_control();