<?php
namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */

class SR_TextGradient {


	/*public function __construct() {
		parent::__construct();
		$this->init_control();
	}*/

	public function get_name() {
		return 'sr-gradient-text';
	}

	public static function register_controls(Element_Base $element) {

		$element->start_controls_section(
			'sr_gradient_text_section',
			[
				'label' => __( 'Gradient Text Color', 'elementor-sonaar' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);

		$element->add_control(
			'sr_gradient_text',
			[
				'label' => __( 'Enable Gradient Text', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => '',
				'label_on' => 'Yes',
				'label_off' => 'No',
				'return_value' => 'yes',
			]
		);

		$element->add_control(
			'sr_gradient_text_color',
			[
				'label' => _x( 'Color', 'Background Control', 'elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#670093',
				'title' => _x( 'Background Color', 'Background Control', 'elementor' ),
				'selectors' => [
					'{{WRAPPER}} .elementor-heading-title' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					'sr_gradient_text' => 'yes',
				],
			]
		);

		$element->add_control(
			'sr_gradient_text_color_stop',
			[
				'label' => _x( 'Location', 'Background Control', 'elementor' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ '%' ],
				'default' => [
					'unit' => '%',
					'size' => 0,
				],
				'render_type' => 'ui',
				'condition' => [
					'sr_gradient_text' => 'yes',
				],
			]
		);

		$element->add_control(
			'sr_gradient_text_color_b',
			[
				'label' => _x( 'Second Color', 'Background Control', 'elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#f2295b',
				'render_type' => 'ui',
				'condition' => [
					'sr_gradient_text' => 'yes',
				],
			]
		);

		$element->add_control(
			'sr_gradient_text_color_b_stop',
			[
				'label' => _x( 'Location', 'Background Control', 'elementor' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ '%' ],
				'default' => [
					'unit' => '%',
					'size' => 100,
				],
				'render_type' => 'ui',
				'condition' => [
					'sr_gradient_text' => 'yes',
				],
			]
			);

			$element->add_control(
				'sr_gradient_text_gradient_type',
				[
					'label' => _x( 'Type', 'Background Control', 'elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'options' => [
						'linear' => _x( 'Linear', 'Background Control', 'elementor' ),
						'radial' => _x( 'Radial', 'Background Control', 'elementor' ),
					],
					'default' => 'linear',
					'render_type' => 'ui',
					'condition' => [
						'sr_gradient_text' => 'yes',
					],
				]
			);

			$element->add_control(
				'sr_gradient_text_gradient_angle',
				[
					'label' => _x( 'Angle', 'Background Control', 'elementor' ),
					'type' => \Elementor\Controls_Manager::SLIDER,
					'size_units' => [ 'deg' ],
					'default' => [
						'unit' => 'deg',
						'size' => 180,
					],
					'range' => [
						'deg' => [
							'step' => 10,
						],
					],
					'selectors' => [
						'{{WRAPPER}} .elementor-heading-title' => 'background-color: transparent; background-image: linear-gradient({{SIZE}}{{UNIT}}, {{sr_gradient_text_color.VALUE}} {{sr_gradient_text_color_stop.SIZE}}{{sr_gradient_text_color_stop.UNIT}}, {{sr_gradient_text_color_b.VALUE}} {{sr_gradient_text_color_b_stop.SIZE}}{{sr_gradient_text_color_b_stop.UNIT}}); -webkit-background-clip: text; -webkit-text-fill-color: transparent;',
					],
					'condition' => [
						'sr_gradient_text' => 'yes',
						'sr_gradient_text_gradient_type' => 'linear',
					],
				]
			);

			$element->add_control(
				'sr_gradient_text_gradient_position',
				[
					'label' => _x( 'Position', 'Background Control', 'elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'options' => [
						'center center' => _x( 'Center Center', 'Background Control', 'elementor' ),
						'center left' => _x( 'Center Left', 'Background Control', 'elementor' ),
						'center right' => _x( 'Center Right', 'Background Control', 'elementor' ),
						'top center' => _x( 'Top Center', 'Background Control', 'elementor' ),
						'top left' => _x( 'Top Left', 'Background Control', 'elementor' ),
						'top right' => _x( 'Top Right', 'Background Control', 'elementor' ),
						'bottom center' => _x( 'Bottom Center', 'Background Control', 'elementor' ),
						'bottom left' => _x( 'Bottom Left', 'Background Control', 'elementor' ),
						'bottom right' => _x( 'Bottom Right', 'Background Control', 'elementor' ),
					],
					'default' => 'center center',
					'selectors' => [
						'{{WRAPPER}} .elementor-heading-title' => 'background-color: transparent; background-image: radial-gradient(at {{VALUE}}, {{sr_gradient_text_color.VALUE}} {{sr_gradient_text_color_stop.SIZE}}{{sr_gradient_text_color_stop.UNIT}}, {{sr_gradient_text_color_b.VALUE}} {{sr_gradient_text_color_b_stop.SIZE}}{{sr_gradient_text_color_b_stop.UNIT}}); -webkit-background-clip: text; -webkit-text-fill-color: transparent;',
					],
					'condition' => [
						'sr_gradient_text' => 'yes',
						'sr_gradient_text_gradient_type' => 'radial',
					],
				]
			);

			$element->end_controls_section();

		}

		public static function init_control(){
			add_action( 'elementor/element/heading/section_title_style/after_section_end', [  __CLASS__, 'register_controls' ] );
		}

	}
	SR_TextGradient::init_control();
//Plugin::instance(new SR_TextGradient());