<?php
namespace Elementor;
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Base;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;
use Elementor\Core\Schemes\Typography;

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */

class SR_VideoList extends Widget_Base {

	public function get_name() {
		return 'sr-videolist';
	}
	public function get_title() {
		return __( 'Video List', 'elementor-sonaar' );
	}
	public function get_icon() {
		return 'eicon-youtube sonaar-badge';
	}
	public function get_help_url() {
		return 'https://support.sonaar.io';
	}
	public function is_reload_preview_required() {
		return true;
	}
	public function get_categories() {
		return [ 'elementor-sonaar' ];
	}
	public function get_keywords() {
		return [ 'video', 'youtube', 'sonaar'];
	}
	public function get_script_depends() {
		return [ 'elementor-sonaar' ];
	}

	/**
	* CONTENT
	* -------------------------------------------------
	*/

	protected function register_controls() {
		$this->start_controls_section(
			'section_content',
			[
				'label' => __( 'Videos List Settings', 'elementor-sonaar' ),
			]
		);
		$this->add_control(
			'custom_videolist_option',
			[
				'label' => __( 'Custom video list', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Yes', 'elementor-sonaar' ),
				'label_off' => __( 'No', 'elementor-sonaar' ),
				'return_value' => '1',
				'default' => '',
			]
		);
		$this->add_control(
			'number_of_videos',
			[
				'label' => __( 'Number of videos to show', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 1,
				'max' => 100,
				'step' => 1,
				'default' => 100,
				'condition' => [
					'custom_videolist_option' => '',
				]
			]
		);
		$this->add_control(
			'category_list',
				[
					'label'			=> esc_html__( 'Select Category', 'elementor-sonaar' ),
					'label_block' 	=> true,
					'type'          => \Elementor\Controls_Manager::SELECT2,
					'multiple' 		=> true,
					'label_block'	=> true,
					'options'		=> sr_elementor_select_category('video-category'),
					'condition' => [
						'custom_videolist_option' => '',
					]
				]
		);
		$this->add_control(
			'artit_filter',
			[
				'label' => __( 'Which Artist(s) you want to display the videos for?', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SELECT2,
				'label_block' => true,
				'multiple' => true,
				'options' => sr_elementor_select_events_for(),
				'default' => '',
				'condition' => [
					'custom_videolist_option' => '',
				]
			]
		);
		$this->add_control(
			'video_list',
				[
					'label'                 => esc_html__( 'Select Video(s)', 'elementor-sonaar' ),
					'label_block' => true,
					'type' => \Elementor\Controls_Manager::SELECT2,
					'multiple' => true,
					'options'               => sr_elementor_select_video(),  
					'condition' => [
						'custom_videolist_option' => '1',
					]        	
				]
		);
		$this->add_control(
			'hide_artist',
			[
				'label' => __( 'Hide Artist Name', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Hide', 'elementor-sonaar' ),
				'label_off' => __( 'SHOW', 'elementor-sonaar' ),
				'return_value' => 'none',
				'default' => 'table',
				'selectors' => [
					'{{WRAPPER}} .sr_it-videolist-item-artist' => 'display:{{VALUE}};',
				],
				'separator' => 'before',
			]
		);
		$this->add_control(
			'hide_date',
			[
				'label' => __( 'Hide Date', 'elementor-sonaar' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Hide', 'elementor-sonaar' ),
				'label_off' => __( 'SHOW', 'elementor-sonaar' ),
				'return_value' => 'none',
				'default' => 'table',
				'selectors' => [
					'{{WRAPPER}} .sr_it-videolist-item-date' => 'display:{{VALUE}};',
				],
			]
		);
		$this->add_control(
			'hr12',
				[
					'type' => \Elementor\Controls_Manager::DIVIDER,
					'style' => 'default',
				]
		);
		$this->add_control(
			'sr_video_title_tag',
			[
				'label' => __( 'HTML Video Title Tag', 'elementor-sonaar' ),
				'type' => Controls_Manager::SELECT,
				'options' => [
					'h1' => 'H1',
					'h2' => 'H2',
					'h3' => 'H3',
					'h4' => 'H4',
					'h5' => 'H5',
					'h6' => 'H6',
					'div' => 'div',
					'span' => 'span',
					'p' => 'p',
				],
				'default' => 'h1',
			]
		);
		$this->add_control(
			'hr13',
				[
					'type' => \Elementor\Controls_Manager::DIVIDER,
					'style' => 'default',
				]
		);
		$this->add_control(
			'important_note',
			[
				'label' => __( 'Message', 'elementor-sonaar' ),
				'show_label' => false,
				'type' => \Elementor\Controls_Manager::RAW_HTML,
				'raw' => __( '<br>To add a new video, go to the <a href="./edit.php?post_type=video" target="_blank">Videos Section</a>', 'elementor-sonaar' ),
				'content_classes' => 'elementor-sonaar-raw-html',
			]
		);

		$this->end_controls_section();


		/**
        * STYLE
        * -------------------------------------------------
		*/
		
		//-- COLORS
		$this->start_controls_section(
            'colors',
            [
                'label'                 => __( 'Colors', 'elementor-sonaar' ),
                'tab'                   => Controls_Manager::TAB_STYLE,
            ]
		);
		$this->start_controls_tabs( 'tabs_videolist_item' );
		$this->start_controls_tab(
			'tab_button_normal_videolist_item',
			[
				'label' => __( 'Normal', 'elementor' ),
			]
		);
		$this->add_control(
			'text_color',
			[
				'label'                 => __( 'Text Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .sr_it-videolist-item-title, {{WRAPPER}} .sr_it-videolist-item-artist, {{WRAPPER}} .sr_it-videolist-item-date'  => 'color: {{VALUE}}',
					'{{WRAPPER}} .sr_it-videolist-list .sonaar-play-button polygon, {{WRAPPER}} .sr_it-videolist-list .sonaar-play-button rect, {{WRAPPER}} .sr_it-videolist-list .sonaar-play-button path' => 'fill: {{VALUE}}',
					'{{WRAPPER}} .sr_it-videolist-list .sonaar-play-button .sonaar-play-circle circle'  => 'stroke: {{VALUE}}',
				],
			]
		);
		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover_videolist_item',
			[
				'label' => __( 'Hover', 'elementor' ),
			]
		);
		$this->add_control(
			'text_color_hover',
			[
				'label'                 => __( 'Text Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} article:hover .sr_it-videolist-item-title, {{WRAPPER}} article:hover .sr_it-videolist-item-artist, {{WRAPPER}} article:hover .sr_it-videolist-item-date'  => 'color: {{VALUE}}',
					'{{WRAPPER}} .sr_it-videolist-list article:hover .sonaar-play-button polygon, {{WRAPPER}} .sr_it-videolist-list article:hover .sonaar-play-button rect, {{WRAPPER}} .sr_it-videolist-list article:hover .sonaar-play-button path' => 'fill: {{VALUE}}',
					'{{WRAPPER}} .sr_it-videolist-list article:hover .sonaar-play-button .sonaar-play-circle circle'  => 'stroke: {{VALUE}}',
				],
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();


		//-- TYPOGRAOHY
		$this->start_controls_section(
            'typography',
            [
                'label'                 => __( 'Typography', 'elementor-sonaar' ),
                'tab'                   => Controls_Manager::TAB_STYLE,
            ]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
				[
					'name' => 'video_title_typography',
					'label' => __( 'Video Title Typography', 'elementor-sonaar' ),
					'scheme' => Typography::TYPOGRAPHY_1,
					'selector' => '{{WRAPPER}} .sr_it-videolist-item-title',
				]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
				[
					'name' => 'artist_typography',
					'label' => __( 'Artist Name Typography', 'elementor-sonaar' ),
					'scheme' => Typography::TYPOGRAPHY_1,
					'selector' => '{{WRAPPER}} .sr_it-videolist-item-artist',
				]
		);
		$this->add_group_control(
			Group_Control_Typography::get_type(),
				[
					'name' => 'date_typography',
					'label' => __( 'Date Typography', 'elementor-sonaar' ),
					'scheme' => Typography::TYPOGRAPHY_1,
					'selector' => '{{WRAPPER}} .sr_it-videolist-item-date',
				]
		);
		$this->end_controls_section();


		//-- VIDEOLIST ITEM SETTINGS
		$this->start_controls_section(
            'video_list_item_settings',
            [
                'label'                 => __( 'Video List Item Settings', 'elementor-sonaar' ),
                'tab'                   => Controls_Manager::TAB_STYLE,
            ]
		);
		
		$this->add_control(
			'border_type',
				[
					'label'                 => esc_html__( 'Border Type', 'elementor-sonaar' ),
					'type'                  => Controls_Manager::SELECT,
					'options' => [
								'none'  => __( 'None', 'elementor' ),
								'solid' => __( 'Solid', 'elementor' ),
								'double' => __( 'Double', 'elementor' ),
								'dotted' => __( 'Dotted', 'elementor' ),
								'dashed' => __( 'Dashed', 'elementor' ),
								'groove' => __( 'Groove', 'elementor' )
							],
					'default'               => 'solid',
					'selectors'             => [
						'{{WRAPPER}} .sr_it-videolist-list article' => 'border-bottom-style: {{VALUE}}',
					],													
				]
		);
		$this->add_control(
			'border_color',
			[
				'label'                 => __( 'Border Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} div.sr_it-videolist-list article' => 'border-color: {{VALUE}}',
				],
				'condition' => [
					'border_type!' => 'none',
				] 
			]
		);
		$this->add_responsive_control(
			'border_widths',
			[
				'label' => __( 'Border Width', 'sonaar-elementor' ) . ' (px)',
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 10,
					],
				],
				'default' => [
					'size' => 1,
					],
				'selectors' => [
					'{{WRAPPER}} .sr_it-videolist-list article' => '    border-bottom-width: {{SIZE}}px', 
				],
				'condition' => [
					'border_type!' => 'none',
				] 
			]
		);
		$this->add_responsive_control(
			'video_item_padding',
			[
				'label' => __( 'Item Padding', 'elementor-sonaar' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .sr_it-videolist-list article' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);
		$this->add_control(
			'gap',
			[
				'label' => __( 'Gap', 'sonaar-elementor' ) . ' (px)',
				'type' => Controls_Manager::SLIDER,
				'size_units' => [ 'px', 'em', '%' ],
				'range' => [
					'px' => [
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sr_it-videolist-list article' => ' width: calc( 100% - {{SIZE}}{{UNIT}} )', 
					'(tablet){{WRAPPER}} .sr_it-videolist-list article' => ' width: 100%', 
				],
			]
		);

		
		$this->end_controls_section();


		//-- PLAY BUTTON STYLE
		
		$this->start_controls_section(
			'play_button_style',
			[
				'label'                 => __( 'Play Button', 'elementor-sonaar' ),
				'tab'                   => Controls_Manager::TAB_STYLE,
			]
		);


		$this->start_controls_tabs( 'tabs_button_style_play_button' );
		$this->start_controls_tab(
			'tab_button_normal_play_button',
			[
				'label' => __( 'Normal', 'elementor' ),
			]
		);
		$this->add_control(
			'button_play_color',
			[
				'label'                 => __( 'Button Play Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .sr_it-videolist-list .sonaar-play-button .sonaar-play-circle circle' => 'stroke: {{VALUE}}',
					'{{WRAPPER}} .sr_it-videolist-list .sonaar-play-button rect, {{WRAPPER}} .sr_it-videolist-list .sonaar-play-button path, {{WRAPPER}} .sr_it-videolist-list .sonaar-play-button polygon' => 'fill: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'Button_play_background',
			[
				'label'                 => __( 'Button Play Background Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .sr_it-videolist-list .sonaar-play-button .sonaar-play-circle circle'  => 'fill: {{VALUE}}',
				],
			]
		);
		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover_play_button',
			[
				'label' => __( 'Hover', 'elementor' ),
			]
		);
		$this->add_control(
			'button_play_color_hover',
			[
				'label'                 => __( 'Button Play Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} div.sr_it-videolist-list article:hover .sonaar-play-button .sonaar-play-circle circle'  => 'stroke: {{VALUE}}',
					'{{WRAPPER}} div.sr_it-videolist-list article:hover .sonaar-play-button polygon, {{WRAPPER}} div.sr_it-videolist-list article:hover .sonaar-play-button rect, {{WRAPPER}} .sr_it-videolist-list article:hover .sonaar-play-button path' => 'fill: {{VALUE}}',
				],
			]
		);
		$this->add_control(
			'Button_play_background_hover',
			[
				'label'                 => __( 'Button Play Background Color', 'elementor-sonaar' ),
				'type'                  => Controls_Manager::COLOR,
				'default'               => '',
				'selectors'             => [
					'{{WRAPPER}} .sr_it-videolist-list article:hover .sonaar-play-button .sonaar-play-circle circle'  => 'fill: {{VALUE}}',
				],
			]
		);
		$this->end_controls_tab();
		$this->end_controls_tabs();


		$this->add_responsive_control(
			'play_button_width',
			[
				'label' => esc_html__( 'Play Button Width', 'essential-addons-elementor' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 300,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sr_it-videolist-list .sonaar-play-button' => 'width: {{SIZE}}px; height: {{SIZE}}px;',
				],
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'play_icon_width',
			[
				'label' => esc_html__( 'Control Icon Width', 'essential-addons-elementor' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 250,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sr_it-videolist-list .sonaar-play-button .sonaar-play-icon' => 'width: {{SIZE}}px; height: {{SIZE}}px;',
				],
			]
		);
		$this->add_responsive_control(
			'play_border_width',
			[
				'label' => esc_html__( 'Border Width', 'essential-addons-elementor' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .sr_it-videolist-list .sonaar-play-button .sonaar-play-circle circle' => 'stroke-width: {{SIZE}};',
				],
			]
		);
		$this->add_responsive_control(
			'play_button_offset_x',
			[
				'label' => __( 'Horizontal Offset', 'elementor' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => -500,
						'max' => 500,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'size_units' => [ '%', 'px' ],
				'default' => [
					'size' => '3',
					'unit' => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .sr_it-videolist-list .sonaar-play-button' => 'left: {{SIZE}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);
		$this->add_responsive_control(
			'play_button_offset_y',
			[
				'label' => __( 'Vertical Offset', 'elementor' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => -500,
						'max' => 500,
						'step' => 1,
					],
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'size_units' => [ '%', 'px' ],
				'default' => [
					'size' => '36',
					'unit' => 'px',
				],
				'selectors' => [
					'{{WRAPPER}} .sr_it-videolist-list .sonaar-play-button' => 'top: {{SIZE}}{{UNIT}};',
				],
			]
		);
	
		$this->end_controls_section();




	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$display_videos = $settings['video_list'];
		if(is_array($display_videos)){
			$display_videos = implode(", ", $display_videos); 
		}
		$category_list = $settings['category_list'];
		if(is_array($category_list)){
			$category_list = implode(", ", $category_list); 
		}
		$artist_filter = $settings['artit_filter'];
		if(is_array($artist_filter)){
			$artist_filter = implode(",", $artist_filter); 
		}

		$shortcode = '[iron_recentvideos titletag="'. $settings['sr_video_title_tag'] .'" hide_title="true" include="' . $display_videos . '" number="'. $settings['number_of_videos'] . '" category="' . $category_list . '" ';
		if( $artist_filter != ''){ 
			$shortcode .= 'artists_filter="' .  $artist_filter . '" ';
		};
		$shortcode .= ']';

		echo do_shortcode( $shortcode );
	}

	public function render_plain_content() {
		$settings = $this->get_settings_for_display();
		$display_videos = $settings['video_list'];
		if(is_array($display_videos)){
			$display_videos = implode(", ", $display_videos); 
		}
		$category_list = $settings['category_list'];
		if(is_array($category_list)){
			$category_list = implode(", ", $category_list); 
		}
		$artist_filter = $settings['artit_filter'];
		if(is_array($artist_filter)){
			$artist_filter = implode(",", $artist_filter); 
		}

		$shortcode = '[iron_recentvideos titletag="'. $settings['sr_video_title_tag'] .'" hide_title="true" include="' . $display_videos . '" number="'. $settings['number_of_videos'] . '" category="' . $category_list . '" ';
		if( $artist_filter != ''){ 
			$shortcode .= 'artists_filter="' .  $artist_filter . '" ';
		};
		$shortcode .= ']';

		echo do_shortcode( $shortcode );
	}

	
}


Plugin::instance()->widgets_manager->register( new SR_VideoList() );